(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    227953,       5783]
NotebookOptionsPosition[    210358,       5484]
NotebookOutlinePosition[    210810,       5502]
CellTagsIndexPosition[    210767,       5499]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Scalings for \[OpenCurlyDoubleQuote]3D buoyant \
hydraulic fractures: finite volume release from a point source\
\[CloseCurlyDoubleQuote] ",
 FontFamily->"Helvetica Neue"]], "Title",
 CellChangeTimes->{{3.672402542803837*^9, 3.67240257956633*^9}, 
   3.672402622675029*^9, {3.771845270199484*^9, 3.7718452715926437`*^9}, {
   3.772528431753448*^9, 3.77252844007487*^9}, {3.7725320415809727`*^9, 
   3.772532044977256*^9}, {3.806919272311406*^9, 3.806919283865741*^9}, {
   3.859617869115142*^9, 3.859617879788341*^9}, 3.8870707469311733`*^9, {
   3.887070779192176*^9, 3.887070789776341*^9}},
 TextAlignment->Center,
 TextJustification->0.,ExpressionUUID->"5de7d24f-a41e-4c7e-8291-a064e5e3d79f"],

Cell["A. M\[ODoubleDot]ri - B. Lecampion ", "Subtitle",
 CellChangeTimes->{{3.7718452745779676`*^9, 3.771845363879918*^9}, 
   3.772528445085444*^9, {3.806919291394862*^9, 3.8069192952379713`*^9}, {
   3.859618004202692*^9, 3.859618049378354*^9}, {3.859622883900078*^9, 
   3.859622907218726*^9}, {3.8870706317657557`*^9, 3.887070636569601*^9}, {
   3.887070799778553*^9, 
   3.887070803811445*^9}},ExpressionUUID->"737d3d60-8653-4558-9499-\
bc62f6bc803b"],

Cell[TextData[{
 "Supplemental Materials to the paper ",
 StyleBox["\[OpenCurlyDoubleQuote]Three-dimensional buoyant hydraulic \
fractures: finite volume release\[CloseCurlyDoubleQuote]",
  FontFamily->"Helvetica Neue"],
 "\nJ. Fluid Mech. (2023)"
}], "Subtitle",
 CellChangeTimes->{{3.672402649056776*^9, 3.6724027509088507`*^9}, 
   3.679135325676858*^9, 3.772528449154668*^9, {3.806919285281415*^9, 
   3.806919287240301*^9}, {3.887070642889352*^9, 3.887070644504691*^9}, {
   3.887070810060297*^9, 
   3.887070843031581*^9}},ExpressionUUID->"75a26214-14d1-47c0-bd31-\
c77a506dd51a"],

Cell["Impermeable medium", "Text",
 CellChangeTimes->{{3.859622911692726*^9, 
  3.859622920018463*^9}},ExpressionUUID->"e0d2a60a-9a10-4713-8db1-\
90e15e730ee0"],

Cell["\<\
We define all the dimensionless groups in a Mathematica replacement rule :\
\>", "Text",
 CellChangeTimes->{{3.672403045904581*^9, 3.672403108859313*^9}, {
  3.6724656731754503`*^9, 3.672465673979554*^9}, {3.772532061696175*^9, 
  3.772532079493392*^9}, {3.777562340923559*^9, 
  3.777562353819628*^9}},ExpressionUUID->"a3baab5e-c968-465e-a114-\
ae07dc6b5bad"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DimensionlessGroups", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"Ge", "\[Rule]", " ", 
      FractionBox[
       RowBox[{"Wstar", " ", "Ep"}], 
       RowBox[{"   ", 
        RowBox[{"bstar", " ", "Pstar"}]}]]}], 
     RowBox[{"(*", " ", 
      RowBox[{"elastic", " ", "pressure"}], " ", "*)"}], ",", "  ", 
     RowBox[{"Gv", "\[Rule]", " ", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{"Qstar", " ", "t"}], 
        RowBox[{"Wstar", "  ", "Lstar", " ", "bstar"}]], ")"}]}], 
     RowBox[{"(*", " ", 
      RowBox[{"Global", " ", "volume", " ", "balance"}], "*)"}], ",", "  ", 
     RowBox[{"Gm", "\[Rule]", " ", 
      FractionBox[
       RowBox[{"\[Mu]p", "  ", "Qstar", " "}], 
       RowBox[{"Pstar", " ", 
        SuperscriptBox["Wstar", "3"]}]]}], 
     RowBox[{"(*", " ", 
      RowBox[{"viscosity", " ", "-", "  ", 
       RowBox[{
       "viscous", " ", "pressure", " ", "over", " ", "characteristic", " ", 
        "pressure"}]}], "  ", "*)"}], ",", 
     RowBox[{"Gk", "\[Rule]", " ", 
      FractionBox["KIc", 
       RowBox[{
        SqrtBox["bstar"], " ", "Pstar"}]]}], 
     RowBox[{"(*", " ", 
      RowBox[{
      "toughness", " ", "pressure", " ", "over", " ", "characteristic", " ", 
       "pressure"}], " ", "*)"}], ",", 
     RowBox[{"Gq", "\[Rule]", " ", 
      FractionBox[
       RowBox[{"Qo", " "}], 
       RowBox[{"Qstar", "  "}]]}], 
     RowBox[{"(*", " ", 
      RowBox[{"inj", " ", "rate"}], "*)"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"Gb", "\[Rule]", "    ", 
      FractionBox[
       RowBox[{"\[CapitalDelta]\[Gamma]", " ", "Lstar"}], 
       RowBox[{" ", "Pstar"}]]}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "Buoyancy", " ", "pressure", " ", "vs", " ", "characteristic", " ", 
       "pressure"}], " ", "*)"}], ",", 
     RowBox[{"Gmh", "\[Rule]", " ", 
      FractionBox[
       RowBox[{"\[Mu]p", "  ", "vxstar", " ", "bstar", " "}], 
       RowBox[{"Pstar", " ", 
        SuperscriptBox["Wstar", "2"]}]]}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"viscous", " ", "pressure", " ", 
       RowBox[{"(", 
        RowBox[{
        "associated", " ", "with", " ", "horizontal", " ", "velocity"}], 
        ")"}], "  ", "vs", " ", "characteristic", " ", "pressure"}], " ", 
      "*)"}], " ", ",", 
     RowBox[{"Gmv", "\[Rule]", " ", 
      FractionBox[
       RowBox[{"\[Mu]p", "  ", "vzstar", " ", "Lstar", " "}], 
       RowBox[{"\[CapitalDelta]\[Gamma]", " ", "Lstar", " ", 
        SuperscriptBox["Wstar", "2"]}]]}], 
     RowBox[{"(*", "   ", 
      RowBox[{"viscous", " ", "pressure", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
         "associated", " ", "with", " ", "vertical", " ", "velocity"}], ")"}],
         " ", "/", " ", "buoyancy"}], " ", "pressure"}], "  ", "*)"}], " ", 
     ",", 
     RowBox[{"Gs", "\[Rule]", " ", 
      RowBox[{"bstar", "/", "Lstar"}]}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"aspect", " ", "ratio"}], " ", "*)"}], " ", ",", 
     RowBox[{"GvelV", "->", " ", 
      RowBox[{"vzstar", " ", 
       FractionBox["t", "Lstar"]}]}]}], " ", 
    RowBox[{"(*", "  ", 
     RowBox[{
      RowBox[{"vertical", " ", "velocity"}], " ", "==", " ", 
      RowBox[{"fracture", " ", "length", " ", "velocity"}]}], "*)"}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.533052358671875*^9, 3.533052522671875*^9}, {
   3.533065219265625*^9, 3.5330652194375*^9}, {3.5629352099735146`*^9, 
   3.5629352203781147`*^9}, {3.566321357308629*^9, 3.5663213617246294`*^9}, {
   3.566321660746629*^9, 3.566321661131629*^9}, {3.5663217370926294`*^9, 
   3.566321741011629*^9}, {3.616930170709961*^9, 3.6169302415610137`*^9}, {
   3.6169303057756863`*^9, 3.61693032122157*^9}, 3.6169303557105427`*^9, {
   3.616932316908717*^9, 3.6169323234410906`*^9}, {3.6169354608725414`*^9, 
   3.6169355309045467`*^9}, {3.6193525852060566`*^9, 3.619352592867597*^9}, {
   3.619946799536836*^9, 3.6199468029320307`*^9}, {3.652609093215761*^9, 
   3.652609129430015*^9}, {3.652759702376358*^9, 3.652759732342367*^9}, {
   3.652762943181024*^9, 3.652762958424828*^9}, {3.652762995944518*^9, 
   3.652763017936494*^9}, {3.6527631564851637`*^9, 3.6527631832274027`*^9}, {
   3.6527632969350863`*^9, 3.652763303795904*^9}, 3.652763430077737*^9, {
   3.652763591780796*^9, 3.652763634158802*^9}, {3.6527661978970757`*^9, 
   3.652766202508829*^9}, 3.6527662837146463`*^9, 3.652766322640197*^9, 
   3.652766527296386*^9, {3.652767478251933*^9, 3.652767485913275*^9}, {
   3.652767521125354*^9, 3.652767522074901*^9}, 3.6527678752149897`*^9, 
   3.652768682640833*^9, {3.653395052521241*^9, 3.6533950599458923`*^9}, 
   3.6533951346624537`*^9, {3.653395179696431*^9, 3.653395182303726*^9}, {
   3.653395281331224*^9, 3.653395318759282*^9}, {3.672403079280705*^9, 
   3.672403082565544*^9}, 3.6724031161902657`*^9, {3.6724034940764923`*^9, 
   3.672403516884142*^9}, 3.672403901477663*^9, {3.6724039550299587`*^9, 
   3.672403968229536*^9}, {3.672404029958021*^9, 3.672404050445199*^9}, {
   3.67240408812247*^9, 3.672404090511881*^9}, 3.672404145835596*^9, {
   3.67240422701035*^9, 3.672404272661921*^9}, {3.672404541563258*^9, 
   3.672404597456646*^9}, {3.672405992452827*^9, 3.672406008229105*^9}, {
   3.6724062739004707`*^9, 3.6724062912974377`*^9}, {3.672406377863359*^9, 
   3.672406380036438*^9}, {3.67246827700905*^9, 3.672468282590543*^9}, {
   3.67246852623904*^9, 3.6724685298567*^9}, {3.772528470165105*^9, 
   3.772528479770712*^9}, {3.7775608011666803`*^9, 3.777560816075879*^9}, {
   3.7775623303652697`*^9, 3.777562336114339*^9}, {3.806919329206262*^9, 
   3.806919331586741*^9}, {3.8069193748548*^9, 3.806919396287855*^9}, {
   3.841327421381083*^9, 3.841327569567313*^9}, 3.841327611079843*^9, {
   3.842437567682034*^9, 3.842437570354681*^9}, 3.854167943332735*^9, {
   3.854168102608548*^9, 3.8541681067274017`*^9}, {3.854178241497179*^9, 
   3.854178256666668*^9}, {3.854278206011071*^9, 3.854278373217987*^9}, {
   3.854278808412108*^9, 3.8542788271679487`*^9}, {3.85875263686759*^9, 
   3.8587526655040417`*^9}, {3.859622941206584*^9, 3.859623035930221*^9}, {
   3.8596230728828087`*^9, 3.859623083064233*^9}, 3.860655868506115*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"ca414df2-c49e-4bf5-bf9a-3a42f4ce0aed"],

Cell[TextData[{
 "Ep: Plane Strain Young Modulus (Pa)\nt: time  (s) \n\[Mu]p = 12 \[Mu] : \
viscosity coefficient appearing in Poiseuille law   (Pa.s) and in viscous \
energy dissipation \nKIc   : fracture toughness\nQo :  injection rate ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["m", "3"], "/", " ", "s"}], ")"}], TraditionalForm]],
  ExpressionUUID->"168d2086-7c97-446b-b26d-19d00bfc6b8d"],
 "\nVo :  released volume ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SuperscriptBox["m", "3"], ")"}], TraditionalForm]],ExpressionUUID->
  "b35a8789-be3e-4189-bb32-42af666ae8bc"],
 "\nts : shut-in time (s)"
}], "Text",
 CellChangeTimes->{{3.6724031221318073`*^9, 3.672403405265527*^9}, {
   3.6724034588704147`*^9, 3.672403476389062*^9}, {3.672403519538478*^9, 
   3.672403526954012*^9}, {3.6724035711460133`*^9, 3.672403594054043*^9}, {
   3.6724036361419697`*^9, 3.672403648466851*^9}, {3.672403863670496*^9, 
   3.672403865116671*^9}, 3.672403911498766*^9, {3.6724061706258097`*^9, 
   3.672406190895205*^9}, {3.772528483888185*^9, 3.772528485519836*^9}, 
   3.772532098361033*^9, 3.777562326981731*^9, {3.777562363252494*^9, 
   3.777562399881998*^9}, {3.8069194365978394`*^9, 3.806919465205038*^9}, {
   3.854278157044847*^9, 3.854278195248653*^9}, {3.854278388841071*^9, 
   3.8542783903718863`*^9}, {3.85962306292028*^9, 3.85962306825403*^9}, {
   3.860655850119569*^9, 3.860655873871814*^9}, {3.868528968944254*^9, 
   3.868528972819821*^9}, {3.887070867872283*^9, 3.887070877139203*^9}, 
   3.8870716076795893`*^9},ExpressionUUID->"f2300f5c-5086-43d1-9698-\
3158a72fa88c"],

Cell[CellGroupData[{

Cell["Radial scalings bstar=Lstar", "Section",
 CellChangeTimes->{{3.672406456311734*^9, 3.672406515818255*^9}, 
   3.772528498063231*^9, {3.772528566620352*^9, 3.7725285685682898`*^9}, {
   3.800876394886496*^9, 3.800876395920429*^9}, {3.806919320026758*^9, 
   3.806919321193184*^9}, {3.8395848095215893`*^9, 3.8395848143448668`*^9}, {
   3.859623111560573*^9, 
   3.859623121108039*^9}},ExpressionUUID->"9ed53687-2777-4407-a980-\
19d3e5bb2c31"],

Cell[CellGroupData[{

Cell["Classical zero buoyancy scalings  ", "Subsection",
 CellChangeTimes->{{3.8395847990656023`*^9, 3.839584841041462*^9}, {
   3.854278353768096*^9, 3.854278358355378*^9}, 
   3.859623108967618*^9},ExpressionUUID->"98f8bdde-7eb8-472b-9ba2-\
7258e0a60c57"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", 
    RowBox[{"[", "V", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f24f4bc9-feef-4815-8105-4d761169c20e"],
 " Scaling: finite volume / storage / Viscosity scaling"
}], "Subsubsection",
 CellChangeTimes->{{3.672403429121324*^9, 3.672403453670259*^9}, {
   3.672403568072235*^9, 3.672403569423004*^9}, {3.672406226933893*^9, 
   3.672406232236374*^9}, 3.8069198540691643`*^9, {3.8685289787241983`*^9, 
   3.868528979475827*^9}, {3.8870708970239773`*^9, 
   3.887070931672121*^9}},ExpressionUUID->"1660a6b5-aab8-4a82-b336-\
de7c335fe195"],

Cell["\<\
Gv=Gm=Ge=1 and Gq = Qo/(Vo/t) in that scaling  (i.e. storage, finite volume, \
elasticity  and viscosity as first order phenomena)  / no fluid lag\
\>", "Text",
 CellChangeTimes->{{3.672403687255912*^9, 3.67240369741529*^9}, {
  3.672406243749956*^9, 3.672406247995278*^9}, {3.672406310280857*^9, 
  3.672406312591201*^9}, {3.772531554610944*^9, 3.772531608037846*^9}, {
  3.77253167970325*^9, 3.772531682355589*^9}, {3.777564304028982*^9, 
  3.777564310276422*^9}, {3.88707093817679*^9, 
  3.8870709892389383`*^9}},ExpressionUUID->"ea5e164f-2205-4710-a8b3-\
b60d599f28ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MScales", "=", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", " ", 
           RowBox[{"#", " ", "/.", "DimensionlessGroups"}], ")"}], "\[Equal]",
           "1"}], " ", "&"}], " ", "/@", " ", 
        RowBox[{"{", 
         RowBox[{"Ge", ",", "Gv", ",", "Gm", ",", "Gs", " ", ",", 
          RowBox[{"vxstar", "/", "vzstar"}], ",", "GvelV"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Gq", "\[Equal]", 
           RowBox[{"Qo", "/", 
            RowBox[{"(", 
             RowBox[{"Vo", "/", "t"}], ")"}]}]}], ")"}], "/.", 
         "DimensionlessGroups"}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "Lstar", ",", "bstar", ",", " ", "Wstar", ",", "Pstar", ",", "Qstar", 
       ",", "vxstar", ",", "vzstar"}], "}"}]}], "]"}], " ", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.672403653062512*^9, 3.6724036790815353`*^9}, 
   3.6724039067706327`*^9, 3.672404114303997*^9, {3.67240415202325*^9, 
   3.672404154164214*^9}, {3.672404299101603*^9, 3.6724043143795347`*^9}, {
   3.672404606568009*^9, 3.6724046308877583`*^9}, {3.67240631943143*^9, 
   3.672406331390646*^9}, 3.672466044229739*^9, {3.777560843271785*^9, 
   3.77756084497405*^9}, {3.841327576208165*^9, 3.8413275820304747`*^9}, {
   3.858755724959578*^9, 3.858755726284359*^9}, {3.859623372000393*^9, 
   3.859623378083046*^9}, {3.860655801714856*^9, 3.860655837584363*^9}, {
   3.860655881763236*^9, 3.860655890138815*^9}, 3.8606560811690617`*^9},
 CellLabel->"In[72]:=",ExpressionUUID->"18e9cf7b-b438-440b-b69d-04aa2e675e99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "9"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]]}], 
     SuperscriptBox["\[Mu]p", 
      RowBox[{"1", "/", "9"}]]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "9"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]]}], 
     SuperscriptBox["\[Mu]p", 
      RowBox[{"1", "/", "9"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"2", "/", "9"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "9"}]]}]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}], 
     SuperscriptBox["t", 
      RowBox[{"1", "/", "3"}]]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox["Vo", "t"]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "9"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"8", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "9"}]]}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "9"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"8", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "9"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.672403657468069*^9, 3.672403669527316*^9}, 
   3.672403738816983*^9, {3.672404098390545*^9, 3.672404115676429*^9}, 
   3.67240415499277*^9, {3.672404303178442*^9, 3.6724043157026987`*^9}, 
   3.672404372376451*^9, {3.672404607237997*^9, 3.6724046315956593`*^9}, 
   3.672406127022051*^9, {3.672406324074513*^9, 3.6724063321792517`*^9}, 
   3.672406391928029*^9, 3.672406422737809*^9, 3.67240774678997*^9, 
   3.672465984595598*^9, 3.6724660452175293`*^9, 3.672468350062853*^9, {
   3.67246854084615*^9, 3.672468546478408*^9}, 3.672477670894991*^9, 
   3.672477830279271*^9, 3.672478395141573*^9, 3.672478494563546*^9, 
   3.672483139871182*^9, 3.679382408166603*^9, 3.772527523704281*^9, {
   3.772528561748595*^9, 3.772528570953174*^9}, 3.772531610449092*^9, 
   3.777560846279707*^9, {3.783255979142168*^9, 3.783255992669018*^9}, 
   3.783268505877932*^9, 3.7906671962943573`*^9, 3.80691969794639*^9, 
   3.8069236741287403`*^9, {3.80693492259382*^9, 3.806934926815383*^9}, 
   3.839667986696463*^9, {3.8413275852803288`*^9, 3.8413276143025713`*^9}, 
   3.842437589567285*^9, 3.842438512536666*^9, 3.854192948179517*^9, 
   3.8542783973719263`*^9, 3.854278832034605*^9, 3.856261270083714*^9, 
   3.858417800500339*^9, 3.858417870125019*^9, 3.8587556297099867`*^9, 
   3.858755728272196*^9, 3.8588294344077806`*^9, 3.858919005894705*^9, 
   3.858919052495152*^9, 3.8596232811725683`*^9, 3.859623378474963*^9, {
   3.860655882537301*^9, 3.860655890724596*^9}, 3.8606560817154016`*^9, 
   3.860727222585422*^9, 3.8607435798418503`*^9, 3.860828860311945*^9, 
   3.8611561646406527`*^9, 3.86118012575098*^9, 3.861186017918254*^9, 
   3.861193414020494*^9, 3.861193928183041*^9, {3.861194414860976*^9, 
   3.8611944162839737`*^9}, 3.861249102165388*^9, {3.868528981803545*^9, 
   3.868528996616441*^9}, 3.868662181177919*^9, 3.869136963452468*^9, 
   3.869221837220746*^9, 3.869624278180192*^9, {3.8707689402202253`*^9, 
   3.870768955947217*^9}, {3.887245908949605*^9, 3.8872459192042418`*^9}},
 CellLabel->"Out[72]=",ExpressionUUID->"efede6bf-029d-414e-a9e0-d8007f3f7409"]
}, Open  ]],

Cell["\<\
The remaining (non-unity) dimensionless numbers provides the dimensionless \
numbers governing the solution of the problem\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 3.672403786033778*^9}, {
  3.78326850660122*^9, 3.78326850727908*^9}, {3.86118012621662*^9, 
  3.861180127117938*^9}},ExpressionUUID->"23bdf49a-d94e-48b7-93b4-\
058d28ad4a97"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mnumbers", "=", 
  RowBox[{
   RowBox[{"DimensionlessGroups", "/.", "MScales"}], " ", "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.6724037909628773`*^9, 3.672403797056397*^9}, 
   3.672406420408486*^9, {3.6724066006953983`*^9, 3.672406602869825*^9}, 
   3.6724660495896063`*^9},
 CellLabel->"In[73]:=",ExpressionUUID->"636d4c22-3b04-4c94-a20a-bf769529f284"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gm", "\[Rule]", "1"}], ",", 
   RowBox[{"Gk", "\[Rule]", 
    FractionBox[
     RowBox[{"KIc", " ", 
      SuperscriptBox["t", 
       RowBox[{"5", "/", "18"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"13", "/", "18"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "6"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"5", "/", "18"}]]}]]}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{"Qo", " ", "t"}], "Vo"]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"4", "/", "9"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", "\[CapitalDelta]\[Gamma]"}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"4", "/", "9"}]]}]]}], ",", 
   RowBox[{"Gmh", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmv", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"4", "/", "9"}]]}], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"4", "/", "9"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", "\[CapitalDelta]\[Gamma]"}]]}], ",", 
   RowBox[{"Gs", "\[Rule]", "1"}], ",", 
   RowBox[{"GvelV", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6724037929730186`*^9, 3.672403797589807*^9}, 
   3.672404124172846*^9, 3.672404157509701*^9, 3.6724046350615788`*^9, 
   3.67240612911729*^9, 3.6724063340202723`*^9, 3.672406393511703*^9, 
   3.672406424152906*^9, 3.67240774865287*^9, 3.6724659847409687`*^9, 
   3.672466049910244*^9, 3.6724683501210327`*^9, {3.672468540891635*^9, 
   3.6724685465282383`*^9}, 3.672477670946267*^9, 3.67247783033049*^9, 
   3.67247839519382*^9, 3.672478494612151*^9, 3.672483139923152*^9, 
   3.67938240819844*^9, 3.772527523773363*^9, 3.77252857249334*^9, 
   3.7725316147405167`*^9, 3.777560850152916*^9, {3.783255979349505*^9, 
   3.7832559926838703`*^9}, 3.78326850839297*^9, 3.79066719724582*^9, 
   3.806919699902247*^9, 3.8069236741357193`*^9, {3.806934922674449*^9, 
   3.806934926823443*^9}, 3.8396679867322197`*^9, {3.8413275885818987`*^9, 
   3.841327615646639*^9}, 3.842437591848042*^9, 3.854192948261839*^9, 
   3.854278401481739*^9, 3.854278834038022*^9, 3.856261270094116*^9, 
   3.8584178008719*^9, 3.858417870319849*^9, 3.858755629873725*^9, 
   3.858829434573132*^9, 3.858919005901099*^9, 3.8589190525656033`*^9, 
   3.859623281361197*^9, 3.859623380636733*^9, 3.860655897606262*^9, 
   3.8606560891036263`*^9, 3.860727225070011*^9, 3.8607435818218107`*^9, 
   3.8608288638509083`*^9, 3.861156166802294*^9, 3.8611801288427258`*^9, 
   3.861186020961018*^9, 3.8611934170014467`*^9, 3.861193928319584*^9, {
   3.861194415021804*^9, 3.861194416336042*^9}, 3.861249102340502*^9, 
   3.868528996642445*^9, 3.868662181313743*^9, 3.869136963606477*^9, 
   3.8692218372952843`*^9, 3.8696242782264*^9, {3.87076894032653*^9, 
   3.870768956007153*^9}, {3.8872459089571037`*^9, 3.887245919217104*^9}},
 CellLabel->"Out[73]=",ExpressionUUID->"2181cf4f-2209-4ff6-9879-6116c0d21c6f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "time", " ", "of", " ", "viscous", " ", "buoyancy", " ", "transition", "  ", 
    SubscriptBox["t", 
     RowBox[{"m", 
      OverscriptBox["m", "^"]}]]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"tmb", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Gb", "/.", "Mnumbers"}], ")"}], "\[Equal]", " ", "1"}], ",",
        "t"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "PowerExpand", 
    "    "}]}]}]], "Input",
 CellChangeTimes->{{3.772528573871196*^9, 3.772528619475988*^9}, 
   3.772528758677088*^9, {3.772531617950453*^9, 3.772531638414073*^9}, {
   3.772531737946969*^9, 3.772531742940597*^9}, {3.777560939443859*^9, 
   3.7775609515221243`*^9}, {3.777564524442505*^9, 3.777564528483741*^9}, 
   3.7832560218877287`*^9, {3.80691972126637*^9, 3.806919746373539*^9}, {
   3.8596231310375013`*^9, 3.8596231528074007`*^9}, {3.887071021976694*^9, 
   3.887071040390813*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"9194d2f9-7050-4db1-8ae8-345ea69c9a88"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["Ep", 
      RowBox[{"5", "/", "4"}]], " ", "\[Mu]p"}], 
    RowBox[{
     SuperscriptBox["Vo", 
      RowBox[{"3", "/", "4"}]], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"9", "/", "4"}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.772531743603874*^9, 3.772531781320299*^9, 3.777560857499569*^9, {
   3.783255979447081*^9, 3.783255992725329*^9}, 3.7832685097872553`*^9, 
   3.7906671993892927`*^9, 3.8069197477111387`*^9, 3.8069236741743813`*^9, {
   3.8069349227536182`*^9, 3.8069349495433064`*^9}, 3.839667986765564*^9, {
   3.841327620079565*^9, 3.8413276355338297`*^9}, 3.84243759507889*^9, 
   3.8541929483145313`*^9, 3.854278413022934*^9, 3.856261270209818*^9, 
   3.85841780090664*^9, 3.8584178704052343`*^9, 3.858755629989236*^9, 
   3.858829434642208*^9, 3.8589190059729557`*^9, 3.858919052601713*^9, 
   3.8596232815620728`*^9, 3.8596233831472263`*^9, 3.8606559190654707`*^9, 
   3.860656090962236*^9, 3.8607272277437963`*^9, 3.860743582703425*^9, 
   3.860828864624242*^9, 3.86115616795539*^9, 3.861180129827241*^9, 
   3.861186022451076*^9, 3.86119341860072*^9, 3.861193928347947*^9, {
   3.861194415055376*^9, 3.861194416374399*^9}, 3.861249102368107*^9, 
   3.868528996660117*^9, 3.868662181335984*^9, 3.86913696362932*^9, 
   3.8692218373158827`*^9, 3.869624278243794*^9, {3.870768940386075*^9, 
   3.870768956027019*^9}, {3.887245908997727*^9, 3.887245919255625*^9}},
 CellLabel->"Out[74]=",ExpressionUUID->"2da6cc11-e091-45be-81d7-1fbd632772ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "time", " ", "of", " ", "viscosity", " ", "to", " ", "toughness", " ", 
    "transition", " ", 
    SubscriptBox["t", "mk"]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"tmk", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Gk", "/.", "Mnumbers"}], ")"}], "\[Equal]", " ", "1"}], ",",
        "t"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "PowerExpand", 
    "    "}]}]}]], "Input",
 CellChangeTimes->{{3.8069197618631353`*^9, 3.806919775739375*^9}, {
  3.8596231593684483`*^9, 3.8596231604130783`*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"6a60b8da-c24c-41b1-a78e-6a2435c0afb0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["Ep", 
      RowBox[{"13", "/", "5"}]], " ", 
     SuperscriptBox["Vo", 
      RowBox[{"3", "/", "5"}]], " ", "\[Mu]p"}], 
    SuperscriptBox["KIc", 
     RowBox[{"18", "/", "5"}]]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8069197763129883`*^9, 3.806923674184155*^9, {3.806934922808035*^9, 
   3.8069349268797626`*^9}, 3.839667986779317*^9, {3.841327621909608*^9, 
   3.841327637395011*^9}, 3.8424375962887173`*^9, 3.854192948341063*^9, 
   3.854278421237378*^9, 3.8562612702490673`*^9, 3.858417800922785*^9, 
   3.858417870435849*^9, 3.858755630052753*^9, 3.858829434670961*^9, 
   3.858919005997176*^9, 3.858919052629794*^9, 3.859623281601287*^9, 
   3.860655926598695*^9, 3.860656093584762*^9, 3.860727230203348*^9, 
   3.860743583345977*^9, 3.86082886523897*^9, 3.861156169064335*^9, 
   3.861180130649962*^9, 3.861186023088327*^9, 3.86119342002702*^9, 
   3.861193928381797*^9, {3.861194415088036*^9, 3.861194416408057*^9}, 
   3.861249102399181*^9, 3.868528996678163*^9, 3.868662181360869*^9, 
   3.8691369636530247`*^9, 3.869221837332087*^9, 3.869624278257992*^9, {
   3.8707689404148703`*^9, 3.870768956042687*^9}, {3.887245909039262*^9, 
   3.887245919298835*^9}},
 CellLabel->"Out[75]=",ExpressionUUID->"4664d8d0-b5ae-49d1-8603-66d7ea271844"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["K", 
    RowBox[{"[", "V", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e660f165-a50c-438f-8532-9e63e6177e31"],
 " Scaling: finite volume / storage / Toughness scaling"
}], "Subsubsection",
 CellChangeTimes->{{3.672403429121324*^9, 3.672403453670259*^9}, {
   3.672403568072235*^9, 3.672403569423004*^9}, {3.672406226933893*^9, 
   3.672406232236374*^9}, {3.672406398146133*^9, 3.672406401937819*^9}, 
   3.77252771122622*^9, {3.887070906361886*^9, 3.8870709102311974`*^9}, 
   3.887071219697435*^9},ExpressionUUID->"4ca980d4-d168-4bf6-99b4-\
082e67966b8e"],

Cell["\<\
Ge=Gv=Gk=1 and Gq = Qo/(Vo/t) in that scaling  (i.e. storage, finite volume, \
elasticity  and toughness as first order phenomena)  / no fluid lag\
\>", "Text",
 CellChangeTimes->{{3.672403687255912*^9, 3.67240369741529*^9}, {
   3.672406243749956*^9, 3.672406247995278*^9}, {3.672406310280857*^9, 
   3.672406312591201*^9}, 3.672406404834804*^9, {3.772531653422431*^9, 
   3.772531686194335*^9}, {3.7775643152279577`*^9, 3.777564317675724*^9}, {
   3.8870712622827597`*^9, 
   3.887071285107943*^9}},ExpressionUUID->"ae4fe989-2572-41b7-bc04-\
ee410b24ef73"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KScales", "=", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", " ", 
           RowBox[{"#", " ", "/.", "DimensionlessGroups"}], ")"}], "\[Equal]",
           "1"}], " ", "&"}], " ", "/@", " ", 
        RowBox[{"{", 
         RowBox[{"Ge", ",", "Gv", ",", "Gk", ",", "Gs", " ", ",", 
          RowBox[{"vxstar", "/", "vzstar"}], ",", "GvelV"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Gq", "\[Equal]", " ", 
           RowBox[{"Qo", "/", 
            RowBox[{"(", 
             RowBox[{"Vo", "/", "t"}], ")"}]}]}], ")"}], "/.", 
         "DimensionlessGroups"}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "Lstar", ",", "bstar", ",", " ", "Wstar", ",", "Pstar", ",", "Qstar", 
       ",", "vxstar", ",", "vzstar"}], "}"}]}], "]"}], " ", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.672403653062512*^9, 3.6724036790815353`*^9}, 
   3.6724039067706327`*^9, 3.672404114303997*^9, {3.67240415202325*^9, 
   3.672404154164214*^9}, {3.672404299101603*^9, 3.6724043143795347`*^9}, {
   3.672404606568009*^9, 3.6724046308877583`*^9}, {3.67240631943143*^9, 
   3.672406331390646*^9}, {3.672406407364108*^9, 3.672406417529558*^9}, 
   3.672466053029285*^9, {3.777560982442871*^9, 3.777560984873324*^9}, {
   3.842437791670762*^9, 3.842437800488782*^9}, {3.858755734858754*^9, 
   3.858755736566877*^9}, {3.859623338001145*^9, 3.859623353586422*^9}, {
   3.860655945583679*^9, 3.860655947713462*^9}, {3.860656037118222*^9, 
   3.860656072009262*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"2c4339b2-38e1-4fa8-a064-a41b701214fb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "5"}]]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "5"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]]}], 
     SuperscriptBox["Ep", 
      RowBox[{"4", "/", "5"}]]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"6", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]]}]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox["Vo", "t"]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "5"}]], " ", "t"}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "5"}]], " ", "t"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.860656072563443*^9, 3.8606560979707823`*^9}, 
   3.860727232747313*^9, 3.860743586468485*^9, 3.860828867902113*^9, 
   3.861156171479562*^9, 3.8611801328631573`*^9, 3.861186024768598*^9, 
   3.861193421993072*^9, 3.8611939284400682`*^9, {3.8611944151439857`*^9, 
   3.861194416474545*^9}, 3.8612491024713593`*^9, {3.868528985233622*^9, 
   3.868528996732032*^9}, 3.86866218141917*^9, 3.869136963712245*^9, 
   3.869221837386923*^9, 3.869624278314996*^9, {3.870768940439866*^9, 
   3.8707689561022177`*^9}, {3.887245909110737*^9, 3.88724591937071*^9}},
 CellLabel->"Out[76]=",ExpressionUUID->"1289a08f-4c31-45e1-8003-0a771bba2a61"]
}, Open  ]],

Cell["\<\
The remaining (non-unity) dimensionless numbers provides the dimensionless \
numbers governing the solution of the problem\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 
  3.672403786033778*^9}},ExpressionUUID->"8497c22f-0262-4618-84d9-\
f6c993734ae5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Knumbers", "=", 
  RowBox[{
   RowBox[{"DimensionlessGroups", "/.", "KScales"}], " ", "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.6724037909628773`*^9, 3.672403797056397*^9}, {
   3.6724064318589687`*^9, 3.672406432232029*^9}, {3.672406606862803*^9, 
   3.6724066084054613`*^9}, 3.6724660581402187`*^9},
 CellLabel->"In[77]:=",ExpressionUUID->"3ec36e26-2dbf-4c78-8d3f-bcba9997f0f3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gm", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"13", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "5"}]], " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"18", "/", "5"}]], " ", "t"}]]}], ",", 
   RowBox[{"Gk", "\[Rule]", "1"}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{"Qo", " ", "t"}], "Vo"]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"3", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "5"}]], " ", "\[CapitalDelta]\[Gamma]"}], 
     SuperscriptBox["KIc", 
      RowBox[{"8", "/", "5"}]]]}], ",", 
   RowBox[{"Gmh", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"13", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "5"}]], " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"18", "/", "5"}]], " ", "t"}]]}], ",", 
   RowBox[{"Gmv", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", "2"], " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", "2"], " ", "t", " ", 
      "\[CapitalDelta]\[Gamma]"}]]}], ",", 
   RowBox[{"Gs", "\[Rule]", "1"}], ",", 
   RowBox[{"GvelV", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.6724037929730186`*^9, 3.672403797589807*^9}, 
   3.672404124172846*^9, 3.672404157509701*^9, 3.6724046350615788`*^9, 
   3.67240612911729*^9, 3.6724063340202723`*^9, {3.672406409646882*^9, 
   3.672406432686328*^9}, 3.672407751785379*^9, 3.672407898871233*^9, 
   3.67246598787674*^9, 3.672466058480567*^9, 3.6724683502186413`*^9, {
   3.67246854099185*^9, 3.672468546628808*^9}, 3.6724776710449677`*^9, 
   3.672477830411378*^9, 3.672478395292605*^9, 3.672478494712739*^9, 
   3.672483140029542*^9, 3.6793824082659197`*^9, 3.7725275265931597`*^9, 
   3.772528746630934*^9, 3.777560988480579*^9, 3.783255995716959*^9, 
   3.806919875307722*^9, 3.806923674233439*^9, 3.806934926965375*^9, 
   3.8396679748205357`*^9, 3.8424377532179937`*^9, 3.8424378033554487`*^9, 
   3.854278450672962*^9, 3.856261273700107*^9, 3.858417801045882*^9, 
   3.858417870560124*^9, 3.858755644955052*^9, 3.8587557400926332`*^9, 
   3.858829440269277*^9, 3.858919060399378*^9, 3.8596232924539957`*^9, 
   3.859623359815352*^9, 3.8596234506356583`*^9, 3.860656100813826*^9, 
   3.860727234847899*^9, 3.8607435929982758`*^9, 3.860828869866884*^9, 
   3.861156173668638*^9, 3.861180134501737*^9, 3.861186026516711*^9, 
   3.861193423719679*^9, 3.861193928447296*^9, {3.861194415151393*^9, 
   3.861194416482484*^9}, 3.8612491025037537`*^9, 3.868528996739208*^9, 
   3.868662181425559*^9, 3.869136963720779*^9, 3.8692218373932037`*^9, 
   3.869624278321889*^9, {3.870768940460795*^9, 3.870768956107855*^9}, {
   3.8872459091180553`*^9, 3.887245919381263*^9}},
 CellLabel->"Out[77]=",ExpressionUUID->"84ecd23d-9e38-4f55-9b96-d05845e452f8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Check", " ", "that", " ", 
   SubscriptBox["t", "mk"], " ", "remains", " ", "the", " ", "same"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.887071320407805*^9, 3.887071326676772*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"b17e25c6-b9f3-4b24-a7b2-d6a2fed7c5d6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t", "/.", "tmk"}], ")"}], "==", " ", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Gm", "/.", "Knumbers"}], ")"}], "\[Equal]", " ", "1"}], ",", 
      "t"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.8396679601850452`*^9, 3.8396679700792418`*^9}, {
  3.887071331582515*^9, 3.8870713426380796`*^9}},
 CellLabel->"In[79]:=",ExpressionUUID->"bb25a50a-b903-443b-bffc-6f1d0419d478"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["Ep", 
     RowBox[{"13", "/", "5"}]], " ", 
    SuperscriptBox["Vo", 
     RowBox[{"3", "/", "5"}]], " ", "\[Mu]p"}], 
   SuperscriptBox["KIc", 
    RowBox[{"18", "/", "5"}]]], "\[Equal]", 
  RowBox[{"{", 
   RowBox[{"t", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"13", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "5"}]], " ", "\[Mu]p"}], 
     SuperscriptBox["KIc", 
      RowBox[{"18", "/", "5"}]]]}], "}"}]}]], "Output",
 CellChangeTimes->{
  3.839667974866405*^9, 3.854278459040154*^9, 3.856261273768259*^9, 
   3.858417801096828*^9, 3.8584178706198683`*^9, 3.858755651671382*^9, 
   3.858755742085882*^9, 3.8588294403360853`*^9, 3.858919060485571*^9, 
   3.859623450694442*^9, 3.8606673924205637`*^9, 3.860727236514819*^9, 
   3.860743620806726*^9, 3.860828871715746*^9, 3.860828925695753*^9, 
   3.8611561747182817`*^9, 3.861180136443618*^9, 3.861193425718482*^9, 
   3.861193928470557*^9, {3.861194415175006*^9, 3.861194416508957*^9}, 
   3.8612491025113077`*^9, 3.868528996757666*^9, 3.868662181446843*^9, 
   3.869136963742375*^9, 3.869221837406645*^9, 3.869624278339555*^9, {
   3.870768940490559*^9, 3.870768956122073*^9}, {3.88724590914428*^9, 
   3.887245919426354*^9}},
 CellLabel->"Out[79]=",ExpressionUUID->"07155f80-b44b-48c6-a5dd-5371439857bf"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Transition from ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["M", 
    RowBox[{"[", "V", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "91f1917f-7b61-4f34-ae03-70e81f72a532"],
 " to ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["K", 
    RowBox[{"[", "V", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "36eb3027-19a3-4925-897a-0568f9ac61c1"],
 " - Zero buoyancy"
}], "Subsubsection",
 CellChangeTimes->{{3.8587556576888237`*^9, 3.858755677695462*^9}, {
  3.8596233893691483`*^9, 3.859623390957161*^9}, {3.88707091572075*^9, 
  3.887070919982699*^9}},ExpressionUUID->"915d8ccb-4625-430b-beb5-\
8ca502eed153"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"scales", " ", "at", " ", "the", " ", "transition"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"KScales", "/.", "tmk"}], " ", "//", "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.858755654630866*^9, 3.858755696761755*^9}, {
  3.887071371328854*^9, 3.8870713835029783`*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"f56d4cb4-6634-41be-91aa-175ca1216e18"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "5"}]]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "5"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]]}], 
     SuperscriptBox["Ep", 
      RowBox[{"4", "/", "5"}]]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"6", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]]}]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"18", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"13", "/", "5"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"16", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"11", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"16", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"11", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]], " ", "\[Mu]p"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.858755688357615*^9, 3.85875569718396*^9}, 
   3.858755745033227*^9, 3.858829444145988*^9, 3.858919068418066*^9, 
   3.859623457956422*^9, 3.860667405510969*^9, 3.86072723841459*^9, 
   3.8608288746577387`*^9, 3.8611561760405693`*^9, 3.861180137747998*^9, 
   3.861186028320097*^9, 3.861193427082309*^9, 3.86119392847817*^9, {
   3.861194415184211*^9, 3.861194416517775*^9}, 3.8612491025438557`*^9, {
   3.8685289884376497`*^9, 3.8685289967661743`*^9}, 3.868662181453082*^9, 
   3.86913696375158*^9, 3.869221837412635*^9, 3.8696242783477783`*^9, {
   3.870768940513988*^9, 3.870768956127653*^9}, {3.8872459091665*^9, 
   3.8872459194522676`*^9}},
 CellLabel->"Out[80]=",ExpressionUUID->"c9e027f3-b98d-432d-9409-57d68be8c3b8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "checking", " ", "if", " ", "the", " ", "transition", " ", "scales", " ", 
    "are", " ", "the", " ", "same"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MScales", " ", "/.", "tmk"}], " ", "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.858755698324522*^9, 3.858755705244131*^9}, {
  3.88707139227879*^9, 3.88707140226938*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"a172fbfe-325f-4415-9734-26d3dab39dd1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "5"}]]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "5"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]]}], 
     SuperscriptBox["Ep", 
      RowBox[{"4", "/", "5"}]]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"6", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]]}]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"18", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"13", "/", "5"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"16", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"11", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"16", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"11", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "5"}]], " ", "\[Mu]p"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.860828881533228*^9, 3.861156177151655*^9, 3.8611801394053497`*^9, 
   3.86118602892831*^9, 3.861193428304112*^9, 3.861193928502557*^9, {
   3.861194415207344*^9, 3.861194416553932*^9}, 3.861249102577569*^9, 
   3.8685289967846823`*^9, 3.868662181474197*^9, 3.869136963774499*^9, 
   3.869221837418447*^9, 3.869624278366171*^9, {3.870768940521367*^9, 
   3.870768956142015*^9}, {3.887245909174553*^9, 3.887245919462295*^9}},
 CellLabel->"Out[81]=",ExpressionUUID->"194e5d1f-49ed-4508-a986-66cd50e16240"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "get", " ", "the", " ", "dimensionless", " ", "numbers", " ", "at", " ", 
    "the", " ", "transition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DimensionlessGroups", "/.", "KScales"}], "/.", "tmk"}], " ", "//",
    "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.858755762303014*^9, 3.8587557715886602`*^9}, {
  3.887071406423814*^9, 3.887071429552133*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"f69d985b-97d8-4b28-abbb-e752d51aadda"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gm", "\[Rule]", "1"}], ",", 
   RowBox[{"Gk", "\[Rule]", "1"}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"13", "/", "5"}]], " ", "Qo", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"18", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}]]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"3", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "5"}]], " ", "\[CapitalDelta]\[Gamma]"}], 
     SuperscriptBox["KIc", 
      RowBox[{"8", "/", "5"}]]]}], ",", 
   RowBox[{"Gmh", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmv", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"8", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"3", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "5"}]], " ", "\[CapitalDelta]\[Gamma]"}]]}], ",", 
   RowBox[{"Gs", "\[Rule]", "1"}], ",", 
   RowBox[{"GvelV", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.858755764186976*^9, 3.858755772589633*^9}, 
   3.8588294442328787`*^9, 3.8589190684794188`*^9, 3.859623458030243*^9, 
   3.860667408419004*^9, 3.860727243618374*^9, 3.860828886388228*^9, 
   3.861156178186041*^9, 3.861180140280079*^9, 3.861186029482095*^9, 
   3.861193429435265*^9, 3.861193928509761*^9, {3.861194415215261*^9, 
   3.8611944165691633`*^9}, 3.861249102586557*^9, 3.8685289967916327`*^9, 
   3.868662181481366*^9, 3.86913696378192*^9, 3.8692218374326363`*^9, 
   3.869624278372058*^9, {3.87076894054739*^9, 3.87076895614769*^9}, {
   3.887245909195511*^9, 3.8872459194877872`*^9}},
 CellLabel->"Out[82]=",ExpressionUUID->"8acb8884-643b-4a47-aee7-51c969ce50f1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "check", " ", "the", " ", "dimensionless", " ", "numbers", " ", "at", " ", 
    "the", " ", "transition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DimensionlessGroups", "/.", "MScales"}], "/.", "tmk"}], " ", "//",
    "PowerExpand"}]}]], "Input",
 CellChangeTimes->{
  3.858755838735944*^9, {3.887071433391389*^9, 3.887071452014797*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"04cb543a-1a58-4dfb-843a-27e0e6c474f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gm", "\[Rule]", "1"}], ",", 
   RowBox[{"Gk", "\[Rule]", "1"}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"13", "/", "5"}]], " ", "Qo", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"18", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "5"}]]}]]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"3", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "5"}]], " ", "\[CapitalDelta]\[Gamma]"}], 
     SuperscriptBox["KIc", 
      RowBox[{"8", "/", "5"}]]]}], ",", 
   RowBox[{"Gmh", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmv", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"8", "/", "5"}]], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"3", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "5"}]], " ", "\[CapitalDelta]\[Gamma]"}]]}], ",", 
   RowBox[{"Gs", "\[Rule]", "1"}], ",", 
   RowBox[{"GvelV", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587558392243433`*^9, 3.858829444260742*^9, 3.8589190684875402`*^9, 
   3.8596234580404863`*^9, 3.860667409552731*^9, 3.860727250611405*^9, 
   3.8608288870749693`*^9, 3.861156178959818*^9, 3.8611801411833687`*^9, 
   3.861193928534237*^9, {3.861194415238866*^9, 3.861194416598569*^9}, 
   3.861249102618643*^9, 3.868528996810891*^9, 3.868662181502368*^9, 
   3.869136963804537*^9, 3.869221837446826*^9, 3.869624278391508*^9, {
   3.870768940558816*^9, 3.870768956162678*^9}, {3.887245909202641*^9, 
   3.887245919495726*^9}},
 CellLabel->"Out[83]=",ExpressionUUID->"c53fbdb9-c6e2-40c7-9aff-8a985b8913f4"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Scales at the onset of Buoyancy  ", "Subsection",
 CellChangeTimes->{{3.858755794633295*^9, 3.858755797998148*^9}, {
  3.859623395542186*^9, 3.859623409240288*^9}, {3.861180141875477*^9, 
  3.861180142844833*^9}},ExpressionUUID->"7e5db26d-7867-405c-956a-\
75c8caaed28c"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Scales", " ", "when", " ", "the", " ", "viscous", " ", 
   FormBox[
    RowBox[{
     SuperscriptBox["M", 
      RowBox[{"[", "V", "]"}]], " ", "-", " ", 
     RowBox[{"pulse", " ", "becomes", " ", "buoyant"}]}],
    TraditionalForm]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.85962342955241*^9, 3.859623431864551*^9}, {
  3.887071467304208*^9, 3.887071497117675*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"dad550b1-8045-4b9a-905d-d00f4c6ac407"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"scales", " ", "at", " ", "the", " ", "transition"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MScales", "/.", "tmb"}], " ", "//", "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.85875579962626*^9, 3.858755827970002*^9}, 
   3.8596257451305637`*^9, {3.887071514830324*^9, 3.887071515595087*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"a2cc4976-1f2a-4d5a-8c6d-65d3b519da98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]]}], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"1", "/", "4"}]]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]]}], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"1", "/", "4"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SqrtBox["Vo"], " ", 
      SqrtBox["\[CapitalDelta]\[Gamma]"]}], 
     SqrtBox["Ep"]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    RowBox[{
     SuperscriptBox["Ep", 
      RowBox[{"1", "/", "4"}]], " ", 
     SuperscriptBox["Vo", 
      RowBox[{"1", "/", "4"}]], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"3", "/", "4"}]]}]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Vo", 
       RowBox[{"7", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"9", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "4"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{"Vo", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", "2"]}], 
     RowBox[{"Ep", " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{"Vo", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", "2"]}], 
     RowBox[{"Ep", " ", "\[Mu]p"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.887245909247456*^9, 3.887245919557432*^9}},
 CellLabel->"Out[85]=",ExpressionUUID->"c68f867e-67b0-46ad-aac1-6cab9cbe5e88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "dimensionless", " ", "numbers", " ", "at", " ", "the", " ", 
    "transition"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"DimensionlessGroups", "/.", "MScales"}], "/.", "tmb"}], " ", "//",
    "PowerExpand"}]}]], "Input",
 CellChangeTimes->{
  3.858755865055356*^9, {3.8587564036289883`*^9, 3.858756403998928*^9}, {
   3.8870715175106487`*^9, 3.887071523710466*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"999b2f72-b489-4989-a411-af9aadf0e258"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gm", "\[Rule]", "1"}], ",", 
   RowBox[{"Gk", "\[Rule]", 
    FractionBox["KIc", 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"3", "/", "8"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "8"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"5", "/", "8"}]]}]]}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "4"}]], " ", "Qo", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["Vo", 
       RowBox[{"7", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"9", "/", "4"}]]}]]}], ",", 
   RowBox[{"Gb", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmh", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gs", "\[Rule]", "1"}], ",", 
   RowBox[{"GvelV", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.858755865583888*^9, 3.858756404642817*^9, 3.858919073579405*^9, {
   3.859623441794668*^9, 3.859623470246292*^9}, 3.859625751247924*^9, 
   3.860667454627962*^9, 3.860727253798437*^9, 3.860743629491294*^9, 
   3.860828889955373*^9, 3.8611561827440147`*^9, 3.8611801451909122`*^9, 
   3.86118603282689*^9, 3.86119392857576*^9, 3.861194416652727*^9, 
   3.8612491026865473`*^9, 3.868529002425213*^9, 3.868662185723957*^9, 
   3.8691369671788063`*^9, 3.8692218374725018`*^9, 3.869624278420951*^9, {
   3.870768940611549*^9, 3.870768956186369*^9}, {3.887245909253869*^9, 
   3.8872459195636044`*^9}},
 CellLabel->"Out[86]=",ExpressionUUID->"24db1e59-03c0-4d75-836f-b51534ea0569"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Relating", " ", "the", " ", "toughness", " ", "at", " ", "the", " ", 
    "transition", " ", "to", " ", "the", " ", "dimensionless", " ", 
    "buoyancy"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Gk", "/.", "DimensionlessGroups"}], "/.", "MScales"}], "/.", 
     "tmb"}], "//", "PowerExpand"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Gk", "/.", "DimensionlessGroups"}], "/.", "MScales"}], "/.",
         "tmb"}], "//", "PowerExpand"}], " ", ")"}], "\[Equal]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"Gb", "/.", "Knumbers"}], ")"}], 
      RowBox[{
       RowBox[{"-", "5"}], "/", "8"}]]}], "//", "PowerExpand"}]}]}]], "Input",\

 CellChangeTimes->{{3.86066759942765*^9, 3.860667653330885*^9}, {
  3.8870715626307287`*^9, 3.8870716014720697`*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"28b37027-6f63-4ebd-9590-85d2468bf997"],

Cell[BoxData[
 FractionBox["KIc", 
  RowBox[{
   SuperscriptBox["Ep", 
    RowBox[{"3", "/", "8"}]], " ", 
   SuperscriptBox["Vo", 
    RowBox[{"3", "/", "8"}]], " ", 
   SuperscriptBox["\[CapitalDelta]\[Gamma]", 
    RowBox[{"5", "/", "8"}]]}]]], "Output",
 CellChangeTimes->{{3.860667631090753*^9, 3.8606676536738462`*^9}, 
   3.860727254505458*^9, 3.860743630212195*^9, 3.86082889100377*^9, 
   3.8611561833444366`*^9, 3.86118014641542*^9, 3.861186033395624*^9, 
   3.861193928600862*^9, 3.861194416685423*^9, 3.861249102694819*^9, 
   3.8685290024459553`*^9, 3.868662185747751*^9, 3.869136970107493*^9, 
   3.869221837491774*^9, 3.86962427844695*^9, {3.870768940658977*^9, 
   3.870768956205821*^9}, {3.8872459092606907`*^9, 3.8872459196034203`*^9}},
 CellLabel->"Out[87]=",ExpressionUUID->"ee8dfe84-69e8-4af4-9e02-e9db5161dd91"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.860667631090753*^9, 3.8606676536738462`*^9}, 
   3.860727254505458*^9, 3.860743630212195*^9, 3.86082889100377*^9, 
   3.8611561833444366`*^9, 3.86118014641542*^9, 3.861186033395624*^9, 
   3.861193928600862*^9, 3.861194416685423*^9, 3.861249102694819*^9, 
   3.8685290024459553`*^9, 3.868662185747751*^9, 3.869136970107493*^9, 
   3.869221837491774*^9, 3.86962427844695*^9, {3.870768940658977*^9, 
   3.870768956205821*^9}, {3.8872459092606907`*^9, 3.8872459196042023`*^9}},
 CellLabel->"Out[88]=",ExpressionUUID->"4857d049-6424-45e0-be0e-e6d189e9fd4a"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Buoyancy - Elongated scalings", "Section",
 CellChangeTimes->{{3.858755292752894*^9, 3.85875530073918*^9}, {
  3.8611860342194643`*^9, 
  3.861186034945052*^9}},ExpressionUUID->"97e3b3ef-9c85-45f7-90a8-\
156818a8d806"],

Cell[CellGroupData[{

Cell["Toughness dominated buoyancy", "Subsection",
 CellChangeTimes->{{3.858755301361298*^9, 3.858755318650674*^9}, {
  3.8596234740543823`*^9, 3.85962347568577*^9}, {3.8596246314618053`*^9, 
  3.859624635874669*^9}},ExpressionUUID->"2cb2cc1d-d055-41ee-9409-\
2ab75906efbe"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["K", "^"], 
    RowBox[{"[", "V", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "622558a0-67d7-4735-8380-e1a0c1d6e82b"],
 " - Tail elongated scaling"
}], "Subsubsection",
 CellChangeTimes->{{3.859623966764525*^9, 3.8596239746636353`*^9}, {
  3.887071633017538*^9, 
  3.887071645360611*^9}},ExpressionUUID->"fd1fd992-2c1d-463f-a952-\
3a48f19cf3fd"],

Cell["\<\
We fix the breadth of the fracture to the buoyancy length scale (which is the \
characteristic scales at the onset of buoyancy in the toughness dominated \
regime).\
\>", "Text",
 CellChangeTimes->{{3.858865157732641*^9, 3.858865183414806*^9}, {
   3.859623486003992*^9, 3.859623511376896*^9}, {3.859624639086478*^9, 
   3.859624704086314*^9}, 3.861156189472329*^9, {3.8870716548765373`*^9, 
   3.887071663031353*^9}},ExpressionUUID->"a7c22649-af08-4476-90a4-\
8e8874519796"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Breadth", " ", "is", " ", "the", " ", "buoyancy", " ", "length", " ", 
    "scale"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"bset", "=", 
   RowBox[{"{", 
    RowBox[{"bstar", "->", 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "3"}]], 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.858844549126308*^9, 3.858844562430065*^9}, {
   3.8588449609248323`*^9, 3.858844984407064*^9}, {3.858845274044895*^9, 
   3.858845274329544*^9}, 3.8596239974808817`*^9, 3.860667696303348*^9, 
   3.860746627375259*^9, {3.887071677337482*^9, 3.887071685064086*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"5526b6e5-8f19-49ba-95c1-20f7f83ff9a2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"bstar", "\[Rule]", 
   FractionBox[
    SuperscriptBox["KIc", 
     RowBox[{"2", "/", "3"}]], 
    SuperscriptBox["\[CapitalDelta]\[Gamma]", 
     RowBox[{"2", "/", "3"}]]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.858844583064192*^9, 3.85884498507303*^9, 3.858845274801935*^9, 
   3.85891907948635*^9, {3.8596239980533657`*^9, 3.859624003198276*^9}, 
   3.860667697415216*^9, 3.860727259798431*^9, 3.860743658256599*^9, 
   3.860746627881625*^9, 3.860828952435491*^9, 3.861156190714966*^9, 
   3.8611801504120398`*^9, 3.86118603830416*^9, 3.8611934367297163`*^9, 
   3.861193933916238*^9, 3.861194421905925*^9, 3.8612491060225363`*^9, 
   3.861249516582163*^9, 3.868529005549209*^9, 3.868662189222135*^9, 
   3.869136973638839*^9, 3.869221841810197*^9, 3.869624280995965*^9, {
   3.8707689415647182`*^9, 3.870768958559149*^9}, {3.887245909280579*^9, 
   3.887245919648294*^9}},
 CellLabel->"Out[89]=",ExpressionUUID->"2e6da476-0f60-4306-b463-1e81a5b435f8"]
}, Open  ]],

Cell["\<\
Gv=Gmv=Ge=1 and Gq = Qo/(Vo/t) in that scaling  (i.e. storage, finite volume, \
elasticity  and vertical-viscosity as first order phenomena)  / no fluid lag
We also fix that the aspect ratio corresponds to the ratio of velocities \
(e.g. Gs= vx/vz and  vz~Lstar/t)\
\>", "Text",
 CellChangeTimes->{{3.672403687255912*^9, 3.67240369741529*^9}, {
  3.672406243749956*^9, 3.672406247995278*^9}, {3.672406310280857*^9, 
  3.672406312591201*^9}, {3.772531554610944*^9, 3.772531608037846*^9}, {
  3.77253167970325*^9, 3.772531682355589*^9}, {3.777564304028982*^9, 
  3.777564310276422*^9}, {3.88707093817679*^9, 3.8870709892389383`*^9}, {
  3.8870717243332863`*^9, 3.8870717804885607`*^9}, {3.887072260298339*^9, 
  3.88707226929814*^9}},ExpressionUUID->"a93d64fe-d2fb-4ad5-a9f4-\
e57412908582"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Kelongated", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"Join", "[", " ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", " ", 
               RowBox[{
                RowBox[{"#", " ", "/.", "DimensionlessGroups"}], "/.", 
                "bset"}], ")"}], "\[Equal]", "1"}], " ", "&"}], " ", "/@", 
            " ", 
            RowBox[{"{", " ", 
             RowBox[{"Ge", ",", "Gv", ",", 
              RowBox[{"Gs", "  ", 
               RowBox[{"vzstar", "/", "vxstar"}]}], " ", ",", " ", "Gmv", ",",
               "GvelV"}], "\[IndentingNewLine]", "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Gq", "\[Equal]", 
               RowBox[{"Qo", "/", 
                RowBox[{"(", 
                 RowBox[{"Vo", "/", "t"}], ")"}]}]}], ")"}], "/.", 
             "DimensionlessGroups"}], "}"}]}], "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
          "Pstar", ",", " ", "vxstar", ",", "vzstar", ",", "Lstar", ",", 
           "Qstar", ",", "Wstar"}], "}"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], " ", "//", "PowerExpand"}], " ", "//", 
     "FullSimplify"}], ",", "bset"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8588445362715483`*^9, 3.858844604774263*^9}, {
   3.8588448239521847`*^9, 3.858844841549242*^9}, 3.858844934029737*^9, {
   3.858844993576692*^9, 3.858845018763*^9}, 3.858845127777177*^9, {
   3.858845182650461*^9, 3.85884521808302*^9}, {3.858845258281481*^9, 
   3.858845271094495*^9}, {3.858845983743629*^9, 3.8588460072692947`*^9}, {
   3.85884641164132*^9, 3.858846412155635*^9}, {3.858846447486786*^9, 
   3.858846450248763*^9}, {3.859623232314109*^9, 3.859623240204007*^9}, {
   3.8606677258685427`*^9, 3.860667739733724*^9}, 3.860667989480751*^9, {
   3.8870716877845182`*^9, 3.8870717006711817`*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"26e99fb1-7f93-4340-bbae-ba4986da21d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     RowBox[{"Ep", " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"5", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], 
     RowBox[{"t", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"7", "/", "9"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"7", "/", "9"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox["Vo", "t"]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "9"}]]}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"2", "/", "3"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.858844584154757*^9, 3.858844607326393*^9}, 
   3.858844754360709*^9, {3.85884491956441*^9, 3.858844934627658*^9}, {
   3.85884499794806*^9, 3.858845019247591*^9}, {3.8588451838725986`*^9, 
   3.85884524197771*^9}, 3.8588452819324627`*^9, 3.858845340014948*^9, 
   3.858845487986902*^9, {3.858845984490611*^9, 3.8588460094503517`*^9}, {
   3.858846389141841*^9, 3.858846450726573*^9}, 3.8588464871096907`*^9, 
   3.8588472128439713`*^9, 3.858919080390147*^9, 3.859624004425234*^9, 
   3.8606677408168983`*^9, 3.860727260889636*^9, 3.860743659120173*^9, 
   3.860746628873654*^9, 3.8608289532951813`*^9, 3.861156194726495*^9, 
   3.861180151439993*^9, 3.861186039010023*^9, 3.861193436891078*^9, 
   3.861193934065496*^9, 3.8611944226060038`*^9, 3.861249106156337*^9, 
   3.86124951746247*^9, 3.868529006461298*^9, 3.8686621893463087`*^9, 
   3.869136974471533*^9, 3.869221841919322*^9, 3.869624281106028*^9, {
   3.870768941641489*^9, 3.870768958670808*^9}, {3.8872459094052563`*^9, 
   3.887245919722815*^9}},
 CellLabel->"Out[90]=",ExpressionUUID->"9c3afaa5-ce22-4440-bcb9-e9838aea1758"]
}, Open  ]],

Cell["\<\
The remaining (non-unity) dimensionless numbers provides the dimensionless \
numbers governing the solution of the problem\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 3.672403786033778*^9}, {
  3.78326850660122*^9, 3.78326850727908*^9}, {3.86118012621662*^9, 
  3.861180127117938*^9}},ExpressionUUID->"5b6b5467-ec11-4217-b54d-\
d72fbc59f6ae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"KelongatedGroups", "=", 
  RowBox[{
   RowBox[{"DimensionlessGroups", "/.", "Kelongated"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{
  3.858844763310615*^9, {3.858846405879012*^9, 3.858846408203876*^9}, 
   3.858846686322895*^9},
 CellLabel->"In[91]:=",ExpressionUUID->"cb21fd47-511c-4887-a202-12899c18d909"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gm", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"14", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{"Ep", " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gk", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"14", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{"Ep", " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{"Qo", " ", "t"}], "Vo"]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "9"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"11", "/", "9"}]]}], 
     RowBox[{"Ep", " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"2", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gmh", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"8", "/", "3"}]], 
     RowBox[{"Ep", " ", "Vo", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"5", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gmv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gs", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"10", "/", "9"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"13", "/", "9"}]]}]]}], ",", 
   RowBox[{"GvelV", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8588447637056*^9, 3.858845243705799*^9, 3.858845283934393*^9, {
   3.858846408695068*^9, 3.858846451840562*^9}, 3.858846644322031*^9, 
   3.858846686862563*^9, 3.8589190809582787`*^9, 3.859624011866749*^9, 
   3.860667804782658*^9, 3.860727262221974*^9, 3.8607436598659573`*^9, 
   3.8607466295793953`*^9, 3.8608289544434767`*^9, 3.861156196203773*^9, 
   3.861180152368186*^9, 3.861186039512457*^9, 3.861193436899858*^9, 
   3.8611939340734787`*^9, 3.861194423262294*^9, 3.8612491061664057`*^9, 
   3.861249519229115*^9, 3.868529007944008*^9, 3.868662189351708*^9, 
   3.869136977022832*^9, 3.869221841925324*^9, 3.8696242811128817`*^9, {
   3.870768941649033*^9, 3.8707689586771727`*^9}, {3.887245909411991*^9, 
   3.8872459197324343`*^9}},
 CellLabel->"Out[91]=",ExpressionUUID->"393e5189-eb82-4a17-81a8-9bcbcfa64a77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "We", " ", "get", " ", "the", " ", "horizontal", " ", "viscosity", " ", 
     "and", " ", "relate", " ", "it", " ", "to", " ", "the", " ", 
     "dimensionles", " ", "buoyancy", " ", "in", " ", "the", " ", 
     FormBox[
      SuperscriptBox["K", 
       RowBox[{"[", "V", "]"}]],
      TraditionalForm]}], "-", "Scaling"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Gmh", " ", "/.", " ", "KelongatedGroups"}], ")"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"Gmh", " ", "/.", " ", "KelongatedGroups"}], ")"}], "\[Equal]", 
    RowBox[{"(", 
     RowBox[{"Gb", "/.", "Knumbers"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.858846721199203*^9, 3.858846726383214*^9}, {
  3.88707181284307*^9, 3.887071896298257*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"70080bba-db7a-4dd5-9fcb-a072b2d2cfa4"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["KIc", 
   RowBox[{"8", "/", "3"}]], 
  RowBox[{"Ep", " ", "Vo", " ", 
   SuperscriptBox["\[CapitalDelta]\[Gamma]", 
    RowBox[{"5", "/", "3"}]]}]]], "Output",
 CellChangeTimes->{{3.858846715960841*^9, 3.858846726856213*^9}, 
   3.8589190816953278`*^9, 3.86066788165654*^9, 3.8607274337493563`*^9, 
   3.860743660678643*^9, 3.8607466304260807`*^9, 3.860828955550305*^9, 
   3.8611561974198933`*^9, 3.861180153020698*^9, 3.861186040104507*^9, 
   3.8611934369338903`*^9, 3.8611939341066227`*^9, 3.86119442523932*^9, 
   3.861249106195236*^9, 3.861249520152689*^9, 3.868529009747672*^9, 
   3.8686621893696012`*^9, 3.869136978123185*^9, 3.869221841938613*^9, 
   3.869624281130744*^9, {3.8707689416697197`*^9, 3.870768958692232*^9}, {
   3.887245909432909*^9, 3.887245919770866*^9}},
 CellLabel->"Out[92]=",ExpressionUUID->"63afb0af-666b-4cbf-89c7-71c4a5a4e1ce"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SuperscriptBox["KIc", 
    RowBox[{"8", "/", "3"}]], 
   RowBox[{"Ep", " ", "Vo", " ", 
    SuperscriptBox["\[CapitalDelta]\[Gamma]", 
     RowBox[{"5", "/", "3"}]]}]], "\[Equal]", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Ep", 
     RowBox[{"3", "/", "5"}]], " ", 
    SuperscriptBox["Vo", 
     RowBox[{"3", "/", "5"}]], " ", "\[CapitalDelta]\[Gamma]"}], 
   SuperscriptBox["KIc", 
    RowBox[{"8", "/", "5"}]]]}]], "Output",
 CellChangeTimes->{{3.858846715960841*^9, 3.858846726856213*^9}, 
   3.8589190816953278`*^9, 3.86066788165654*^9, 3.8607274337493563`*^9, 
   3.860743660678643*^9, 3.8607466304260807`*^9, 3.860828955550305*^9, 
   3.8611561974198933`*^9, 3.861180153020698*^9, 3.861186040104507*^9, 
   3.8611934369338903`*^9, 3.8611939341066227`*^9, 3.86119442523932*^9, 
   3.861249106195236*^9, 3.861249520152689*^9, 3.868529009747672*^9, 
   3.8686621893696012`*^9, 3.869136978123185*^9, 3.869221841938613*^9, 
   3.869624281130744*^9, {3.8707689416697197`*^9, 3.870768958692232*^9}, {
   3.887245909432909*^9, 3.887245919771696*^9}},
 CellLabel->"Out[93]=",ExpressionUUID->"9d608ead-6c6e-4f4d-b065-9867ca8ddc46"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["K", "^"], 
    RowBox[{"head", ",", 
     RowBox[{"[", "V", "]"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "759a0b46-71d3-4a30-a58e-49be032a197d"],
 " - Toughness - head scaling (bstar  ~ Lstar)"
}], "Subsubsection",
 CellChangeTimes->{{3.839584861666774*^9, 3.8395848847991257`*^9}, {
   3.839584974735856*^9, 3.839584985613241*^9}, 3.8395851264335537`*^9, {
   3.8395856470883303`*^9, 3.839585650631641*^9}, {3.859623915061808*^9, 
   3.859623915660859*^9}, 3.859623964010624*^9, {3.860746631982893*^9, 
   3.8607466326621437`*^9}, {3.887071908331661*^9, 3.887071912888723*^9}, 
   3.887072165942966*^9},ExpressionUUID->"e627e254-3f8a-4a2f-a382-\
27e5f43b6e12"],

Cell[BoxData[
 StyleBox[
  RowBox[{
  "Note", " ", "that", " ", "this", " ", "head", " ", "scales", " ", "are", 
   " ", "strictly", " ", "the", " ", "toughness", " ", "scaling", " ", "at", 
   " ", "the", " ", "transition", " ", "time", " ", "scale", " ", 
   FormBox[
    SubscriptBox["t", 
     RowBox[{"k", 
      OverscriptBox["k", "^"]}]],
    TraditionalForm], " ", "to", " ", "buoyancy", " ", "and", " ", "also", 
   " ", "are", " ", "the", " ", "same", " ", "as", " ", "in", " ", "the", " ",
    "continuous", " ", "release", " ", 
   RowBox[{"case", "."}]}], "Text"]], "Text",
 CellChangeTimes->{{3.8596247069095716`*^9, 3.8596247210875387`*^9}, {
  3.8870719233384943`*^9, 3.887071937706708*^9}, {3.887071971457554*^9, 
  3.8870719745523777`*^9}},ExpressionUUID->"4276bf36-0cce-447b-9add-\
386aaa7ff2b0"],

Cell["Ge=Gb= Gk=Gs=1 and Gq = Qo/(Vo/t) in that scaling   ", "Text",
 CellChangeTimes->{{3.672403687255912*^9, 3.67240369741529*^9}, {
   3.672406243749956*^9, 3.672406247995278*^9}, {3.672406310280857*^9, 
   3.672406312591201*^9}, 3.672406404834804*^9, {3.772531653422431*^9, 
   3.772531686194335*^9}, {3.7775643152279577`*^9, 3.777564317675724*^9}, {
   3.8395848996598673`*^9, 3.839584908979759*^9}, {3.8395856519752197`*^9, 
   3.839585652327642*^9}, {3.8870719683710127`*^9, 3.887071968680587*^9}, {
   3.8870720662017193`*^9, 
   3.887072102545032*^9}},ExpressionUUID->"0d1b0f31-a100-44e8-99d5-\
da86cb432c12"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HeadkScales", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"Join", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", " ", 
           RowBox[{"#", " ", "/.", "aux"}], ")"}], "\[Equal]", "1"}], " ", 
         "&"}], " ", "/@", " ", 
        RowBox[{"{", 
         RowBox[{"Ge", ",", "Gb", ",", "Gk", ",", "Gs"}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Gq", "\[Equal]", 
           RowBox[{"Qo", "/", 
            RowBox[{"(", 
             RowBox[{"Vo", "/", "t"}], ")"}]}]}], ")"}], "/.", 
         "DimensionlessGroups"}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "Lstar", ",", "Wstar", ",", "Pstar", ",", "Qstar", ",", "bstar"}], 
      "}"}]}], "]"}], " ", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8607436998597918`*^9, 3.860743769026129*^9}, {
   3.8870720507933817`*^9, 3.8870720583473587`*^9}, 3.887072088634527*^9},
 CellLabel->"In[94]:=",ExpressionUUID->"d2ea2258-f506-43d5-be53-df6f05f61a39"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"2", "/", "3"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"4", "/", "3"}]], 
     RowBox[{"Ep", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    RowBox[{
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"1", "/", "3"}]]}]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox["Vo", "t"]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"2", "/", "3"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.672403657468069*^9, 3.672403669527316*^9}, 
   3.672403738816983*^9, {3.672404098390545*^9, 3.672404115676429*^9}, 
   3.67240415499277*^9, {3.672404303178442*^9, 3.6724043157026987`*^9}, 
   3.672404372376451*^9, {3.672404607237997*^9, 3.6724046315956593`*^9}, 
   3.672406127022051*^9, {3.672406324074513*^9, 3.6724063321792517`*^9}, {
   3.672406407889263*^9, 3.672406426952512*^9}, 3.6724077501594954`*^9, 
   3.6724078974897137`*^9, 3.672465987760776*^9, 3.672466055242416*^9, 
   3.6724683501627197`*^9, {3.672468540942375*^9, 3.6724685465760098`*^9}, 
   3.672477670991399*^9, 3.672477830373823*^9, 3.6724783952450867`*^9, 
   3.6724784946677322`*^9, 3.672483139972924*^9, 3.6793824082429657`*^9, 
   3.77252752653059*^9, 3.77252874491532*^9, 3.777560985753244*^9, 
   3.7832559957034883`*^9, 3.8069198734677143`*^9, {3.80691997631779*^9, 
   3.806919983470696*^9}, {3.806920062645522*^9, 3.806920071865707*^9}, 
   3.80692367430243*^9, 3.806923717760538*^9, 3.8069349270471783`*^9, 
   3.839584935525642*^9, 3.839584966246337*^9, 3.839585657827276*^9, 
   3.839585806951165*^9, 3.839666426330853*^9, 3.839667999825431*^9, 
   3.854190698480776*^9, 3.854278587307022*^9, 3.854278640769505*^9, 
   3.856261278057572*^9, {3.858417852384104*^9, 3.858417873859489*^9}, 
   3.858417908209588*^9, 3.85877685744596*^9, 3.858829927242076*^9, 
   3.858833699892565*^9, {3.858833963634923*^9, 3.858833982459895*^9}, 
   3.858834789398177*^9, {3.858842676490945*^9, 3.8588426868217173`*^9}, 
   3.858842992305436*^9, 3.858843336216694*^9, 3.8588436116620007`*^9, 
   3.8596244714889097`*^9, 3.8596245179620867`*^9, 3.860667922835663*^9, 
   3.860727446704287*^9, 3.860743679295333*^9, {3.860743729550459*^9, 
   3.860743776412217*^9}, 3.86074562294495*^9, 3.860746636096978*^9, 
   3.8608289712679167`*^9, 3.86115620202365*^9, 3.861180155706443*^9, 
   3.86118604318506*^9, 3.8611934456173983`*^9, 3.8611939378517103`*^9, 
   3.861194429128571*^9, 3.861249106271468*^9, 3.861249523107386*^9, 
   3.868529013437454*^9, 3.868662189433634*^9, 3.869136982577794*^9, 
   3.86922184200242*^9, 3.869624281199531*^9, {3.8707689418977737`*^9, 
   3.870768958757174*^9}, {3.887245909539454*^9, 3.8872459198050203`*^9}},
 CellLabel->"Out[94]=",ExpressionUUID->"ed932f0c-a8bf-4a5b-84f1-092754b8b3c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Deriving", " ", "the", " ", "head", " ", "and", " ", "tail", " ", 
    "volume"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Vkhead", " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["Lstar", "2"], " ", "Wstar"}], " ", "//.", 
     "HeadkScales"}]}], "\[IndentingNewLine]", 
   RowBox[{"Vktail", " ", "=", " ", 
    RowBox[{"Vo", " ", "-", " ", "Vkhead", " "}]}]}]}]], "Input",
 CellChangeTimes->{{3.839585273630432*^9, 3.839585296743086*^9}, {
  3.839585661834203*^9, 3.83958566267203*^9}, {3.854278590315559*^9, 
  3.8542785935467978`*^9}, {3.88707200015582*^9, 3.88707200685034*^9}, {
  3.887072126563623*^9, 3.887072134525991*^9}, {3.8870725009793787`*^9, 
  3.887072502427062*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"89f12a5c-f4ca-4e2a-bf4e-14c95aedd71e"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["KIc", 
   RowBox[{"8", "/", "3"}]], 
  RowBox[{"Ep", " ", 
   SuperscriptBox["\[CapitalDelta]\[Gamma]", 
    RowBox[{"5", "/", "3"}]]}]]], "Output",
 CellChangeTimes->{
  3.8395852970897827`*^9, 3.839585663229546*^9, 3.839585807921587*^9, 
   3.839666427363884*^9, 3.839667999868332*^9, 3.8541906985304613`*^9, 
   3.854278593915484*^9, 3.854278642636602*^9, 3.8562612780648403`*^9, {
   3.858417852454755*^9, 3.8584178739044313`*^9}, 3.858417908216283*^9, 
   3.858776859785201*^9, 3.858829928469836*^9, 3.858842683727437*^9, 
   3.858842932667961*^9, 3.8588433377945223`*^9, 3.859624474756481*^9, 
   3.85962451950352*^9, 3.860667927009501*^9, 3.8607274473317337`*^9, 
   3.8607437875077467`*^9, 3.860745629914771*^9, 3.8607466367134037`*^9, 
   3.860828972680896*^9, 3.861156203046764*^9, 3.861180156612718*^9, 
   3.861186043689788*^9, 3.861193446526353*^9, 3.861193937858902*^9, 
   3.8611944299057493`*^9, 3.861249106279316*^9, 3.86124952390711*^9, 
   3.868529015044909*^9, 3.868662189438507*^9, 3.8691369836025343`*^9, 
   3.869221842007978*^9, 3.869624281205244*^9, {3.870768941909161*^9, 
   3.870768958763114*^9}, {3.887245909546855*^9, 3.887245919838277*^9}},
 CellLabel->"Out[95]=",ExpressionUUID->"b5bb67fe-145e-49f8-a22a-7851062aee5d"],

Cell[BoxData[
 RowBox[{"Vo", "-", 
  FractionBox[
   SuperscriptBox["KIc", 
    RowBox[{"8", "/", "3"}]], 
   RowBox[{"Ep", " ", 
    SuperscriptBox["\[CapitalDelta]\[Gamma]", 
     RowBox[{"5", "/", "3"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.8395852970897827`*^9, 3.839585663229546*^9, 3.839585807921587*^9, 
   3.839666427363884*^9, 3.839667999868332*^9, 3.8541906985304613`*^9, 
   3.854278593915484*^9, 3.854278642636602*^9, 3.8562612780648403`*^9, {
   3.858417852454755*^9, 3.8584178739044313`*^9}, 3.858417908216283*^9, 
   3.858776859785201*^9, 3.858829928469836*^9, 3.858842683727437*^9, 
   3.858842932667961*^9, 3.8588433377945223`*^9, 3.859624474756481*^9, 
   3.85962451950352*^9, 3.860667927009501*^9, 3.8607274473317337`*^9, 
   3.8607437875077467`*^9, 3.860745629914771*^9, 3.8607466367134037`*^9, 
   3.860828972680896*^9, 3.861156203046764*^9, 3.861180156612718*^9, 
   3.861186043689788*^9, 3.861193446526353*^9, 3.861193937858902*^9, 
   3.8611944299057493`*^9, 3.861249106279316*^9, 3.86124952390711*^9, 
   3.868529015044909*^9, 3.868662189438507*^9, 3.8691369836025343`*^9, 
   3.869221842007978*^9, 3.869624281205244*^9, {3.870768941909161*^9, 
   3.870768958763114*^9}, {3.887245909546855*^9, 3.8872459198391123`*^9}},
 CellLabel->"Out[96]=",ExpressionUUID->"03856b4c-ddfe-4220-a18e-3b7dff05ad88"]
}, Open  ]],

Cell["\<\
The remaining (non-unity) dimensionless numbers provides the dimensionless \
numbers governing the solution of the problem\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 3.672403786033778*^9}, {
  3.78326850660122*^9, 3.78326850727908*^9}, {3.86118012621662*^9, 
  3.861180127117938*^9}},ExpressionUUID->"e1f15ed4-a2cf-4214-9f33-\
4cc0a9864af8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Khnumbers", "=", 
  RowBox[{
   RowBox[{"DimensionlessGroups", "//.", "HeadkScales"}], " ", "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.83958500273477*^9, 3.839585005127421*^9}, {
   3.839585814228545*^9, 3.839585820860989*^9}, {3.839668070504938*^9, 
   3.8396680740860023`*^9}, 3.8542786049238377`*^9},
 CellLabel->"In[97]:=",ExpressionUUID->"cb81f80f-1753-40e5-bbfe-0ac5cb706798"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", 
    FractionBox[
     RowBox[{"Ep", " ", "Vo", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"5", "/", "3"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"8", "/", "3"}]]]}], ",", 
   RowBox[{"Gm", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", "3"], " ", "Vo", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]], " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"14", "/", "3"}]], " ", "t"}]]}], ",", 
   RowBox[{"Gk", "\[Rule]", "1"}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{"Qo", " ", "t"}], "Vo"]}], ",", 
   RowBox[{"Gb", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmh", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", "2"], " ", "vxstar", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gmv", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", "2"], " ", "vzstar", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gs", "\[Rule]", "1"}], ",", 
   RowBox[{"GvelV", "\[Rule]", 
    FractionBox[
     RowBox[{"t", " ", "vzstar", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.86913698598914*^9, 3.869221842022531*^9, 3.869624281224101*^9, {
   3.8707689419370604`*^9, 3.870768958777398*^9}, {3.887245909570058*^9, 
   3.887245919847069*^9}},
 CellLabel->"Out[97]=",ExpressionUUID->"abd0519a-9654-49a1-b5f6-1e68dd72564d"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Viscosity dominated buoyancy", "Subsection",
 CellChangeTimes->{{3.858755301361298*^9, 3.858755318650674*^9}, {
  3.8587761995631723`*^9, 3.858776201385442*^9}, {3.85962474998917*^9, 
  3.859624750234804*^9}, {3.8611801589325647`*^9, 
  3.861180159822345*^9}},ExpressionUUID->"d6b5b8d5-d8d7-46be-8180-\
c44e8a65721a"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["M", "^"], 
    RowBox[{"[", "V", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "bc5b61b6-7973-427c-aa40-dbf2d0f877bb"],
 " -Tail / Source region scaling"
}], "Subsubsection",
 CellChangeTimes->{{3.859624759320595*^9, 3.859624773324108*^9}, {
  3.8870721919603863`*^9, 
  3.887072196782042*^9}},ExpressionUUID->"c3d3b48d-d0a5-492b-9b8f-\
3c7564274c27"],

Cell["\<\
This scaling is strictly similar to the Lister (1990b) scaling. \
Ge=Gv=Gmv=Gmh=1,   Gs= vx/vz,    vz~Lstar/t\
\>", "Text",
 CellChangeTimes->{{3.859624814513838*^9, 3.859624878975244*^9}, 
   3.887072232802318*^9},ExpressionUUID->"7af19012-07ac-4dce-8486-\
d760eab85d4c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Melongated", "=", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", " ", 
           RowBox[{"#", " ", "/.", "DimensionlessGroups"}], ")"}], "\[Equal]",
           "1"}], " ", "&"}], " ", "/@", " ", 
        RowBox[{"{", " ", 
         RowBox[{"Ge", ",", "Gmv", ",", "Gmh", ",", 
          RowBox[{"Gs", "   ", 
           RowBox[{"vzstar", "/", "vxstar"}]}], " ", ",", " ", "Gv", ",", 
          "GvelV"}], "\[IndentingNewLine]", "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Gq", "\[Equal]", 
           RowBox[{"Qo", "/", 
            RowBox[{"(", 
             RowBox[{"Vo", "/", "t"}], ")"}]}]}], ")"}], "/.", 
         "DimensionlessGroups"}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "Pstar", ",", " ", "vxstar", ",", "vzstar", ",", "Lstar", ",", "Qstar", 
       ",", "Wstar", ",", "bstar"}], "}"}]}], "]"}], " ", "[", 
   RowBox[{"[", "4", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858769046109249*^9, 3.858769056640641*^9}, {
   3.858769157538121*^9, 3.858769164436137*^9}, {3.85877621955331*^9, 
   3.858776300203027*^9}, {3.8596232140817537`*^9, 3.859623217412119*^9}, {
   3.859624782189176*^9, 3.8596248010831633`*^9}, 3.859625412275505*^9, {
   3.860668009227661*^9, 3.860668051709929*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"467e2c0f-8ac0-458e-9588-b1eb7b148308"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}], 
     SuperscriptBox["t", 
      RowBox[{"1", "/", "3"}]]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]]}], 
     RowBox[{"t", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "4"}]]}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SqrtBox["Vo"], " ", 
      SqrtBox["\[CapitalDelta]\[Gamma]"]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "6"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SqrtBox["Vo"], " ", 
      SqrtBox["\[CapitalDelta]\[Gamma]"]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "6"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox["Vo", "t"]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "12"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "4"}]]}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]]}], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"1", "/", "4"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.858769165125598*^9, {3.858769211504148*^9, 3.8587692147169*^9}, 
   3.858769461024029*^9, {3.858776224563163*^9, 3.858776307708559*^9}, 
   3.85877660562254*^9, {3.858830807816169*^9, 3.8588308280616302`*^9}, {
   3.858865199683423*^9, 3.8588652084534893`*^9}, 3.858919092432768*^9, {
   3.8596247779069*^9, 3.85962480129198*^9}, 3.8596248809388933`*^9, 
   3.8596254203152237`*^9, {3.8606680322142878`*^9, 3.860668052226815*^9}, 
   3.860668094882593*^9, 3.860743189280388*^9, 3.860743942004777*^9, 
   3.860743975541212*^9, 3.8607456495501623`*^9, 3.860746643260685*^9, 
   3.860828984071612*^9, 3.861156229249304*^9, 3.861180161881269*^9, 
   3.861186049004736*^9, 3.861193455943364*^9, 3.861193945016158*^9, 
   3.8611944342418737`*^9, 3.861249106425724*^9, 3.8612495296577578`*^9, 
   3.8685290207664967`*^9, 3.8686621914261503`*^9, 3.869136915529517*^9, 
   3.869136995357245*^9, 3.869221845391553*^9, {3.869624258588187*^9, 
   3.869624286503068*^9}, {3.870768943417749*^9, 3.870768961130457*^9}, {
   3.887245909666725*^9, 3.887245919946083*^9}},
 CellLabel->"Out[98]=",ExpressionUUID->"322dc93b-7a3f-41e6-a9de-f0b5f6db5884"]
}, Open  ]],

Cell["\<\
The remaining (non-unity) dimensionless numbers provides the dimensionless \
numbers governing the solution of the problem\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 3.672403786033778*^9}, {
  3.78326850660122*^9, 3.78326850727908*^9}, {3.86118012621662*^9, 
  3.861180127117938*^9}},ExpressionUUID->"a7452d8f-5116-4054-8852-\
7bb0f958becd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MelongatedGroups", "=", 
  RowBox[{
   RowBox[{"DimensionlessGroups", "/.", "Melongated"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.858769465014312*^9, 3.858769470618102*^9}, {
   3.858769612838788*^9, 3.8587696167317533`*^9}, {3.8587763243303337`*^9, 
   3.858776326050528*^9}, 3.859625415576453*^9},
 CellLabel->"In[99]:=",ExpressionUUID->"a3b86557-2875-4bc5-aaf1-e6226cc9326b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gm", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "12"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gk", "\[Rule]", 
    FractionBox[
     RowBox[{"KIc", " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"19", "/", "24"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "8"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{"Qo", " ", "t"}], "Vo"]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SqrtBox["Vo"], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "6"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"2", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gmh", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gs", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "12"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "4"}]]}]]}], ",", 
   RowBox[{"GvelV", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587694711904*^9, 3.8587696171201487`*^9, 3.858776326802511*^9, 
   3.858776466158087*^9, {3.858776599757185*^9, 3.8587766066972227`*^9}, {
   3.85883080785837*^9, 3.858830829663897*^9}, {3.8588652151472607`*^9, 
   3.858865217638895*^9}, 3.858866052140752*^9, 3.8589190932811413`*^9, 
   3.859624804644741*^9, 3.859624881758153*^9, 3.8596254210308037`*^9, 
   3.8606680967981043`*^9, 3.860743195561616*^9, 3.860743968488106*^9, 
   3.86074403705613*^9, 3.8607456527413397`*^9, 3.860746644123886*^9, 
   3.860828984884768*^9, 3.861156230424399*^9, 3.861180162813637*^9, 
   3.861186049535434*^9, 3.861193457129602*^9, 3.8611939451930113`*^9, 
   3.861194435041634*^9, 3.8612491064350433`*^9, 3.8612495312378197`*^9, 
   3.8685290241984453`*^9, 3.868662191458631*^9, 3.869136916240571*^9, 
   3.869137006381151*^9, 3.869221845459717*^9, {3.869624258677182*^9, 
   3.869624286537315*^9}, {3.8707689434402237`*^9, 3.870768961185878*^9}, {
   3.88724590967325*^9, 3.887245919952859*^9}},
 CellLabel->"Out[99]=",ExpressionUUID->"4fc6256e-23a5-4cc6-885a-74ee6c32467a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "The", " ", "dimensionless", " ", "toughness", " ", "increases", " ", 
    "with", " ", "time"}], " ", "-", " ", 
   RowBox[{"for", " ", "horizontal", " ", "growth"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.859624883215942*^9, 3.859624910802237*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"5f4f54aa-43c9-4f13-923f-19b178401b81"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "timescale", " ", "for", " ", "the", " ", "horizontal", " ", "toughness", 
   " ", "to", " ", "be", " ", "of", " ", "order", " ", "1"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.859624914356731*^9, 3.859624927446308*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"993551e4-2062-4e8d-ac84-1946c87ca68f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tmxkx", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Gk", "/.", "MelongatedGroups"}], ")"}], "==", "1"}], ",", 
       "t"}], "]"}], "//", "PowerExpand"}], " ", ")"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t", "/.", "tmb"}], ")"}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"Gb", "/.", "Knumbers"}], ")"}], 
    RowBox[{"15", "/", "8"}]]}], "//", "PowerExpand"}]}], "Input",
 CellChangeTimes->{{3.8588310943485413`*^9, 3.858831148509613*^9}, {
  3.859625417939992*^9, 3.85962543617417*^9}, {3.8607432440258923`*^9, 
  3.860743256152416*^9}, {3.86923502210441*^9, 3.869235143819694*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"86769a93-b729-465f-9442-a4aff9c25aef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["Ep", 
      RowBox[{"19", "/", "8"}]], " ", 
     SuperscriptBox["Vo", 
      RowBox[{"3", "/", "8"}]], " ", "\[Mu]p"}], 
    RowBox[{
     SuperscriptBox["KIc", "3"], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"3", "/", "8"}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.868662191521544*^9, 3.869136922102037*^9, 3.869137039339484*^9, 
   3.869221845487382*^9, 3.869235023973221*^9, {3.8692350708574944`*^9, 
   3.869235144398185*^9}, {3.869624258780983*^9, 3.8696242865641403`*^9}, {
   3.8707689434976463`*^9, 3.870768961225914*^9}, {3.887245909709209*^9, 
   3.88724592002391*^9}},
 CellLabel->
  "Out[102]=",ExpressionUUID->"ed0a2980-6ca3-4dea-a73b-2c84c3f2c087"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Ep", 
    RowBox[{"19", "/", "8"}]], " ", 
   SuperscriptBox["Vo", 
    RowBox[{"3", "/", "8"}]], " ", "\[Mu]p"}], 
  RowBox[{
   SuperscriptBox["KIc", "3"], " ", 
   SuperscriptBox["\[CapitalDelta]\[Gamma]", 
    RowBox[{"3", "/", "8"}]]}]]], "Output",
 CellChangeTimes->{
  3.868662191521544*^9, 3.869136922102037*^9, 3.869137039339484*^9, 
   3.869221845487382*^9, 3.869235023973221*^9, {3.8692350708574944`*^9, 
   3.869235144398185*^9}, {3.869624258780983*^9, 3.8696242865641403`*^9}, {
   3.8707689434976463`*^9, 3.870768961225914*^9}, {3.887245909709209*^9, 
   3.887245920025063*^9}},
 CellLabel->
  "Out[103]=",ExpressionUUID->"b73d15dc-45b5-4367-abd4-e141a7048e5b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Scales", " ", "at", " ", "the", " ", "transition", " ", "of", " ", "the", 
    " ", "tail"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Melongated", "/.", "tmxkx"}], "//", "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.868529027951659*^9, 3.86852904195999*^9}, {
  3.887072326835003*^9, 3.887072337634779*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"44ab58ed-afd1-4c2d-8b11-ea23f4993684"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     RowBox[{"KIc", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "8"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "8"}]]}]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", "3"], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"17", "/", "8"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "8"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", "2"], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"7", "/", "4"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "8"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"5", "/", "8"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "8"}]]}], "KIc"]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", "3"], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"5", "/", "8"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"19", "/", "8"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{"KIc", " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"7", "/", "8"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "8"}]]}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]]}], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"1", "/", "4"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.868529036811864*^9, 3.8685290422072268`*^9}, 
   3.8686621915286417`*^9, 3.869136923755327*^9, 3.8691370411049213`*^9, 
   3.869221845493354*^9, {3.8696242588230667`*^9, 3.869624286589972*^9}, {
   3.870768943541566*^9, 3.870768961255225*^9}, {3.8872459097398443`*^9, 
   3.8872459200689917`*^9}},
 CellLabel->
  "Out[104]=",ExpressionUUID->"51dab00f-a976-47e5-aba5-8921a6a58472"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "the", " ", "transition", " ", "scale", " ", "for", " ", "pulse", " ", 
   "radial", " ", "viscosity", " ", "to", " ", "buoyant", " ", "is", " ", 
   "the", " ", "same", " ", "as", " ", "the", " ", "scale", " ", "for", " ", 
   "the", " ", "horizontal", " ", "viscosity", " ", "to", " ", "dissapear"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.861156265340398*^9, 3.86115629137862*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"c3172584-e88a-4c02-9ef9-432a191af0bd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"bstar", "/.", "Melongated"}], "/.", "tmxkx"}], "//", 
    "PowerExpand"}], " ", ")"}], "\[Equal]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"bstar", "/.", "MScales"}], "/.", "tmb"}], "//", "PowerExpand"}],
    ")"}]}]], "Input",
 CellChangeTimes->{{3.8607462507791758`*^9, 3.8607462603170967`*^9}, {
  3.860746305934853*^9, 3.86074634486767*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"415a330a-53fd-472b-a557-2d1066762a8a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.86074625558442*^9, 3.860746260742691*^9}, {
   3.860746326694661*^9, 3.860746345849388*^9}, 3.860746647756289*^9, 
   3.86082899041992*^9, 3.861156235194606*^9, 3.8611801666945543`*^9, 
   3.861186053937262*^9, 3.8611861380055513`*^9, 3.8611934619937487`*^9, 
   3.8611939452643347`*^9, 3.861194442772525*^9, 3.861249106532836*^9, 
   3.86124953452693*^9, 3.868529076354933*^9, 3.868662191553595*^9, 
   3.869136929504521*^9, 3.869137044784284*^9, 3.869221845511837*^9, {
   3.869624258867093*^9, 3.869624286611343*^9}, {3.870768943592005*^9, 
   3.870768961277296*^9}, {3.8872459097672243`*^9, 3.887245920108048*^9}},
 CellLabel->
  "Out[106]=",ExpressionUUID->"bf0239ba-9727-4ac0-9f0e-8ca73adbae2c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["M", "^"], 
    RowBox[{"head", ",", 
     RowBox[{"[", "V", "]"}]}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "1c8a1e2a-dea2-489d-9b88-bc27c7a4805c"],
 " - Viscosity - head scaling"
}], "Subsubsection",
 CellChangeTimes->{{3.839584861666774*^9, 3.8395848847991257`*^9}, {
   3.839584974735856*^9, 3.839584985613241*^9}, 3.8395851264335537`*^9, {
   3.887072208855023*^9, 
   3.8870722232514343`*^9}},ExpressionUUID->"e17d5e2b-6733-4987-8dbb-\
2975278e62c7"],

Cell["\<\
We set the characteristic vertical flow velocity in that scaling to be equal \
to the elongated (tail) viscous scaling \
\>", "Text",
 CellChangeTimes->{{3.672403687255912*^9, 3.67240369741529*^9}, {
   3.672406243749956*^9, 3.672406247995278*^9}, {3.672406310280857*^9, 
   3.672406312591201*^9}, 3.672406404834804*^9, {3.772531653422431*^9, 
   3.772531686194335*^9}, {3.7775643152279577`*^9, 3.777564317675724*^9}, {
   3.8395848996598673`*^9, 3.839584908979759*^9}, {3.859625074325778*^9, 
   3.859625117564455*^9}, {3.859625464382572*^9, 3.8596254644315367`*^9}, {
   3.887072438969*^9, 
   3.887072440763072*^9}},ExpressionUUID->"507d700b-2ec1-4a17-97ce-\
cc80c9bc1901"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aux", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{"DimensionlessGroups", ",", 
    RowBox[{"{", 
     RowBox[{"Gqhead", "->", " ", 
      RowBox[{"bstar", " ", "Wstar", " ", 
       RowBox[{
        RowBox[{"(", "  ", 
         RowBox[{
          RowBox[{"(", "  ", "vzstar", ")"}], "/.", "Melongated"}], ")"}], 
        " ", "/", "Qstar"}]}]}], "  ", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8588338404251747`*^9, 3.8588339141684437`*^9}, {
   3.858834683984518*^9, 3.858834686964871*^9}, {3.858842697880095*^9, 
   3.8588427086920023`*^9}, {3.858843154090629*^9, 3.858843161160417*^9}, {
   3.858843224202639*^9, 3.858843232285664*^9}, {3.8590074666549063`*^9, 
   3.859007467960573*^9}, {3.859007527960826*^9, 3.8590075424406033`*^9}, {
   3.8590075730167217`*^9, 3.859007610432612*^9}, {3.859013769137916*^9, 
   3.859013770379259*^9}, {3.8596251220239477`*^9, 3.8596251224308662`*^9}, 
   3.860668190452582*^9},
 CellLabel->
  "In[107]:=",ExpressionUUID->"44d87571-0e97-411d-914a-199f20a097ac"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", 
    FractionBox[
     RowBox[{"Ep", " ", "Wstar"}], 
     RowBox[{"bstar", " ", "Pstar"}]]}], ",", 
   RowBox[{"Gv", "\[Rule]", 
    FractionBox[
     RowBox[{"Qstar", " ", "t"}], 
     RowBox[{"bstar", " ", "Lstar", " ", "Wstar"}]]}], ",", 
   RowBox[{"Gm", "\[Rule]", 
    FractionBox[
     RowBox[{"Qstar", " ", "\[Mu]p"}], 
     RowBox[{"Pstar", " ", 
      SuperscriptBox["Wstar", "3"]}]]}], ",", 
   RowBox[{"Gk", "\[Rule]", 
    FractionBox["KIc", 
     RowBox[{
      SqrtBox["bstar"], " ", "Pstar"}]]}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox["Qo", "Qstar"]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{"Lstar", " ", "\[CapitalDelta]\[Gamma]"}], "Pstar"]}], ",", 
   RowBox[{"Gmh", "\[Rule]", 
    FractionBox[
     RowBox[{"bstar", " ", "vxstar", " ", "\[Mu]p"}], 
     RowBox[{"Pstar", " ", 
      SuperscriptBox["Wstar", "2"]}]]}], ",", 
   RowBox[{"Gmv", "\[Rule]", 
    FractionBox[
     RowBox[{"vzstar", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["Wstar", "2"], " ", "\[CapitalDelta]\[Gamma]"}]]}], ",", 
   
   RowBox[{"Gs", "\[Rule]", 
    FractionBox["bstar", "Lstar"]}], ",", 
   RowBox[{"GvelV", "\[Rule]", 
    FractionBox[
     RowBox[{"t", " ", "vzstar"}], "Lstar"]}], ",", 
   RowBox[{"Gqhead", "\[Rule]", 
    FractionBox[
     RowBox[{"bstar", " ", 
      SqrtBox["Vo"], " ", "Wstar", " ", 
      SqrtBox["\[CapitalDelta]\[Gamma]"]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "6"}]], " ", "Qstar", " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.868662205882855*^9, 3.869137054774055*^9, 3.8692218457376842`*^9, 
   3.869624286872342*^9, {3.870768944344515*^9, 3.870768961575779*^9}, {
   3.887245909773417*^9, 3.887245920115769*^9}},
 CellLabel->
  "Out[107]=",ExpressionUUID->"ee36aeb9-dcf3-404f-adc0-adcfcd013f7c"]
}, Open  ]],

Cell["Ge=Gqhead=Gb= Gm=1 in that scaling, uniform aspect ration .", "Text",
 CellChangeTimes->{{3.672403687255912*^9, 3.67240369741529*^9}, {
   3.672406243749956*^9, 3.672406247995278*^9}, {3.672406310280857*^9, 
   3.672406312591201*^9}, 3.672406404834804*^9, {3.772531653422431*^9, 
   3.772531686194335*^9}, {3.7775643152279577`*^9, 3.777564317675724*^9}, {
   3.8395848996598673`*^9, 3.839584908979759*^9}, {3.859625074325778*^9, 
   3.859625117564455*^9}, {3.859625464382572*^9, 3.8596254644315367`*^9}, {
   3.887072438969*^9, 
   3.8870724744906282`*^9}},ExpressionUUID->"e4d3d00f-8600-4993-8ffa-\
147a5fa5bd7f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HeadmScales", "=", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"#", " ", "/.", "aux"}], ")"}], "\[Equal]", "1"}], " ", 
       "&"}], " ", "/@", " ", 
      RowBox[{"{", 
       RowBox[{
       "Ge", ",", "Gqhead", ",", "Gb", ",", "Gm", ",", "Gs", ",", "Gmv", ",", 
        "Gmh"}], "}"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "Lstar", ",", "Wstar", ",", "Pstar", ",", "Qstar", ",", "bstar", ",", 
       "vxstar", ",", "vzstar"}], "}"}]}], "]"}], " ", "[", 
   RowBox[{"[", 
    RowBox[{"-", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.672403653062512*^9, 3.6724036790815353`*^9}, 
   3.6724039067706327`*^9, 3.672404114303997*^9, {3.67240415202325*^9, 
   3.672404154164214*^9}, {3.672404299101603*^9, 3.6724043143795347`*^9}, {
   3.672404606568009*^9, 3.6724046308877583`*^9}, {3.67240631943143*^9, 
   3.672406331390646*^9}, {3.672406407364108*^9, 3.672406417529558*^9}, 
   3.672466053029285*^9, {3.777560982442871*^9, 3.777560984873324*^9}, {
   3.806919974806553*^9, 3.806919982826289*^9}, 3.806920059758603*^9, 
   3.806923669679187*^9, 3.8069237169299107`*^9, {3.839584921780796*^9, 
   3.839584951958296*^9}, {3.839650416295413*^9, 3.8396504169904327`*^9}, {
   3.85419071539447*^9, 3.854190747801169*^9}, {3.854278501685665*^9, 
   3.8542785028881903`*^9}, {3.858833886854329*^9, 3.858833925454385*^9}, 
   3.858834699926235*^9, {3.8588428249766407`*^9, 3.858842837058086*^9}, 
   3.858843239469275*^9, {3.85900747334306*^9, 3.8590074795419827`*^9}, {
   3.859007515357909*^9, 3.859007551264103*^9}, {3.85900760491114*^9, 
   3.859007623959424*^9}, {3.8590137788435497`*^9, 3.859013778914*^9}, {
   3.859625129656451*^9, 3.859625132448779*^9}, 3.8596267937354507`*^9},
 CellLabel->
  "In[108]:=",ExpressionUUID->"f2ad813b-6af7-4a2a-be13-090035ac60d1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"11", "/", "24"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "8"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "6"}]]}], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"1", "/", "6"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"5", "/", "8"}]]}]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "12"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "4"}]]}]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"11", "/", "24"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "8"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "8"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "6"}]]}], 
     SuperscriptBox["t", 
      RowBox[{"1", "/", "6"}]]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "24"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"7", "/", "8"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "6"}]]}], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"7", "/", "6"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "8"}]]}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"11", "/", "24"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "8"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "6"}]]}], 
     RowBox[{
      SuperscriptBox["t", 
       RowBox[{"1", "/", "6"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"5", "/", "8"}]]}]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SqrtBox["Vo"], " ", 
      SqrtBox["\[CapitalDelta]\[Gamma]"]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "6"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SqrtBox["Vo"], " ", 
      SqrtBox["\[CapitalDelta]\[Gamma]"]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "6"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "3"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.672403657468069*^9, 3.672403669527316*^9}, 
   3.672403738816983*^9, {3.672404098390545*^9, 3.672404115676429*^9}, 
   3.67240415499277*^9, {3.672404303178442*^9, 3.6724043157026987`*^9}, 
   3.672404372376451*^9, {3.672404607237997*^9, 3.6724046315956593`*^9}, 
   3.672406127022051*^9, {3.672406324074513*^9, 3.6724063321792517`*^9}, {
   3.672406407889263*^9, 3.672406426952512*^9}, 3.6724077501594954`*^9, 
   3.6724078974897137`*^9, 3.672465987760776*^9, 3.672466055242416*^9, 
   3.6724683501627197`*^9, {3.672468540942375*^9, 3.6724685465760098`*^9}, 
   3.672477670991399*^9, 3.672477830373823*^9, 3.6724783952450867`*^9, 
   3.6724784946677322`*^9, 3.672483139972924*^9, 3.6793824082429657`*^9, 
   3.77252752653059*^9, 3.77252874491532*^9, 3.777560985753244*^9, 
   3.7832559957034883`*^9, 3.8069198734677143`*^9, {3.80691997631779*^9, 
   3.806919983470696*^9}, {3.806920062645522*^9, 3.806920071865707*^9}, 
   3.80692367430243*^9, 3.806923717760538*^9, 3.8069349270471783`*^9, 
   3.839584935525642*^9, 3.839584966246337*^9, 3.839650418007703*^9, 
   3.839650602842745*^9, 3.839650675007737*^9, 3.839651679322927*^9, 
   3.839651743958797*^9, 3.839667995513178*^9, {3.854190692177032*^9, 
   3.8541907481178293`*^9}, 3.854278509191331*^9, 3.856261277982375*^9, 
   3.85841790810883*^9, 3.858776778635797*^9, 3.858833664430471*^9, {
   3.8588338880824423`*^9, 3.858833926208077*^9}, {3.858834695171741*^9, 
   3.858834700684237*^9}, {3.858842700375757*^9, 3.858842711057232*^9}, {
   3.85884281905077*^9, 3.8588428523492327`*^9}, 3.8588431556122217`*^9, {
   3.858843234393036*^9, 3.858843239886325*^9}, {3.85900745033883*^9, 
   3.859007489972138*^9}, {3.859007521537912*^9, 3.85900755161021*^9}, {
   3.859007587744184*^9, 3.859007624392219*^9}, 3.8590076932708406`*^9, {
   3.859013772255981*^9, 3.859013779428578*^9}, 3.8590142436543293`*^9, 
   3.859014409195273*^9, {3.859625126240057*^9, 3.859625133226408*^9}, 
   3.8596267953672113`*^9, 3.8606682167579393`*^9, 3.860726054180727*^9, 
   3.8607434370153103`*^9, 3.8607456649114237`*^9, 3.8608291664640913`*^9, 
   3.86119445978096*^9, 3.861249106818365*^9, 3.8685290939776278`*^9, 
   3.868662206862859*^9, 3.869137055524317*^9, 3.8692218457983713`*^9, 
   3.869624286934462*^9, {3.870768944493717*^9, 3.8707689616382*^9}, {
   3.88724590984124*^9, 3.887245920206684*^9}},
 CellLabel->
  "Out[108]=",ExpressionUUID->"f3c989a3-23ba-4ceb-8a71-33ce84654c7b"]
}, Open  ]],

Cell["\<\
The remaining (non-unity) dimensionless numbers provides the dimensionless \
numbers governing the solution of the problem\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 3.672403786033778*^9}, {
  3.78326850660122*^9, 3.78326850727908*^9}, {3.86118012621662*^9, 
  3.861180127117938*^9}},ExpressionUUID->"d975a2e7-4a4b-40b8-ac88-\
e7b62d26a578"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HeadmNumbers", " ", "=", 
  RowBox[{
   RowBox[{"aux", "/.", "HeadmScales"}], "//", "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.858842775643182*^9, 3.858842785149295*^9}, 
   3.8590076371131077`*^9, 3.8596267988190536`*^9, {3.860745759568349*^9, 
   3.86074576374961*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"00569d06-c30a-41ca-a083-9f6d44b96ffd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", 
    FractionBox[
     RowBox[{
      SqrtBox["t"], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "8"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"9", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "8"}]], " ", 
      SqrtBox["\[Mu]p"]}]]}], ",", 
   RowBox[{"Gm", "\[Rule]", "1"}], ",", 
   RowBox[{"Gk", "\[Rule]", 
    FractionBox[
     RowBox[{"KIc", " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"11", "/", "16"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "16"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "16"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "4"}]]}]]}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{"Qo", " ", 
      SuperscriptBox["t", 
       RowBox[{"7", "/", "6"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "24"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"7", "/", "8"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "6"}]]}]]}], ",", 
   RowBox[{"Gb", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmh", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gs", "\[Rule]", "1"}], ",", 
   RowBox[{"GvelV", "\[Rule]", 
    FractionBox[
     RowBox[{
      SqrtBox["t"], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"3", "/", "8"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"9", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "8"}]], " ", 
      SqrtBox["\[Mu]p"]}]]}], ",", 
   RowBox[{"Gqhead", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.858842781012267*^9, 3.858842785746969*^9}, {
   3.858842840203796*^9, 3.858842865430044*^9}, 3.858843243459241*^9, {
   3.859007461166748*^9, 3.8590074915577*^9}, 3.859007522803841*^9, 
   3.8590076258924837`*^9, 3.8590076939344263`*^9, 3.859625145842854*^9, 
   3.8596267992239647`*^9, 3.860668237634693*^9, 3.860743444050274*^9, 
   3.860745675937064*^9, 3.860745764239544*^9, 3.860829168626164*^9, 
   3.861194461390545*^9, 3.861249106871077*^9, 3.8686622083987637`*^9, 
   3.869137057088293*^9, 3.8692218458176327`*^9, 3.8696242869664803`*^9, {
   3.8707689445656424`*^9, 3.870768961666256*^9}, {3.8872459099168053`*^9, 
   3.887245920221938*^9}},
 CellLabel->
  "Out[109]=",ExpressionUUID->"67f19dbd-cb92-4e9f-8ebe-edecab018a92"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"introducing", " ", "the", " ", "dimensionless", " ", "time", " ", 
   RowBox[{"t", "/", 
    SubscriptBox["t", 
     RowBox[{"m", 
      OverscriptBox["m", "^"]}]]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.859625153146306*^9, 3.859625168929289*^9}, {
  3.8870725476281033`*^9, 3.887072552234955*^9}},
 CellLabel->
  "In[110]:=",ExpressionUUID->"e383315b-1a6c-442d-b560-d07610871795"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"HeadmScales", " ", "/.", 
    RowBox[{"{", 
     RowBox[{"t", "->", " ", 
      RowBox[{"\[Tau]", " ", "t"}]}], "}"}]}], "/.", "tmb"}], " ", "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.859007698877822*^9, 3.8590077042722273`*^9}, {
   3.859014534650084*^9, 3.859014539217992*^9}, 3.859626803333776*^9},
 CellLabel->
  "In[111]:=",ExpressionUUID->"29d0af93-3c26-4114-9482-6e2790a1374b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[Tau]", 
       RowBox[{"1", "/", "6"}]]}]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SqrtBox["Vo"], " ", 
      SqrtBox["\[CapitalDelta]\[Gamma]"]}], 
     RowBox[{
      SqrtBox["Ep"], " ", 
      SuperscriptBox["\[Tau]", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "4"}]]}], 
     SuperscriptBox["\[Tau]", 
      RowBox[{"1", "/", "6"}]]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Vo", 
       RowBox[{"7", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"9", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"5", "/", "4"}]], " ", "\[Mu]p", " ", 
      SuperscriptBox["\[Tau]", 
       RowBox[{"7", "/", "6"}]]}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[Tau]", 
       RowBox[{"1", "/", "6"}]]}]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{"Vo", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", "2"]}], 
     RowBox[{"Ep", " ", "\[Mu]p", " ", 
      SuperscriptBox["\[Tau]", 
       RowBox[{"2", "/", "3"}]]}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{"Vo", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", "2"]}], 
     RowBox[{"Ep", " ", "\[Mu]p", " ", 
      SuperscriptBox["\[Tau]", 
       RowBox[{"2", "/", "3"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8590077005430727`*^9, 3.85900770484904*^9}, {
   3.859014533031431*^9, 3.859014540527316*^9}, {3.85962515049468*^9, 
   3.859625173532711*^9}, 3.85962680381981*^9, 3.8606682423679237`*^9, 
   3.860743474966529*^9, 3.860745680369253*^9, 3.860829170148443*^9, 
   3.8611944629013157`*^9, 3.861249106907568*^9, 3.868662210427984*^9, 
   3.869137059775426*^9, 3.869221845838113*^9, 3.869624286994153*^9, {
   3.87076894459855*^9, 3.870768961688394*^9}, {3.887245909928628*^9, 
   3.887245920269693*^9}},
 CellLabel->
  "Out[111]=",ExpressionUUID->"952dcb22-ad3f-46d7-b071-3fcf58d802ec"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "head", " ", "at", " ", "the", " ", "transition", " ", "of", " ", "the", 
   " ", "tail"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8870725638195333`*^9, 3.88707256738734*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"b0b1c32e-7752-4dff-b075-4c5f357496cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"HeadmScales", " ", "/.", "tmxkx"}], " ", "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.868529933593227*^9, 3.868529936581292*^9}},
 CellLabel->
  "In[113]:=",ExpressionUUID->"19e80c42-5574-4672-82ef-bac0db14006d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "16"}]], " ", 
      SqrtBox["KIc"], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "16"}]]}], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"9", "/", "16"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{"KIc", " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "8"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"7", "/", "8"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "8"}]]}]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    RowBox[{
     SuperscriptBox["Ep", 
      RowBox[{"1", "/", "16"}]], " ", 
     SqrtBox["KIc"], " ", 
     SuperscriptBox["Vo", 
      RowBox[{"1", "/", "16"}]], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"7", "/", "16"}]]}]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"7", "/", "2"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"7", "/", "16"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "16"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"41", "/", "16"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "16"}]], " ", 
      SqrtBox["KIc"], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "16"}]]}], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"9", "/", "16"}]]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", "2"], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"7", "/", "4"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", "2"], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "4"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "4"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"7", "/", "4"}]], " ", "\[Mu]p"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.868529936858344*^9, 3.868662211597628*^9, 3.869137062230928*^9, 
   3.86922184584639*^9, 3.869624287017211*^9, {3.870768944606159*^9, 
   3.870768961704523*^9}, {3.887245909982992*^9, 3.8872459203240843`*^9}},
 CellLabel->
  "Out[113]=",ExpressionUUID->"f7f4329b-6c0b-49c7-855a-7733421a568b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Get", " ", "the", " ", "head", " ", "and", " ", "tail", " ", "volume"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Vmhead", " ", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Wstar", " ", "Lstar", " ", "bstar"}], " ", "/.", 
       "HeadmScales"}], ")"}], "//", "PowerExpand"}]}], "\[IndentingNewLine]", 
   RowBox[{"Vmtail", " ", "=", " ", 
    RowBox[{"Vo", " ", "-", " ", "Vmhead", " "}]}]}]}]], "Input",
 CellChangeTimes->{{3.8692262015111923`*^9, 3.8692262028161497`*^9}, {
  3.887072488844521*^9, 3.887072522290943*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"ed59ad67-cb92-4f6b-8316-bbcebec8ff8c"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["Ep", 
    RowBox[{"5", "/", "6"}]], " ", 
   SqrtBox["Vo"], " ", 
   SuperscriptBox["\[Mu]p", 
    RowBox[{"2", "/", "3"}]]}], 
  RowBox[{
   SuperscriptBox["t", 
    RowBox[{"2", "/", "3"}]], " ", 
   SuperscriptBox["\[CapitalDelta]\[Gamma]", 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{
  3.869226202986565*^9, 3.869624286940277*^9, {3.870768944504274*^9, 
   3.870768961644423*^9}, {3.887245910007462*^9, 3.887245920351893*^9}},
 CellLabel->
  "Out[114]=",ExpressionUUID->"6e97bad7-9c14-415e-9542-87e2e3ed20d8"],

Cell[BoxData[
 RowBox[{"Vo", "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Ep", 
     RowBox[{"5", "/", "6"}]], " ", 
    SqrtBox["Vo"], " ", 
    SuperscriptBox["\[Mu]p", 
     RowBox[{"2", "/", "3"}]]}], 
   RowBox[{
    SuperscriptBox["t", 
     RowBox[{"2", "/", "3"}]], " ", 
    SuperscriptBox["\[CapitalDelta]\[Gamma]", 
     RowBox[{"3", "/", "2"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.869226202986565*^9, 3.869624286940277*^9, {3.870768944504274*^9, 
   3.870768961644423*^9}, {3.887245910007462*^9, 3.887245920352927*^9}},
 CellLabel->
  "Out[115]=",ExpressionUUID->"69b89578-8262-453a-9df6-04ad20697fa2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Introducing", " ", "the", " ", "dimensionless", " ", "time", " ", 
   RowBox[{"t", "/", 
    SubscriptBox["t", 
     RowBox[{"m", 
      OverscriptBox["m", "^"]}]]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.8870726254807873`*^9, 3.887072644667177*^9}},
 CellLabel->
  "In[116]:=",ExpressionUUID->"6664e471-fb74-4398-b462-bae32c37f0f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Wstar", " ", "Lstar", " ", "bstar"}], " ", "/.", 
      "HeadmScales"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{"t", "->", " ", 
      RowBox[{"\[Tau]", " ", "t"}]}], " ", "}"}]}], "/.", "tmb"}], " ", "//", 
  "PowerExpand"}]], "Input",
 CellLabel->
  "In[117]:=",ExpressionUUID->"62581e8d-5d9c-454e-ace6-928daa8d9a8c"],

Cell[BoxData[
 FractionBox["Vo", 
  SuperscriptBox["\[Tau]", 
   RowBox[{"2", "/", "3"}]]]], "Output",
 CellChangeTimes->{{3.8872459100398273`*^9, 3.887245920388665*^9}},
 CellLabel->
  "Out[117]=",ExpressionUUID->"d0942d15-a4ac-48bd-8cd0-dcdce2083cf9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Get", " ", "the", " ", "transition", " ", "time", " ", "of", " ", "the", 
    " ", "head", " ", "and", " ", "compare", " ", "it", " ", "to", " ", "the",
     " ", "tail"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"tmxkxhead", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Gk", "/.", "HeadmNumbers"}], ")"}], "==", "1"}], ",", 
         "t"}], "]"}], "//", "PowerExpand"}], " ", ")"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"t", "/", "tmxkxhead"}], ")"}], "\[Equal]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t", "/.", "tmxkx"}], ")"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"Gb", "/.", "Knumbers"}], ")"}], 
       RowBox[{"5", "/", "8"}]]}]}], "//", "PowerExpand"}]}]}]], "Input",
 CellChangeTimes->{{3.8607457396461267`*^9, 3.8607458016323233`*^9}, {
  3.868662011742476*^9, 3.868662016141*^9}, {3.868662109063178*^9, 
  3.868662167466065*^9}, {3.868662237049006*^9, 3.8686622393202543`*^9}, {
  3.8686623645588503`*^9, 3.868662386210943*^9}, {3.868662483269744*^9, 
  3.868662483964555*^9}, {3.86866254757022*^9, 3.8686625682356586`*^9}, {
  3.868662599064783*^9, 3.86866262589859*^9}, {3.869137090838179*^9, 
  3.869137134331658*^9}, {3.869137176361456*^9, 3.869137176543154*^9}, {
  3.8870726799264803`*^9, 3.8870727097004004`*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"ee9e551c-3ede-4e6f-817a-8bf7117bdae7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["Ep", 
      RowBox[{"11", "/", "4"}]], " ", 
     SuperscriptBox["Vo", 
      RowBox[{"3", "/", "4"}]], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"1", "/", "4"}]], " ", "\[Mu]p"}], 
    SuperscriptBox["KIc", "4"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.860745749230847*^9, 3.8607458018825817`*^9}, 
   3.860829174992432*^9, 3.861249107013671*^9, 3.868662229551062*^9, 
   3.86866236563517*^9, {3.868662562266693*^9, 3.8686625686322203`*^9}, {
   3.868662601445031*^9, 3.868662637308469*^9}, 3.8691370677529097`*^9, 
   3.869137136258395*^9, 3.869137176928329*^9, 3.869221845915946*^9, 
   3.869624287121538*^9, {3.870768944804728*^9, 3.870768961800202*^9}, {
   3.887245910053441*^9, 3.887245920418076*^9}},
 CellLabel->
  "Out[118]=",ExpressionUUID->"65e86f2a-aa02-412c-8628-8a959cc4b907"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   FractionBox["t", 
    RowBox[{"t", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"11", "/", "4"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"3", "/", "4"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "4"}]], " ", "\[Mu]p"}], 
      SuperscriptBox["KIc", "4"]]}]], "}"}], "\[Equal]", 
  FractionBox[
   RowBox[{
    SuperscriptBox["Ep", 
     RowBox[{"11", "/", "4"}]], " ", 
    SuperscriptBox["Vo", 
     RowBox[{"3", "/", "4"}]], " ", 
    SuperscriptBox["\[CapitalDelta]\[Gamma]", 
     RowBox[{"1", "/", "4"}]], " ", "\[Mu]p"}], 
   SuperscriptBox["KIc", "4"]]}]], "Output",
 CellChangeTimes->{{3.860745749230847*^9, 3.8607458018825817`*^9}, 
   3.860829174992432*^9, 3.861249107013671*^9, 3.868662229551062*^9, 
   3.86866236563517*^9, {3.868662562266693*^9, 3.8686625686322203`*^9}, {
   3.868662601445031*^9, 3.868662637308469*^9}, 3.8691370677529097`*^9, 
   3.869137136258395*^9, 3.869137176928329*^9, 3.869221845915946*^9, 
   3.869624287121538*^9, {3.870768944804728*^9, 3.870768961800202*^9}, {
   3.887245910053441*^9, 3.8872459204191303`*^9}},
 CellLabel->
  "Out[119]=",ExpressionUUID->"fda331de-10a2-444a-8ee9-5dadb36d1cc6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Get", " ", "the", " ", "head", " ", "scales", " ", "at", " ", "the", " ", 
    "transition", " ", "of", " ", "the", " ", "head"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"HeadmScales", "/.", "tmxkxhead"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.869225485558919*^9, 3.869225500389215*^9}, {
  3.887072718420714*^9, 3.8870727283580847`*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"bf50641c-dac3-496b-8e37-389a71af42d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"2", "/", "3"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"4", "/", "3"}]], 
     RowBox[{"Ep", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    RowBox[{
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"1", "/", "3"}]]}]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"14", "/", "3"}]], 
     RowBox[{
      SuperscriptBox["Ep", "3"], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"2", "/", "3"}]]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", "2"], " ", "\[Mu]p"}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", "2"], " ", "\[Mu]p"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.869225501102943*^9, 3.8696242871309357`*^9, {3.870768944913138*^9, 
   3.870768961824719*^9}, {3.8872459100818233`*^9, 3.887245920426166*^9}},
 CellLabel->
  "Out[120]=",ExpressionUUID->"318f5a30-fd3a-48bf-9831-d53ff2e677f1"]
}, Open  ]],

Cell["\<\
Note that these scales are equivalent to the toughness-dominated head.\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 3.672403786033778*^9}, {
  3.78326850660122*^9, 3.78326850727908*^9}, {3.86118012621662*^9, 
  3.861180127117938*^9}, {3.887072738925902*^9, 
  3.887072751644382*^9}},ExpressionUUID->"bfae1fbb-49fc-4fd2-8c5a-\
c324f3ada106"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stabilized viscosity", "Subsection",
 CellChangeTimes->{{3.858755301361298*^9, 3.858755318650674*^9}, {
  3.8587761995631723`*^9, 3.858776201385442*^9}, {3.85962474998917*^9, 
  3.859624750234804*^9}, {3.8611801589325647`*^9, 3.861180159822345*^9}, {
  3.869143498525667*^9, 
  3.8691435030926743`*^9}},ExpressionUUID->"31cea144-ed70-4069-a0cc-\
3776c4eb3a72"],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["MK", "^"], 
    RowBox[{"[", "V", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "c3c22020-59f3-4034-9701-231b65885aa2"],
 " -Tail"
}], "Subsubsection",
 CellChangeTimes->{{3.859624759320595*^9, 3.859624773324108*^9}, {
  3.869144086746908*^9, 3.869144087105008*^9}, {3.887072776399935*^9, 
  3.887072780445622*^9}},ExpressionUUID->"ae52b195-7694-4dc5-987d-\
1d79e26465fc"],

Cell[TextData[{
 "We fix the breadth of the fracture to the fixed breadth obtain from the \
continuous release (lb*M",
 Cell[BoxData[
  FormBox[
   OverscriptBox["k", "^"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "304fbb16-f64c-47d7-b290-b70069c2f507"],
 "^(2/5))"
}], "Text",
 CellChangeTimes->{{3.858865157732641*^9, 3.858865183414806*^9}, {
   3.859623486003992*^9, 3.859623511376896*^9}, {3.859624639086478*^9, 
   3.859624704086314*^9}, 3.861156189472329*^9, {3.8870716548765373`*^9, 
   3.887071663031353*^9}, {3.887243582202664*^9, 
   3.8872436816243362`*^9}},ExpressionUUID->"99595dea-911a-47a4-aa65-\
095587352da3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bset", "=", 
  RowBox[{"{", 
   RowBox[{"bstar", "->", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"6", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"2", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"6", "/", "5"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "5"}]]}]]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.8691435575836782`*^9, 3.869143558830532*^9}, 
   3.869624370830051*^9},
 CellLabel->
  "In[121]:=",ExpressionUUID->"45944d02-f2e0-4063-9733-750a972643b4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"bstar", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["Ep", 
      RowBox[{"6", "/", "5"}]], " ", 
     SuperscriptBox["Qo", 
      RowBox[{"2", "/", "5"}]], " ", 
     SuperscriptBox["\[Mu]p", 
      RowBox[{"2", "/", "5"}]]}], 
    RowBox[{
     SuperscriptBox["KIc", 
      RowBox[{"6", "/", "5"}]], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"2", "/", "5"}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.869143756839629*^9, 3.8696242889156227`*^9, 3.869624371549551*^9, {
   3.870768947557973*^9, 3.870768963857544*^9}, {3.887245910089142*^9, 
   3.88724592045483*^9}},
 CellLabel->
  "Out[121]=",ExpressionUUID->"b0715a95-4c43-4c0d-95f9-db4f540327c6"]
}, Open  ]],

Cell["\<\
This scaling is obtained using Ge=Gv=Gmv=1,   Gs= vx/vz,    vz~Lstar/t, and a \
fixed volume Gq = Qo/(Vo/t) \
\>", "Text",
 CellChangeTimes->{{3.859624814513838*^9, 3.859624878975244*^9}, 
   3.887072232802318*^9, {3.887243812071045*^9, 
   3.8872438709638233`*^9}},ExpressionUUID->"65dfa4d4-8751-4888-aeba-\
98a1ad86163d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MhatToKelongated", " ", "=", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"Join", "[", " ", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", " ", 
                RowBox[{
                 RowBox[{"#", " ", "/.", "DimensionlessGroups"}], "/.", 
                 "bset"}], ")"}], "\[Equal]", "1"}], " ", "&"}], " ", "/@", 
             " ", 
             RowBox[{"{", " ", 
              RowBox[{"Ge", ",", "Gv", ",", 
               RowBox[{"Gs", "  ", 
                RowBox[{"vzstar", "/", "vxstar"}]}], " ", ",", " ", "Gmv", 
               ",", "GvelV"}], "\[IndentingNewLine]", "}"}]}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Gq", "\[Equal]", 
                RowBox[{"Qo", "/", 
                 RowBox[{"(", 
                  RowBox[{"Vo", "/", "t"}], ")"}]}]}], ")"}], "/.", 
              "DimensionlessGroups"}], "}"}]}], "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
           "Pstar", ",", " ", "vxstar", ",", "vzstar", ",", "Lstar", ",", 
            "Qstar", ",", "Wstar"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], " ", "//", "PowerExpand"}], " ", "//",
       "FullSimplify"}], ",", "bset"}], "]"}], "//", "PowerExpand", 
   " "}]}]], "Input",
 CellChangeTimes->{{3.869143573088982*^9, 3.869143584303982*^9}, {
   3.869143778842539*^9, 3.8691437875741863`*^9}, 3.869144295299786*^9, 
   3.869624250232562*^9},
 CellLabel->
  "In[122]:=",ExpressionUUID->"2304c9fb-deb1-4501-8754-c1e0d2b611d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"3", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"8", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "5"}]]}]]}], ",", 
   RowBox[{"vxstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"6", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"2", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"6", "/", "5"}]], " ", "t", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "5"}]]}]]}], ",", 
   RowBox[{"vzstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"4", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"3", "/", "5"}]]}]]}], ",", 
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"4", "/", "15"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"3", "/", "5"}]]}]]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox["Vo", "t"]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"2", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "5"}]]}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"6", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"2", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"6", "/", "5"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "5"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.869143761147469*^9, 3.869143789358506*^9}, 
   3.8691441033018217`*^9, 3.8691453414271317`*^9, 3.869624251019519*^9, 
   3.869624290986904*^9, 3.869624374083067*^9, {3.87076894762269*^9, 
   3.870768966187271*^9}, {3.887245912132575*^9, 3.887245921497628*^9}},
 CellLabel->
  "Out[122]=",ExpressionUUID->"424e8f78-eff5-409a-b492-591ac5293f62"]
}, Open  ]],

Cell["\<\
The remaining (non-unity) dimensionless numbers provides the dimensionless \
numbers governing the solution of the problem\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 3.672403786033778*^9}, {
  3.78326850660122*^9, 3.78326850727908*^9}, {3.86118012621662*^9, 
  3.861180127117938*^9}},ExpressionUUID->"c03f6004-e984-4864-836b-\
816ae214f6e5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MhatToKelongatedGroups", "=", 
  RowBox[{
   RowBox[{"DimensionlessGroups", "/.", "MhatToKelongated"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{3.869143052685934*^9, 3.8691436010167418`*^9, 
  3.869143739075448*^9},
 CellLabel->
  "In[123]:=",ExpressionUUID->"93629099-031e-46bb-9f85-503b21ca302c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gm", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"9", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"14", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"3", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"14", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gk", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Qo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]]}], 
     SuperscriptBox["Vo", 
      RowBox[{"1", "/", "3"}]]]}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{"Qo", " ", "t"}], "Vo"]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Qo", 
       RowBox[{"4", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"7", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"1", "/", "5"}]], " ", 
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"2", "/", "5"}]]}]]}], ",", 
   RowBox[{"Gmh", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"19", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"8", "/", "5"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"8", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"24", "/", "5"}]], " ", "Vo", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "5"}]]}]]}], ",", 
   RowBox[{"Gmv", "\[Rule]", "1"}], ",", 
   RowBox[{"Gs", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", "2"], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"2", "/", "3"}]], " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", "2"], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", "\[CapitalDelta]\[Gamma]"}]]}], ",", 
   RowBox[{"GvelV", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8691430532560053`*^9, 3.869143602252342*^9, 3.86914380358001*^9, 
   3.86914410668156*^9, 3.86962433008526*^9, 3.869624378542959*^9, {
   3.87076894763498*^9, 3.870768973425769*^9}, {3.887245912195897*^9, 
   3.887245921547556*^9}},
 CellLabel->
  "Out[123]=",ExpressionUUID->"d5f43225-4b37-4d2b-9c90-6f933233b9be"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "The", " ", "dimensionless", " ", "toughness", " ", "increases", " ", 
    "with", " ", "time"}], " ", "-", " ", 
   RowBox[{"for", " ", "horizontal", " ", "growth"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.859624883215942*^9, 3.859624910802237*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"87fce4ab-5e0e-49af-a132-e3c40d3c1bba"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "timescale", " ", "for", " ", "the", " ", "horizontal", " ", "toughness", 
   " ", "to", " ", "be", " ", "of", " ", "order", " ", "1"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.859624914356731*^9, 3.859624927446308*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"beaad10d-e946-4d18-998e-a610b982ab43"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"tmkxkx", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Gk", "/.", "MhatToKelongatedGroups"}], ")"}], "==", "1"}], 
       ",", "t"}], "]"}], "//", "PowerExpand"}], " ", ")"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"t", "/.", "tmkxkx"}], ")"}], "\[Equal]", " ", 
   RowBox[{"(", 
    RowBox[{"ts", "/.", 
     RowBox[{"{", 
      RowBox[{"ts", "\[Rule]", " ", 
       RowBox[{"Vo", "/", "Qo"}]}], "}"}]}], ")"}]}], "//", 
  "PowerExpand"}]}], "Input",
 CellChangeTimes->{{3.8588310943485413`*^9, 3.858831148509613*^9}, {
  3.859625417939992*^9, 3.85962543617417*^9}, {3.8607432440258923`*^9, 
  3.860743256152416*^9}, {3.86923502210441*^9, 3.869235143819694*^9}, {
  3.8872465874378567`*^9, 3.887246635776209*^9}},
 CellLabel->
  "In[151]:=",ExpressionUUID->"03aba91f-2481-4466-a330-6a28cbe6be90"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", "\[Rule]", 
   FractionBox["Vo", "Qo"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.868662191521544*^9, 3.869136922102037*^9, 3.869137039339484*^9, 
   3.869221845487382*^9, 3.869235023973221*^9, {3.8692350708574944`*^9, 
   3.869235144398185*^9}, {3.869624258780983*^9, 3.8696242865641403`*^9}, {
   3.8707689434976463`*^9, 3.870768961225914*^9}, {3.887245909709209*^9, 
   3.88724592002391*^9}, 3.887246594357696*^9, {3.887246632449935*^9, 
   3.887246636041037*^9}},
 CellLabel->
  "Out[151]=",ExpressionUUID->"15003a57-6138-4b99-9d4d-a0f03748870d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.868662191521544*^9, 3.869136922102037*^9, 3.869137039339484*^9, 
   3.869221845487382*^9, 3.869235023973221*^9, {3.8692350708574944`*^9, 
   3.869235144398185*^9}, {3.869624258780983*^9, 3.8696242865641403`*^9}, {
   3.8707689434976463`*^9, 3.870768961225914*^9}, {3.887245909709209*^9, 
   3.88724592002391*^9}, 3.887246594357696*^9, {3.887246632449935*^9, 
   3.8872466360430183`*^9}},
 CellLabel->
  "Out[152]=",ExpressionUUID->"b187fb10-45b5-4ca1-b13e-592c1b93cb98"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    OverscriptBox["MK", "^"], 
    RowBox[{"[", "V", "]"}]], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "980ed734-9bac-467a-8221-a44d5aa2ad7a"],
 " -Head"
}], "Subsubsection",
 CellChangeTimes->{{3.859624759320595*^9, 3.859624773324108*^9}, {
   3.869144086746908*^9, 3.869144092859653*^9}, 
   3.887072786674642*^9},ExpressionUUID->"cc5bef16-082e-4f37-8640-\
fdabafbe0c92"],

Cell["\<\
We set the characteristic vertical flow velocity in that scaling to be equal \
to the elongated (tail) viscous scaling \
\>", "Text",
 CellChangeTimes->{{3.672403687255912*^9, 3.67240369741529*^9}, {
   3.672406243749956*^9, 3.672406247995278*^9}, {3.672406310280857*^9, 
   3.672406312591201*^9}, 3.672406404834804*^9, {3.772531653422431*^9, 
   3.772531686194335*^9}, {3.7775643152279577`*^9, 3.777564317675724*^9}, {
   3.8395848996598673`*^9, 3.839584908979759*^9}, {3.859625074325778*^9, 
   3.859625117564455*^9}, {3.859625464382572*^9, 3.8596254644315367`*^9}, {
   3.887072438969*^9, 
   3.887072440763072*^9}},ExpressionUUID->"2e4ec2c1-87bb-4c59-a2f5-\
3b96c84d2d88"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aux", " ", "=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{"DimensionlessGroups", ",", 
    RowBox[{"{", 
     RowBox[{"Gqhead", "->", " ", 
      RowBox[{"bstar", " ", "Wstar", " ", 
       RowBox[{
        RowBox[{"(", "  ", 
         RowBox[{
          RowBox[{"(", "  ", "vzstar", ")"}], "/.", "MhatToKelongated"}], 
         ")"}], " ", "/", "Qstar"}]}]}], "  ", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.860743565211725*^9, 3.8691442692819853`*^9, 
  3.8691443009025784`*^9},
 CellLabel->
  "In[124]:=",ExpressionUUID->"8debc062-9cec-450c-a0be-bc912457e37a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", 
    FractionBox[
     RowBox[{"Ep", " ", "Wstar"}], 
     RowBox[{"bstar", " ", "Pstar"}]]}], ",", 
   RowBox[{"Gv", "\[Rule]", 
    FractionBox[
     RowBox[{"Qstar", " ", "t"}], 
     RowBox[{"bstar", " ", "Lstar", " ", "Wstar"}]]}], ",", 
   RowBox[{"Gm", "\[Rule]", 
    FractionBox[
     RowBox[{"Qstar", " ", "\[Mu]p"}], 
     RowBox[{"Pstar", " ", 
      SuperscriptBox["Wstar", "3"]}]]}], ",", 
   RowBox[{"Gk", "\[Rule]", 
    FractionBox["KIc", 
     RowBox[{
      SqrtBox["bstar"], " ", "Pstar"}]]}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox["Qo", "Qstar"]}], ",", 
   RowBox[{"Gb", "\[Rule]", 
    FractionBox[
     RowBox[{"Lstar", " ", "\[CapitalDelta]\[Gamma]"}], "Pstar"]}], ",", 
   RowBox[{"Gmh", "\[Rule]", 
    FractionBox[
     RowBox[{"bstar", " ", "vxstar", " ", "\[Mu]p"}], 
     RowBox[{"Pstar", " ", 
      SuperscriptBox["Wstar", "2"]}]]}], ",", 
   RowBox[{"Gmv", "\[Rule]", 
    FractionBox[
     RowBox[{"vzstar", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["Wstar", "2"], " ", "\[CapitalDelta]\[Gamma]"}]]}], ",", 
   
   RowBox[{"Gs", "\[Rule]", 
    FractionBox["bstar", "Lstar"]}], ",", 
   RowBox[{"GvelV", "\[Rule]", 
    FractionBox[
     RowBox[{"t", " ", "vzstar"}], "Lstar"]}], ",", 
   RowBox[{"Gqhead", "\[Rule]", 
    FractionBox[
     RowBox[{"bstar", " ", 
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", "Wstar", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"3", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"4", "/", "15"}]], " ", "Qstar", " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"3", "/", "5"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.861193444529893*^9, 3.861193937681444*^9, 3.861194428152976*^9, 
   3.8612491062084513`*^9, 3.8612495220503597`*^9, 3.8685290118559017`*^9, 
   3.868662189374856*^9, 3.869136981608735*^9, {3.869144271743025*^9, 
   3.869144301542658*^9}, 3.869145345077737*^9, 3.869624343743568*^9, 
   3.8696243823467607`*^9, 3.8707689845884733`*^9, {3.887245912204371*^9, 
   3.887245921555533*^9}},
 CellLabel->
  "Out[124]=",ExpressionUUID->"49a7d391-466e-484e-9b67-7725646bfcc2"]
}, Open  ]],

Cell["Ge=Gqhead=Gb= Gm=1 in that scaling, uniform aspect ration .", "Text",
 CellChangeTimes->{{3.672403687255912*^9, 3.67240369741529*^9}, {
   3.672406243749956*^9, 3.672406247995278*^9}, {3.672406310280857*^9, 
   3.672406312591201*^9}, 3.672406404834804*^9, {3.772531653422431*^9, 
   3.772531686194335*^9}, {3.7775643152279577`*^9, 3.777564317675724*^9}, {
   3.8395848996598673`*^9, 3.839584908979759*^9}, {3.859625074325778*^9, 
   3.859625117564455*^9}, {3.859625464382572*^9, 3.8596254644315367`*^9}, {
   3.887072438969*^9, 
   3.8870724744906282`*^9}},ExpressionUUID->"a5c90173-6bac-4039-ab8b-\
f121607eecc5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MhatToKHead", "=", 
  RowBox[{
   RowBox[{"Solve", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{"#", " ", "/.", "aux"}], ")"}], "\[Equal]", "1"}], " ", 
       "&"}], " ", "/@", " ", 
      RowBox[{"{", 
       RowBox[{"Ge", ",", "Gqhead", ",", "Gb", ",", "Gk", ",", "Gs"}], 
       "}"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "Lstar", ",", "Wstar", ",", "Pstar", ",", "Qstar", ",", "bstar"}], 
      "}"}]}], "]"}], " ", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8607436998597918`*^9, 3.860743769026129*^9}, {
  3.869144360285365*^9, 3.869144362962968*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"ad431ea3-bee1-41b6-a742-7250fa76537b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Lstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"2", "/", "3"}]]]}], ",", 
   RowBox[{"Wstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"4", "/", "3"}]], 
     RowBox[{"Ep", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Pstar", "\[Rule]", 
    RowBox[{
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"1", "/", "3"}]]}]}], ",", 
   RowBox[{"Qstar", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"14", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"9", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"4", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"3", "/", "5"}]]}]]}], ",", 
   RowBox[{"bstar", "\[Rule]", 
    FractionBox[
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]], 
     SuperscriptBox["\[CapitalDelta]\[Gamma]", 
      RowBox[{"2", "/", "3"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.672403657468069*^9, 3.672403669527316*^9}, 
   3.672403738816983*^9, {3.672404098390545*^9, 3.672404115676429*^9}, 
   3.67240415499277*^9, {3.672404303178442*^9, 3.6724043157026987`*^9}, 
   3.672404372376451*^9, {3.672404607237997*^9, 3.6724046315956593`*^9}, 
   3.672406127022051*^9, {3.672406324074513*^9, 3.6724063321792517`*^9}, {
   3.672406407889263*^9, 3.672406426952512*^9}, 3.6724077501594954`*^9, 
   3.6724078974897137`*^9, 3.672465987760776*^9, 3.672466055242416*^9, 
   3.6724683501627197`*^9, {3.672468540942375*^9, 3.6724685465760098`*^9}, 
   3.672477670991399*^9, 3.672477830373823*^9, 3.6724783952450867`*^9, 
   3.6724784946677322`*^9, 3.672483139972924*^9, 3.6793824082429657`*^9, 
   3.77252752653059*^9, 3.77252874491532*^9, 3.777560985753244*^9, 
   3.7832559957034883`*^9, 3.8069198734677143`*^9, {3.80691997631779*^9, 
   3.806919983470696*^9}, {3.806920062645522*^9, 3.806920071865707*^9}, 
   3.80692367430243*^9, 3.806923717760538*^9, 3.8069349270471783`*^9, 
   3.839584935525642*^9, 3.839584966246337*^9, 3.839585657827276*^9, 
   3.839585806951165*^9, 3.839666426330853*^9, 3.839667999825431*^9, 
   3.854190698480776*^9, 3.854278587307022*^9, 3.854278640769505*^9, 
   3.856261278057572*^9, {3.858417852384104*^9, 3.858417873859489*^9}, 
   3.858417908209588*^9, 3.85877685744596*^9, 3.858829927242076*^9, 
   3.858833699892565*^9, {3.858833963634923*^9, 3.858833982459895*^9}, 
   3.858834789398177*^9, {3.858842676490945*^9, 3.8588426868217173`*^9}, 
   3.858842992305436*^9, 3.858843336216694*^9, 3.8588436116620007`*^9, 
   3.8596244714889097`*^9, 3.8596245179620867`*^9, 3.860667922835663*^9, 
   3.860727446704287*^9, 3.860743679295333*^9, {3.860743729550459*^9, 
   3.860743776412217*^9}, 3.86074562294495*^9, 3.860746636096978*^9, 
   3.8608289712679167`*^9, 3.86115620202365*^9, 3.861180155706443*^9, 
   3.86118604318506*^9, 3.8611934456173983`*^9, 3.8611939378517103`*^9, 
   3.861194429128571*^9, 3.861249106271468*^9, 3.861249523107386*^9, 
   3.868529013437454*^9, 3.868662189433634*^9, 3.869136982577794*^9, 
   3.8691442729908237`*^9, 3.869144305554141*^9, 3.86914436805693*^9, 
   3.869145348864407*^9, 3.869624354897298*^9, 3.8696243885961657`*^9, 
   3.8707689915939074`*^9, {3.887245918788562*^9, 3.887245927430196*^9}},
 CellLabel->
  "Out[125]=",ExpressionUUID->"c30b2cb1-8ca7-4771-ac06-4949f8d39687"]
}, Open  ]],

Cell["\<\
The remaining (non-unity) dimensionless numbers provides the dimensionless \
numbers governing the solution of the problem\
\>", "Text",
 CellChangeTimes->{{3.6724037532050943`*^9, 3.672403786033778*^9}, {
  3.78326850660122*^9, 3.78326850727908*^9}, {3.86118012621662*^9, 
  3.861180127117938*^9}},ExpressionUUID->"2d5969de-40a4-44bb-8485-\
3db4bb1970b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MhatToKHeadNumbers", "=", 
  RowBox[{
   RowBox[{"DimensionlessGroups", "//.", "MhatToKHead"}], " ", "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.83958500273477*^9, 3.839585005127421*^9}, {
   3.839585814228545*^9, 3.839585820860989*^9}, {3.839668070504938*^9, 
   3.8396680740860023`*^9}, 3.8542786049238377`*^9, {3.8691443828797903`*^9, 
   3.8691443845126057`*^9}, 3.869144423810011*^9},
 CellLabel->
  "In[126]:=",ExpressionUUID->"2f333a8b-88a7-40d1-b99f-e4a956b3de2d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Ge", "\[Rule]", "1"}], ",", 
   RowBox[{"Gv", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"19", "/", "15"}]]}], 
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"4", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"4", "/", "15"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"3", "/", "5"}]]}]]}], ",", 
   RowBox[{"Gm", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"6", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"4", "/", "15"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"2", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"28", "/", "15"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"4", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gk", "\[Rule]", "1"}], ",", 
   RowBox[{"Gq", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", 
       RowBox[{"9", "/", "5"}]], " ", 
      SuperscriptBox["Qo", 
       RowBox[{"19", "/", "15"}]], " ", 
      SuperscriptBox["t", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "5"}]], " ", 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"3", "/", "5"}]]}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"14", "/", "5"}]], " ", 
      SuperscriptBox["Vo", 
       RowBox[{"2", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gb", "\[Rule]", "1"}], ",", 
   RowBox[{"Gmh", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", "2"], " ", "vxstar", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gmv", "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["Ep", "2"], " ", "vzstar", " ", "\[Mu]p"}], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}]]}], ",", 
   RowBox[{"Gs", "\[Rule]", "1"}], ",", 
   RowBox[{"GvelV", "\[Rule]", 
    FractionBox[
     RowBox[{"t", " ", "vzstar", " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]}], 
     SuperscriptBox["KIc", 
      RowBox[{"2", "/", "3"}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.86913698598914*^9, 3.8691443850724382`*^9, 3.869144424404955*^9, 
   3.8691453568770437`*^9, {3.869624364281311*^9, 3.869624388683548*^9}, 
   3.8707689969426517`*^9, {3.887245918832816*^9, 3.8872459274951563`*^9}},
 CellLabel->
  "Out[126]=",ExpressionUUID->"402147cf-73bb-424c-b1f9-128b04493a10"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Deriving", " ", "the", " ", "head", " ", "and", " ", "tail", " ", 
    "volume"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Vmkhead", " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["Lstar", "2"], " ", "Wstar"}], " ", "//.", 
     "MhatToKHead"}]}], "\[IndentingNewLine]", 
   RowBox[{"Vmktail", "=", 
    RowBox[{"Vo", "-", "Vmkhead"}]}]}]}]], "Input",
 CellChangeTimes->{{3.839585273630432*^9, 3.839585296743086*^9}, {
   3.839585661834203*^9, 3.83958566267203*^9}, {3.854278590315559*^9, 
   3.8542785935467978`*^9}, 3.869144370022882*^9, {3.887243944587579*^9, 
   3.887243964668433*^9}},
 CellLabel->
  "In[127]:=",ExpressionUUID->"7c08e1c4-21a6-4279-908e-c053ce3285aa"],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["KIc", 
   RowBox[{"8", "/", "3"}]], 
  RowBox[{"Ep", " ", 
   SuperscriptBox["\[CapitalDelta]\[Gamma]", 
    RowBox[{"5", "/", "3"}]]}]]], "Output",
 CellChangeTimes->{
  3.8395852970897827`*^9, 3.839585663229546*^9, 3.839585807921587*^9, 
   3.839666427363884*^9, 3.839667999868332*^9, 3.8541906985304613`*^9, 
   3.854278593915484*^9, 3.854278642636602*^9, 3.8562612780648403`*^9, {
   3.858417852454755*^9, 3.8584178739044313`*^9}, 3.858417908216283*^9, 
   3.858776859785201*^9, 3.858829928469836*^9, 3.858842683727437*^9, 
   3.858842932667961*^9, 3.8588433377945223`*^9, 3.859624474756481*^9, 
   3.85962451950352*^9, 3.860667927009501*^9, 3.8607274473317337`*^9, 
   3.8607437875077467`*^9, 3.860745629914771*^9, 3.8607466367134037`*^9, 
   3.860828972680896*^9, 3.861156203046764*^9, 3.861180156612718*^9, 
   3.861186043689788*^9, 3.861193446526353*^9, 3.861193937858902*^9, 
   3.8611944299057493`*^9, 3.861249106279316*^9, 3.86124952390711*^9, 
   3.868529015044909*^9, 3.868662189438507*^9, 3.8691369836025343`*^9, 
   3.869144370692217*^9, 3.8691444333409233`*^9, 3.8691453557504673`*^9, {
   3.869624361733222*^9, 3.869624388637261*^9}, 3.8707689950719957`*^9, {
   3.887245918844324*^9, 3.8872459275568733`*^9}},
 CellLabel->
  "Out[127]=",ExpressionUUID->"0d4a07e9-bc1c-4a71-8c15-225a57125617"],

Cell[BoxData[
 RowBox[{"Vo", "-", 
  FractionBox[
   SuperscriptBox["KIc", 
    RowBox[{"8", "/", "3"}]], 
   RowBox[{"Ep", " ", 
    SuperscriptBox["\[CapitalDelta]\[Gamma]", 
     RowBox[{"5", "/", "3"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.8395852970897827`*^9, 3.839585663229546*^9, 3.839585807921587*^9, 
   3.839666427363884*^9, 3.839667999868332*^9, 3.8541906985304613`*^9, 
   3.854278593915484*^9, 3.854278642636602*^9, 3.8562612780648403`*^9, {
   3.858417852454755*^9, 3.8584178739044313`*^9}, 3.858417908216283*^9, 
   3.858776859785201*^9, 3.858829928469836*^9, 3.858842683727437*^9, 
   3.858842932667961*^9, 3.8588433377945223`*^9, 3.859624474756481*^9, 
   3.85962451950352*^9, 3.860667927009501*^9, 3.8607274473317337`*^9, 
   3.8607437875077467`*^9, 3.860745629914771*^9, 3.8607466367134037`*^9, 
   3.860828972680896*^9, 3.861156203046764*^9, 3.861180156612718*^9, 
   3.861186043689788*^9, 3.861193446526353*^9, 3.861193937858902*^9, 
   3.8611944299057493`*^9, 3.861249106279316*^9, 3.86124952390711*^9, 
   3.868529015044909*^9, 3.868662189438507*^9, 3.8691369836025343`*^9, 
   3.869144370692217*^9, 3.8691444333409233`*^9, 3.8691453557504673`*^9, {
   3.869624361733222*^9, 3.869624388637261*^9}, 3.8707689950719957`*^9, {
   3.887245918844324*^9, 3.887245927557972*^9}},
 CellLabel->
  "Out[128]=",ExpressionUUID->"c78e3dc7-c892-4e37-b9d3-90c87cdca58e"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Scaling Tables", "Section",
 CellChangeTimes->{{3.859625775223029*^9, 
  3.8596257802267303`*^9}},ExpressionUUID->"c5748092-b2a1-4a21-b031-\
94ecdd74394a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{"{", " ", 
      RowBox[{
      "\"\<\>\"", " ", ",", " ", "\"\<\!\(\*SubscriptBox[\(l\), \(*\)]\)\>\"",
        ",", " ", "\"\<\!\(\*SubscriptBox[\(b\), \(*\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(w\), \(*\)]\)\>\"", ",", 
       "\"\<\!\(\*SubscriptBox[\(p\), \(*\)]\)\>\"", ",", 
       "\"\<\[ScriptCapitalK],\[ScriptCapitalM]\>\"", ",", 
       "\"\<\[ScriptCapitalB]\>\""}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*SuperscriptBox[\(M\), \([V]\)]\)\>\"", ",", " ", "Lstar", 
         ",", "bstar", ",", "Wstar", ",", "Pstar", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Gk", "/.", "DimensionlessGroups"}], "/.", "MScales"}], 
           " ", "/.", 
           RowBox[{"{", 
            RowBox[{"t", "->", " ", 
             RowBox[{"\[Tau]", " ", "t"}]}], "}"}]}], "/.", "tmk"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Gb", "/.", "DimensionlessGroups"}], "/.", "MScales"}], "/.", 
           RowBox[{"{", 
            RowBox[{"t", "->", " ", 
             RowBox[{"\[Tau]", " ", "t"}]}], "}"}]}], "/.", "tmb"}]}], "}"}], 
       "/.", "MScales"}], " ", "//", "PowerExpand"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<\!\(\*SuperscriptBox[\(K\), \([V]\)]\)\>\"", ",", "Lstar", ",", 
         "bstar", ",", "Wstar", ",", "Pstar", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Gm", "/.", "DimensionlessGroups"}], " ", "/.", 
            "KScales"}], " ", "/.", 
           RowBox[{"{", 
            RowBox[{"t", "->", " ", 
             RowBox[{"\[Tau]", " ", "t"}]}], "}"}]}], "/.", "tmk"}], ",", 
         RowBox[{
          RowBox[{"Gb", "/.", "DimensionlessGroups"}], "/.", "KScales"}]}], 
        "}"}], "/.", "KScales"}], " ", "//", "PowerExpand"}]}], "}"}], "//", 
   "TableForm"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.859625782682753*^9, 3.8596259458161793`*^9}, {
  3.859626651267025*^9, 3.8596266653308363`*^9}, {3.859628609677725*^9, 
  3.8596286586673822`*^9}, {3.887245944374161*^9, 3.887246079005413*^9}},
 CellLabel->
  "In[177]:=",ExpressionUUID->"b647d4cc-ecce-4810-9131-af8ff9a46f31"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(l\\), \\(*\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(b\\), \\(*\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(w\\), \\(*\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(*\\)]\\)\"\>", "\<\"\[ScriptCapitalK],\
\[ScriptCapitalM]\"\>", "\<\"\[ScriptCapitalB]\"\>"},
    {"\<\"\\!\\(\\*SuperscriptBox[\\(M\\), \\([V]\\)]\\)\"\>", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"1", "/", "9"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "9"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]]}], 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "9"}]]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"1", "/", "9"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "9"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]]}], 
      SuperscriptBox["\[Mu]p", 
       RowBox[{"1", "/", "9"}]]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"2", "/", "9"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"2", "/", "9"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"2", "/", "9"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}], 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]]], 
     SuperscriptBox["\[Tau]", 
      RowBox[{"5", "/", "18"}]], 
     SuperscriptBox["\[Tau]", 
      RowBox[{"4", "/", "9"}]]},
    {"\<\"\\!\\(\\*SuperscriptBox[\\(K\\), \\([V]\\)]\\)\"\>", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"2", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"2", "/", "5"}]]}], 
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "5"}]]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"2", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"2", "/", "5"}]]}], 
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "5"}]]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"4", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "5"}]]}], 
      SuperscriptBox["Ep", 
       RowBox[{"4", "/", "5"}]]], 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"6", "/", "5"}]], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"1", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "5"}]]}]], 
     FractionBox["1", "\[Tau]"], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"3", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"3", "/", "5"}]], " ", "\[CapitalDelta]\[Gamma]"}], 
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "5"}]]]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.859625785114019*^9, 3.85962586912395*^9}, {
   3.859625919305306*^9, 3.859625946652088*^9}, 3.8596266658324327`*^9, 
   3.859628569026882*^9, {3.85962862059942*^9, 3.8596286592448397`*^9}, 
   3.859633084936442*^9, 3.8596343891807117`*^9, 3.859807725704195*^9, {
   3.887245918886312*^9, 3.88724595524431*^9}, 3.887245989985332*^9, {
   3.887246050093321*^9, 3.887246079467318*^9}, 3.8872461605297623`*^9, 
   3.8872472117518597`*^9},
 CellLabel->
  "Out[177]//TableForm=",ExpressionUUID->"b9bf8a59-7f99-48b1-9f59-\
8b24df324948"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
     "\"\<\>\"", " ", ",", " ", "\"\<\!\(\*SubscriptBox[\(l\), \(*\)]\)\>\"", 
      ",", " ", "\"\<\!\(\*SubscriptBox[\(b\), \(*\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(w\), \(*\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(V\), \(*\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[\(p\), \(*\)]\)\>\"", ",", 
      "\"\<\[ScriptCapitalK],\[ScriptCapitalM]\>\"", ",", 
      "\"\<\[ScriptCapitalB]\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[OverscriptBox[\(M\), \(^\)], \([V]\)]\) \
(tail)\>\"", " ", ",", " ", "Lstar", ",", "bstar", ",", "Wstar", ",", 
        RowBox[{
        "\"\<\!\(\*SubsuperscriptBox[\(V\), \(*\), \(head\)]\)\>\"", " ", "-",
          " ", 
         RowBox[{"Qo", " ", "t"}]}], ",", "Pstar", ",", 
        RowBox[{
         RowBox[{"Gk", "/.", "DimensionlessGroups"}], "/.", "Melongated"}], 
        " ", ",", 
        RowBox[{
         RowBox[{"Gb", "/.", "DimensionlessGroups"}], " ", "/.", 
         "Melongated"}]}], "}"}], "/.", "Melongated"}], " ", "//", 
     "PowerExpand"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[OverscriptBox[\(M\), \(^\)], \([V]\)]\) \
(head)\>\"", ",", " ", "Lstar", ",", "bstar", ",", "Wstar", ",", 
        RowBox[{"(", " ", 
         RowBox[{"Lstar", " ", "bstar", " ", "Wstar"}], ")"}], ",", "Pstar", 
        ",", 
        RowBox[{
         RowBox[{"Gk", "/.", "DimensionlessGroups"}], "/.", 
         "HeadmNumbers"}]}], " ", "}"}], "/.", "HeadmScales"}], " ", "//", 
     "PowerExpand"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[OverscriptBox[\(K\), \(^\)], \([V]\)]\) \
(tail)\>\"", ",", "Lstar", ",", "bstar", ",", "Wstar", ",", 
        RowBox[{
        "\"\<\!\(\*SubsuperscriptBox[\(V\), \(*\), \(head\)]\)\>\"", " ", "-",
          " ", 
         RowBox[{"Qo", " ", "t"}]}], ",", "Pstar", ",", "\"\< \>\"", ",", 
        RowBox[{
         RowBox[{"Gb", "/.", "DimensionlessGroups"}], "/.", 
         "KelongatedGroups"}]}], " ", "}"}], "/.", "Kelongated"}], " ", "//", 
     "PowerExpand"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[OverscriptBox[\(K\), \(^\)], \([V]\)]\) \
(head)\>\"", ",", "Lstar", ",", "bstar", ",", "Wstar", ",", 
        RowBox[{"(", " ", 
         RowBox[{"Lstar", " ", "bstar", " ", "Wstar"}], ")"}], ",", "Pstar", 
        ",", 
        RowBox[{
         RowBox[{"Gm", "/.", "DimensionlessGroups"}], "/.", 
         "HeadmNumbers"}]}], " ", "}"}], "/.", "HeadkScales"}], " ", "//", 
     "PowerExpand"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[OverscriptBox[\(MK\), \(^\)], \([V]\)]\) \
(tail)\>\"", ",", "Lstar", ",", "bstar", ",", "Wstar", ",", 
        RowBox[{
        "\"\<\!\(\*SubsuperscriptBox[\(V\), \(*\), \(head\)]\)\>\"", " ", "-",
          " ", 
         RowBox[{"Qo", " ", "t"}]}], ",", "Pstar", ",", 
        RowBox[{
         RowBox[{"Gk", "/.", "DimensionlessGroups"}], "/.", 
         "MhatToKelongated"}], " ", ",", 
        RowBox[{
         RowBox[{"Gb", "/.", "DimensionlessGroups"}], " ", "/.", 
         "MhatToKelongated"}]}], "}"}], "/.", "MhatToKelongated"}], " ", "//",
      "PowerExpand"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[OverscriptBox[\(MK\), \(^\)], \([V]\)]\) \
(head)\>\"", ",", "Lstar", ",", "bstar", ",", "Wstar", ",", 
        RowBox[{"(", " ", 
         RowBox[{"Lstar", " ", "bstar", " ", "Wstar"}], ")"}], ",", "Pstar", 
        ",", 
        RowBox[{
         RowBox[{"Gm", "/.", "DimensionlessGroups"}], "/.", " ", 
         "MhatToKHeadNumbers"}]}], "}"}], "/.", "MhatToKHead"}], " ", "//", 
     "PowerExpand"}]}], "}"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.859626686514538*^9, 3.859626717145142*^9}, {
   3.859626757591468*^9, 3.859626762419209*^9}, {3.859626989386319*^9, 
   3.859627137846723*^9}, 3.859627182275381*^9, {3.859628141910087*^9, 
   3.8596283038826427`*^9}, {3.8596283658108463`*^9, 
   3.8596284100569773`*^9}, {3.859628467753705*^9, 3.859628476987838*^9}, {
   3.85962853836462*^9, 3.859628547135109*^9}, 3.8596362621630497`*^9, {
   3.8872461225270233`*^9, 3.887246189745325*^9}, {3.887246251801087*^9, 
   3.887246260831772*^9}, {3.8872463140168037`*^9, 3.8872464528689213`*^9}, {
   3.887246484572226*^9, 3.88724652288019*^9}, {3.887246651793079*^9, 
   3.88724667734086*^9}, {3.8872469296232347`*^9, 3.8872471095223627`*^9}, {
   3.8872471611091003`*^9, 3.8872471864566793`*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"a8cc0132-66f7-429b-bce2-cdf0aa6ceb29"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"\"\>", "\<\"\\!\\(\\*SubscriptBox[\\(l\\), \\(*\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(b\\), \\(*\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(w\\), \\(*\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(V\\), \\(*\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(*\\)]\\)\"\>", "\<\"\[ScriptCapitalK],\
\[ScriptCapitalM]\"\>", "\<\"\[ScriptCapitalB]\"\>"},
    {"\<\"\\!\\(\\*SuperscriptBox[OverscriptBox[\\(M\\), \\(^\\)], \\([V]\\)]\
\\) (tail)\"\>", 
     FractionBox[
      RowBox[{
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SqrtBox["Vo"], " ", 
       SqrtBox["\[CapitalDelta]\[Gamma]"]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"1", "/", "6"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"1", "/", "4"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "4"}]]}], 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "4"}]]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "4"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"1", "/", "12"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "4"}]]}]], 
     RowBox[{"\<\"\\!\\(\\*SubsuperscriptBox[\\(V\\), \\(*\\), \\(head\\)]\\)\
\"\>", "-", 
      RowBox[{"Qo", " ", "t"}]}], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}], 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "3"}]]], 
     FractionBox[
      RowBox[{"KIc", " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "8"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"19", "/", "24"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "8"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["t", 
        RowBox[{"2", "/", "3"}]], " ", 
       SqrtBox["Vo"], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"3", "/", "2"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"5", "/", "6"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"2", "/", "3"}]]}]]},
    {"\<\"\\!\\(\\*SuperscriptBox[OverscriptBox[\\(M\\), \\(^\\)], \\([V]\\)]\
\\) (head)\"\>", 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"11", "/", "24"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "8"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "6"}]]}], 
      RowBox[{
       SuperscriptBox["t", 
        RowBox[{"1", "/", "6"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"5", "/", "8"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"11", "/", "24"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "8"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "6"}]]}], 
      RowBox[{
       SuperscriptBox["t", 
        RowBox[{"1", "/", "6"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"5", "/", "8"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "4"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"1", "/", "12"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "4"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"5", "/", "6"}]], " ", 
       SqrtBox["Vo"], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"2", "/", "3"}]]}], 
      RowBox[{
       SuperscriptBox["t", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"3", "/", "2"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"11", "/", "24"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "8"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"3", "/", "8"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "6"}]]}], 
      SuperscriptBox["t", 
       RowBox[{"1", "/", "6"}]]], 
     FractionBox[
      RowBox[{"KIc", " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "4"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"11", "/", "16"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"3", "/", "16"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "16"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "4"}]]}]], "\<\"\"\>"},
    {"\<\"\\!\\(\\*SuperscriptBox[OverscriptBox[\\(K\\), \\(^\\)], \\([V]\\)]\
\\) (tail)\"\>", 
     FractionBox[
      RowBox[{
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"7", "/", "9"}]]}], 
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"4", "/", "9"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}]], 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "3"}]], 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}], 
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"2", "/", "9"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "9"}]]}]], 
     RowBox[{"\<\"\\!\\(\\*SubsuperscriptBox[\\(V\\), \\(*\\), \\(head\\)]\\)\
\"\>", "-", 
      RowBox[{"Qo", " ", "t"}]}], 
     FractionBox[
      RowBox[{"Ep", " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"5", "/", "9"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "3"}]]}], 
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"8", "/", "9"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]]}]], "\<\" \"\>", 
     FractionBox[
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"4", "/", "9"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"11", "/", "9"}]]}], 
      RowBox[{"Ep", " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"2", "/", "3"}]]}]]},
    {"\<\"\\!\\(\\*SuperscriptBox[OverscriptBox[\\(K\\), \\(^\\)], \\([V]\\)]\
\\) (head)\"\>", 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "3"}]], 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]], 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "3"}]], 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]], 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "3"}]], 
      RowBox[{"Ep", " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "3"}]]}]], 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "3"}]], 
      RowBox[{"Ep", " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"5", "/", "3"}]]}]], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", "3"], " ", "Vo", " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"2", "/", "3"}]], " ", "\[Mu]p"}], 
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"14", "/", "3"}]], " ", "t"}]], "\<\"\"\>"},
    {"\<\"\\!\\(\\*SuperscriptBox[OverscriptBox[\\(MK\\), \\(^\\)], \
\\([V]\\)]\\) (tail)\"\>", 
     FractionBox[
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"4", "/", "5"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"3", "/", "5"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"4", "/", "5"}]], " ", 
       SuperscriptBox["Qo", 
        RowBox[{"4", "/", "15"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"3", "/", "5"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"6", "/", "5"}]], " ", 
       SuperscriptBox["Qo", 
        RowBox[{"2", "/", "5"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"2", "/", "5"}]]}], 
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"6", "/", "5"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"2", "/", "5"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"2", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "5"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"2", "/", "5"}]], " ", 
       SuperscriptBox["Qo", 
        RowBox[{"2", "/", "15"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "5"}]]}]], 
     RowBox[{"\<\"\\!\\(\\*SubsuperscriptBox[\\(V\\), \\(*\\), \\(head\\)]\\)\
\"\>", "-", 
      RowBox[{"Qo", " ", "t"}]}], 
     FractionBox[
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"8", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "5"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"3", "/", "5"}]], " ", 
       SuperscriptBox["Qo", 
        RowBox[{"8", "/", "15"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"1", "/", "5"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Qo", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"1", "/", "3"}]]}], 
      SuperscriptBox["Vo", 
       RowBox[{"1", "/", "3"}]]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Qo", 
        RowBox[{"4", "/", "15"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"7", "/", "5"}]]}], 
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"1", "/", "5"}]], " ", 
       SuperscriptBox["KIc", 
        RowBox[{"4", "/", "5"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"2", "/", "5"}]]}]]},
    {"\<\"\\!\\(\\*SuperscriptBox[OverscriptBox[\\(MK\\), \\(^\\)], \
\\([V]\\)]\\) (head)\"\>", 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "3"}]], 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]], 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "3"}]], 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"2", "/", "3"}]]], 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"4", "/", "3"}]], 
      RowBox[{"Ep", " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "3"}]]}]], 
     FractionBox[
      SuperscriptBox["KIc", 
       RowBox[{"8", "/", "3"}]], 
      RowBox[{"Ep", " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"5", "/", "3"}]]}]], 
     RowBox[{
      SuperscriptBox["KIc", 
       RowBox[{"2", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalDelta]\[Gamma]", 
       RowBox[{"1", "/", "3"}]]}], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"6", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"4", "/", "15"}]], " ", 
       SuperscriptBox["\[Mu]p", 
        RowBox[{"2", "/", "5"}]]}], 
      RowBox[{
       SuperscriptBox["KIc", 
        RowBox[{"28", "/", "15"}]], " ", 
       SuperscriptBox["Qo", 
        RowBox[{"4", "/", "15"}]], " ", 
       SuperscriptBox["t", 
        RowBox[{"2", "/", "3"}]]}]], "\<\"\"\>"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  TableForm[{{
    "", "\!\(\*SubscriptBox[\(l\), \(*\)]\)", 
     "\!\(\*SubscriptBox[\(b\), \(*\)]\)", 
     "\!\(\*SubscriptBox[\(w\), \(*\)]\)", 
     "\!\(\*SubscriptBox[\(V\), \(*\)]\)", 
     "\!\(\*SubscriptBox[\(p\), \(*\)]\)", 
     "\[ScriptCapitalK],\[ScriptCapitalM]", "\[ScriptCapitalB]"}, {
    "\!\(\*SuperscriptBox[OverscriptBox[\(M\), \(^\)], \([V]\)]\) (tail)", \
$CellContext`Ep^Rational[-1, 6] $CellContext`t^Rational[1, 3] $CellContext`Vo^
      Rational[1, 2] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[1, 2] $CellContext`\[Mu]p^Rational[-1, 3], $CellContext`Ep^
      Rational[1, 4] $CellContext`Vo^
      Rational[1, 4] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-1, 4], $CellContext`Ep^Rational[-1, 12] $CellContext`t^
      Rational[-1, 3] $CellContext`Vo^
      Rational[1, 4] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-1, 4] $CellContext`\[Mu]p^Rational[1, 3], 
     "\!\(\*SubsuperscriptBox[\(V\), \(*\), \(head\)]\)" - $CellContext`Qo \
$CellContext`t, $CellContext`Ep^Rational[2, 3] $CellContext`t^
      Rational[-1, 3] $CellContext`\[Mu]p^Rational[1, 3], $CellContext`Ep^
      Rational[-19, 24] $CellContext`KIc $CellContext`t^
      Rational[1, 3] $CellContext`Vo^
      Rational[-1, 8] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[1, 8] $CellContext`\[Mu]p^Rational[-1, 3], $CellContext`Ep^
      Rational[-5, 6] $CellContext`t^Rational[2, 3] $CellContext`Vo^
      Rational[1, 2] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[3, 2] $CellContext`\[Mu]p^Rational[-2, 3]}, {
    "\!\(\*SuperscriptBox[OverscriptBox[\(M\), \(^\)], \([V]\)]\) (head)", \
$CellContext`Ep^Rational[11, 24] $CellContext`t^
      Rational[-1, 6] $CellContext`Vo^
      Rational[1, 8] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-5, 8] $CellContext`\[Mu]p^Rational[1, 6], $CellContext`Ep^
      Rational[11, 24] $CellContext`t^Rational[-1, 6] $CellContext`Vo^
      Rational[1, 8] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-5, 8] $CellContext`\[Mu]p^Rational[1, 6], $CellContext`Ep^
      Rational[-1, 12] $CellContext`t^Rational[-1, 3] $CellContext`Vo^
      Rational[1, 4] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-1, 4] $CellContext`\[Mu]p^Rational[1, 3], $CellContext`Ep^
      Rational[5, 6] $CellContext`t^Rational[-2, 3] $CellContext`Vo^
      Rational[1, 2] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-3, 2] $CellContext`\[Mu]p^Rational[2, 3], $CellContext`Ep^
      Rational[11, 24] $CellContext`t^Rational[-1, 6] $CellContext`Vo^
      Rational[1, 8] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[3, 8] $CellContext`\[Mu]p^Rational[1, 6], $CellContext`Ep^
      Rational[-11, 16] $CellContext`KIc $CellContext`t^
      Rational[1, 4] $CellContext`Vo^
      Rational[-3, 16] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-1, 16] $CellContext`\[Mu]p^Rational[-1, 4]}, {
    "\!\(\*SuperscriptBox[OverscriptBox[\(K\), \(^\)], \([V]\)]\) (tail)", \
$CellContext`KIc^Rational[-4, 9] $CellContext`t^
      Rational[1, 3] $CellContext`Vo^
      Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[7, 9] $CellContext`\[Mu]p^Rational[-1, 3], $CellContext`KIc^
      Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-2, 3], $CellContext`KIc^Rational[-2, 9] $CellContext`t^
      Rational[-1, 3] $CellContext`Vo^
      Rational[1, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-1, 9] $CellContext`\[Mu]p^Rational[1, 3], 
     "\!\(\*SubsuperscriptBox[\(V\), \(*\), \(head\)]\)" - $CellContext`Qo \
$CellContext`t, $CellContext`Ep $CellContext`KIc^
      Rational[-8, 9] $CellContext`t^Rational[-1, 3] $CellContext`Vo^
      Rational[1, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[5, 9] $CellContext`\[Mu]p^Rational[1, 3], 
     " ", $CellContext`Ep^(-1) $CellContext`KIc^Rational[4, 9] $CellContext`t^
      Rational[2, 3] $CellContext`Vo^
      Rational[1, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[11, 9] $CellContext`\[Mu]p^Rational[-2, 3]}, {
    "\!\(\*SuperscriptBox[OverscriptBox[\(K\), \(^\)], \([V]\)]\) (head)", \
$CellContext`KIc^Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-2, 3], $CellContext`KIc^
      Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-2, 3], $CellContext`Ep^(-1) $CellContext`KIc^
      Rational[4, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-1, 3], $CellContext`Ep^(-1) $CellContext`KIc^
      Rational[8, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-5, 3], $CellContext`KIc^
      Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[1, 3], $CellContext`Ep^3 $CellContext`KIc^
      Rational[-14, 
        3] $CellContext`t^(-1) $CellContext`Vo $CellContext`\[CapitalDelta]\
\[Gamma]^Rational[2, 3] $CellContext`\[Mu]p}, {
    "\!\(\*SuperscriptBox[OverscriptBox[\(MK\), \(^\)], \([V]\)]\) (tail)", \
$CellContext`Ep^Rational[-4, 5] $CellContext`KIc^
      Rational[4, 5] $CellContext`Qo^Rational[-4, 15] $CellContext`t^
      Rational[1, 3] $CellContext`Vo^
      Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[3, 5] $CellContext`\[Mu]p^Rational[-3, 5], $CellContext`Ep^
      Rational[6, 5] $CellContext`KIc^Rational[-6, 5] $CellContext`Qo^
      Rational[2, 5] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-2, 5] $CellContext`\[Mu]p^Rational[2, 5], $CellContext`Ep^
      Rational[-2, 5] $CellContext`KIc^Rational[2, 5] $CellContext`Qo^
      Rational[-2, 15] $CellContext`t^Rational[-1, 3] $CellContext`Vo^
      Rational[1, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-1, 5] $CellContext`\[Mu]p^Rational[1, 5], 
     "\!\(\*SubsuperscriptBox[\(V\), \(*\), \(head\)]\)" - $CellContext`Qo \
$CellContext`t, $CellContext`Ep^Rational[-3, 5] $CellContext`KIc^
      Rational[8, 5] $CellContext`Qo^Rational[-8, 15] $CellContext`t^
      Rational[-1, 3] $CellContext`Vo^
      Rational[1, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[1, 5] $CellContext`\[Mu]p^Rational[-1, 5], $CellContext`Qo^
      Rational[1, 3] $CellContext`t^Rational[1, 3] $CellContext`Vo^
      Rational[-1, 3], $CellContext`Ep^Rational[-1, 5] $CellContext`KIc^
      Rational[-4, 5] $CellContext`Qo^Rational[4, 15] $CellContext`t^
      Rational[2, 3] $CellContext`Vo^
      Rational[1, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[7, 5] $CellContext`\[Mu]p^Rational[-2, 5]}, {
    "\!\(\*SuperscriptBox[OverscriptBox[\(MK\), \(^\)], \([V]\)]\) (head)", \
$CellContext`KIc^Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-2, 3], $CellContext`KIc^
      Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-2, 3], $CellContext`Ep^(-1) $CellContext`KIc^
      Rational[4, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-1, 3], $CellContext`Ep^(-1) $CellContext`KIc^
      Rational[8, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[-5, 3], $CellContext`KIc^
      Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[1, 3], $CellContext`Ep^Rational[6, 5] $CellContext`KIc^
      Rational[-28, 15] $CellContext`Qo^Rational[-4, 15] $CellContext`t^
      Rational[-2, 3] $CellContext`Vo^
      Rational[2, 3] $CellContext`\[CapitalDelta]\[Gamma]^
      Rational[4, 15] $CellContext`\[Mu]p^Rational[2, 5]}}]]], "Output",
 CellChangeTimes->{{3.859626692787876*^9, 3.8596267179232903`*^9}, 
   3.859626763990589*^9, {3.859627002436521*^9, 3.859627069058662*^9}, {
   3.859627101657475*^9, 3.859627139628456*^9}, 3.859627183028722*^9, {
   3.859628143062042*^9, 3.859628246286278*^9}, {3.859628291512978*^9, 
   3.859628304509362*^9}, {3.859628366514779*^9, 3.8596284113367643`*^9}, {
   3.859628470816142*^9, 3.85962847792948*^9}, {3.859628539801326*^9, 
   3.859628549320156*^9}, 3.859634969046332*^9, 3.8596362338393393`*^9, {
   3.859636264151932*^9, 3.859636267580724*^9}, 3.859636496911831*^9, 
   3.8598078785077143`*^9, 3.887245918983079*^9, {3.887246156784348*^9, 
   3.8872461907699137`*^9}, 3.887246261450183*^9, {3.8872463572682533`*^9, 
   3.887246379135664*^9}, 3.887246453557406*^9, {3.887246492141449*^9, 
   3.887246523305318*^9}, {3.88724665417157*^9, 3.8872466778969316`*^9}, {
   3.8872469424164047`*^9, 3.887247109958434*^9}, {3.887247187456531*^9, 
   3.887247211890029*^9}},
 CellLabel->
  "Out[178]//TableForm=",ExpressionUUID->"4882375d-738f-4243-8f68-\
100ef9d841e4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(t\), \([V]\)], \(mk\)]\)\>\"", 
      ",", "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(t\), \([V]\)], \(m \
\*OverscriptBox[\(m\), \(^\)]\)]\)\>\"", ",", " ", 
      "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(t\), \([V]\)], \
\(\*OverscriptBox[\(m\), \(^\)] \*OverscriptBox[\(k\), \(^\)]\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(t\), \(head, \([V]\)\)], \
\(\*OverscriptBox[\(m\), \(^\)] \*OverscriptBox[\(k\), \(^\)]\)]\)\>\"", ",", 
      "\"\<\!\(\*SubscriptBox[SuperscriptBox[\(t\), \([V]\)], \
\(\*OverscriptBox[\(mk\), \(^\)] \*OverscriptBox[\(k\), \(^\)]\)]\)\>\""}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"t", "/.", "tmk"}], ")"}], ",", 
      RowBox[{"(", 
       RowBox[{"t", "/.", "tmb"}], ")"}], ",", 
      RowBox[{"(", 
       RowBox[{"t", "/.", "tmxkx"}], ")"}], ",", 
      RowBox[{"(", 
       RowBox[{"t", "/.", "tmxkxhead"}], ")"}], ",", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"t", "/.", "tmkxkx"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Vo", "/", "Qo"}], "\[Rule]", " ", "ts"}], "}"}]}], ")"}]}],
      "}"}]}], "}"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.887246702013811*^9, 3.887246884118445*^9}},
 CellLabel->
  "In[179]:=",ExpressionUUID->"1ed5a197-c154-462d-bea2-e4278447f1a0"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(t\\), \\([V]\\)], \\(mk\\)]\
\\)\"\>", "\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(t\\), \\([V]\\)], \\(m \
\\*OverscriptBox[\\(m\\), \\(^\\)]\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(t\\), \\([V]\\)], \
\\(\\*OverscriptBox[\\(m\\), \\(^\\)] \\*OverscriptBox[\\(k\\), \
\\(^\\)]\\)]\\)\"\>", "\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(t\\), \
\\(head, \\([V]\\)\\)], \\(\\*OverscriptBox[\\(m\\), \\(^\\)] \
\\*OverscriptBox[\\(k\\), \\(^\\)]\\)]\\)\"\>", \
"\<\"\\!\\(\\*SubscriptBox[SuperscriptBox[\\(t\\), \\([V]\\)], \
\\(\\*OverscriptBox[\\(mk\\), \\(^\\)] \\*OverscriptBox[\\(k\\), \\(^\\)]\\)]\
\\)\"\>"},
    {
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"13", "/", "5"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"3", "/", "5"}]], " ", "\[Mu]p"}], 
      SuperscriptBox["KIc", 
       RowBox[{"18", "/", "5"}]]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"5", "/", "4"}]], " ", "\[Mu]p"}], 
      RowBox[{
       SuperscriptBox["Vo", 
        RowBox[{"3", "/", "4"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"9", "/", "4"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"19", "/", "8"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"3", "/", "8"}]], " ", "\[Mu]p"}], 
      RowBox[{
       SuperscriptBox["KIc", "3"], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"3", "/", "8"}]]}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["Ep", 
        RowBox[{"11", "/", "4"}]], " ", 
       SuperscriptBox["Vo", 
        RowBox[{"3", "/", "4"}]], " ", 
       SuperscriptBox["\[CapitalDelta]\[Gamma]", 
        RowBox[{"1", "/", "4"}]], " ", "\[Mu]p"}], 
      SuperscriptBox["KIc", "4"]], "ts"}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.8872468445640783`*^9, 3.887246884401092*^9}, {
  3.887247199853134*^9, 3.887247211904868*^9}},
 CellLabel->
  "Out[179]//TableForm=",ExpressionUUID->"aaf74d8a-f0b5-47dc-84d0-\
b75a0d70c31a"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1440, 716},
WindowMargins->{{0, Automatic}, {Automatic, 180}},
Magnification:>1.25 Inherited,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"d5185949-7b87-4ce5-a33e-a1c60bea4c03"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 719, 11, 188, "Title",ExpressionUUID->"5de7d24f-a41e-4c7e-8291-a064e5e3d79f"],
Cell[1302, 35, 456, 7, 67, "Subtitle",ExpressionUUID->"737d3d60-8653-4558-9499-bc62f6bc803b"],
Cell[1761, 44, 586, 12, 145, "Subtitle",ExpressionUUID->"75a26214-14d1-47c0-bd31-c77a506dd51a"],
Cell[2350, 58, 160, 3, 44, "Text",ExpressionUUID->"e0d2a60a-9a10-4713-8db1-90e15e730ee0"],
Cell[2513, 63, 370, 7, 44, "Text",ExpressionUUID->"a3baab5e-c968-465e-a114-ae07dc6b5bad"],
Cell[2886, 72, 6304, 127, 384, "Input",ExpressionUUID->"ca414df2-c49e-4bf5-bf9a-3a42f4ce0aed"],
Cell[9193, 201, 1618, 31, 221, "Text",ExpressionUUID->"f2300f5c-5086-43d1-9698-3158a72fa88c"],
Cell[CellGroupData[{
Cell[10836, 236, 447, 7, 84, "Section",ExpressionUUID->"9ed53687-2777-4407-a980-19d3e5bb2c31"],
Cell[CellGroupData[{
Cell[11308, 247, 257, 4, 67, "Subsection",ExpressionUUID->"98f8bdde-7eb8-472b-9ba2-7258e0a60c57"],
Cell[CellGroupData[{
Cell[11590, 255, 635, 14, 57, "Subsubsection",ExpressionUUID->"1660a6b5-aab8-4a82-b336-de7c335fe195"],
Cell[12228, 271, 583, 10, 44, "Text",ExpressionUUID->"ea5e164f-2205-4710-a8b3-b60d599f28ee"],
Cell[CellGroupData[{
Cell[12836, 285, 1745, 38, 90, "Input",ExpressionUUID->"18e9cf7b-b438-440b-b69d-04aa2e675e99"],
Cell[14584, 325, 4195, 100, 70, "Output",ExpressionUUID->"efede6bf-029d-414e-a9e0-d8007f3f7409"]
}, Open  ]],
Cell[18794, 428, 366, 7, 44, "Text",ExpressionUUID->"23bdf49a-d94e-48b7-93b4-058d28ad4a97"],
Cell[CellGroupData[{
Cell[19185, 439, 397, 8, 37, "Input",ExpressionUUID->"636d4c22-3b04-4c94-a20a-bf769529f284"],
Cell[19585, 449, 3311, 72, 70, "Output",ExpressionUUID->"2181cf4f-2209-4ff6-9879-6116c0d21c6f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22933, 526, 1118, 26, 65, "Input",ExpressionUUID->"9194d2f9-7050-4db1-8ae8-345ea69c9a88"],
Cell[24054, 554, 1597, 29, 70, "Output",ExpressionUUID->"2da6cc11-e091-45be-81d7-1fbd632772ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25688, 588, 747, 20, 64, "Input",ExpressionUUID->"6a60b8da-c24c-41b1-a78e-6a2435c0afb0"],
Cell[26438, 610, 1361, 26, 70, "Output",ExpressionUUID->"4664d8d0-b5ae-49d1-8603-66d7ea271844"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[27848, 642, 652, 14, 46, "Subsubsection",ExpressionUUID->"4ca980d4-d168-4bf6-99b4-082e67966b8e"],
Cell[28503, 658, 568, 10, 44, "Text",ExpressionUUID->"ae4fe989-2572-41b7-bc04-ee410b24ef73"],
Cell[CellGroupData[{
Cell[29096, 672, 1775, 39, 64, "Input",ExpressionUUID->"2c4339b2-38e1-4fa8-a064-a41b701214fb"],
Cell[30874, 713, 2410, 69, 70, "Output",ExpressionUUID->"1289a08f-4c31-45e1-8003-0a771bba2a61"]
}, Open  ]],
Cell[33299, 785, 274, 6, 44, "Text",ExpressionUUID->"8497c22f-0262-4618-84d9-f6c993734ae5"],
Cell[CellGroupData[{
Cell[33598, 795, 423, 8, 37, "Input",ExpressionUUID->"3ec36e26-2dbf-4c78-8d3f-bcba9997f0f3"],
Cell[34024, 805, 3110, 69, 70, "Output",ExpressionUUID->"84ecd23d-9e38-4f55-9b96-d05845e452f8"]
}, Open  ]],
Cell[37149, 877, 314, 6, 37, "Input",ExpressionUUID->"b17e25c6-b9f3-4b24-a7b2-d6a2fed7c5d6"],
Cell[CellGroupData[{
Cell[37488, 887, 567, 15, 37, "Input",ExpressionUUID->"bb25a50a-b903-443b-bffc-6f1d0419d478"],
Cell[38058, 904, 1405, 32, 70, "Output",ExpressionUUID->"07155f80-b44b-48c6-a5dd-5371439857bf"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[39512, 942, 692, 20, 46, "Subsubsection",ExpressionUUID->"915d8ccb-4625-430b-beb5-8ca502eed153"],
Cell[CellGroupData[{
Cell[40229, 966, 434, 9, 64, "Input",ExpressionUUID->"f56d4cb4-6634-41be-91aa-175ca1216e18"],
Cell[40666, 977, 2712, 77, 70, "Output",ExpressionUUID->"c9e027f3-b98d-432d-9409-57d68be8c3b8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43415, 1059, 499, 11, 64, "Input",ExpressionUUID->"a172fbfe-325f-4415-9734-26d3dab39dd1"],
Cell[43917, 1072, 2492, 74, 70, "Output",ExpressionUUID->"194e5d1f-49ed-4508-a986-66cd50e16240"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46446, 1151, 535, 12, 64, "Input",ExpressionUUID->"f69d985b-97d8-4b28-abbb-e752d51aadda"],
Cell[46984, 1165, 1933, 47, 70, "Output",ExpressionUUID->"8acb8884-643b-4a47-aee7-51c969ce50f1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48954, 1217, 511, 12, 64, "Input",ExpressionUUID->"04cb543a-1a58-4dfb-843a-27e0e6c474f0"],
Cell[49468, 1231, 1865, 47, 70, "Output",ExpressionUUID->"c53fbdb9-c6e2-40c7-9aff-8a985b8913f4"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[51394, 1285, 276, 4, 46, "Subsection",ExpressionUUID->"7e5db26d-7867-405c-956a-75c8caaed28c"],
Cell[51673, 1291, 498, 11, 37, "Input",ExpressionUUID->"dad550b1-8045-4b9a-905d-d00f4c6ac407"],
Cell[CellGroupData[{
Cell[52196, 1306, 456, 9, 64, "Input",ExpressionUUID->"a2cc4976-1f2a-4d5a-8c6d-65d3b519da98"],
Cell[52655, 1317, 1863, 56, 70, "Output",ExpressionUUID->"c68f867e-67b0-46ad-aac1-6cab9cbe5e88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54555, 1378, 539, 13, 64, "Input",ExpressionUUID->"999b2f72-b489-4989-a411-af9aadf0e258"],
Cell[55097, 1393, 1704, 40, 70, "Output",ExpressionUUID->"24db1e59-03c0-4d75-836f-b51534ea0569"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56838, 1438, 1068, 29, 90, "Input",ExpressionUUID->"28b37027-6f63-4ebd-9590-85d2468bf997"],
Cell[57909, 1469, 833, 16, 70, "Output",ExpressionUUID->"ee8dfe84-69e8-4af4-9e02-e9db5161dd91"],
Cell[58745, 1487, 607, 8, 70, "Output",ExpressionUUID->"4857d049-6424-45e0-be0e-e6d189e9fd4a"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[59413, 1502, 224, 4, 84, "Section",ExpressionUUID->"97e3b3ef-9c85-45f7-90a8-156818a8d806"],
Cell[CellGroupData[{
Cell[59662, 1510, 274, 4, 67, "Subsection",ExpressionUUID->"2cb2cc1d-d055-41ee-9409-2ab75906efbe"],
Cell[CellGroupData[{
Cell[59961, 1518, 458, 13, 61, "Subsubsection",ExpressionUUID->"fd1fd992-2c1d-463f-a952-3a48f19cf3fd"],
Cell[60422, 1533, 485, 9, 44, "Text",ExpressionUUID->"a7c22649-af08-4476-90a4-8e8874519796"],
Cell[CellGroupData[{
Cell[60932, 1546, 805, 18, 94, "Input",ExpressionUUID->"5526b6e5-8f19-49ba-95c1-20f7f83ff9a2"],
Cell[61740, 1566, 1000, 19, 70, "Output",ExpressionUUID->"2e6da476-0f60-4306-b463-1e81a5b435f8"]
}, Open  ]],
Cell[62755, 1588, 799, 13, 73, "Text",ExpressionUUID->"a93d64fe-d2fb-4ad5-a9f4-e57412908582"],
Cell[CellGroupData[{
Cell[63579, 1605, 2093, 47, 90, "Input",ExpressionUUID->"26e99fb1-7f93-4340-bbae-ba4986da21d9"],
Cell[65675, 1654, 3427, 89, 70, "Output",ExpressionUUID->"9c3afaa5-ce22-4440-bcb9-e9838aea1758"]
}, Open  ]],
Cell[69117, 1746, 366, 7, 44, "Text",ExpressionUUID->"5b6b5467-ec11-4217-b54d-d72fbc59f6ae"],
Cell[CellGroupData[{
Cell[69508, 1757, 350, 8, 37, "Input",ExpressionUUID->"cb21fd47-511c-4887-a202-12899c18d909"],
Cell[69861, 1767, 3178, 85, 70, "Output",ExpressionUUID->"393e5189-eb82-4a17-81a8-9bcbcfa64a77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73076, 1857, 940, 24, 90, "Input",ExpressionUUID->"70080bba-db7a-4dd5-9fcb-a072b2d2cfa4"],
Cell[74019, 1883, 906, 16, 70, "Output",ExpressionUUID->"63afb0af-666b-4cbf-89c7-71c4a5a4e1ce"],
Cell[74928, 1901, 1176, 25, 70, "Output",ExpressionUUID->"9d608ead-6c6e-4f4d-b065-9867ca8ddc46"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[76153, 1932, 776, 17, 51, "Subsubsection",ExpressionUUID->"e627e254-3f8a-4a2f-a382-27e5f43b6e12"],
Cell[76932, 1951, 815, 17, 47, "Text",ExpressionUUID->"4276bf36-0cce-447b-9add-386aaa7ff2b0"],
Cell[77750, 1970, 618, 9, 44, "Text",ExpressionUUID->"0d1b0f31-a100-44e8-99d5-da86cb432c12"],
Cell[CellGroupData[{
Cell[78393, 1983, 1115, 30, 90, "Input",ExpressionUUID->"d2ea2258-f506-43d5-be53-df6f05f61a39"],
Cell[79511, 2015, 3255, 61, 70, "Output",ExpressionUUID->"ed932f0c-a8bf-4a5b-84f1-092754b8b3c4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82803, 2081, 860, 19, 90, "Input",ExpressionUUID->"89f12a5c-f4ca-4e2a-bf4e-14c95aedd71e"],
Cell[83666, 2102, 1296, 22, 70, "Output",ExpressionUUID->"b5bb67fe-145e-49f8-a22a-7851062aee5d"],
Cell[84965, 2126, 1327, 23, 70, "Output",ExpressionUUID->"03856b4c-ddfe-4220-a18e-3b7dff05ad88"]
}, Open  ]],
Cell[86307, 2152, 366, 7, 44, "Text",ExpressionUUID->"e1f15ed4-a2cf-4214-9f33-4cc0a9864af8"],
Cell[CellGroupData[{
Cell[86698, 2163, 424, 8, 37, "Input",ExpressionUUID->"cb81f80f-1753-40e5-bbfe-0ac5cb706798"],
Cell[87125, 2173, 1968, 55, 70, "Output",ExpressionUUID->"abd0519a-9654-49a1-b5f6-1e68dd72564d"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[89154, 2235, 323, 5, 46, "Subsection",ExpressionUUID->"d6b5b8d5-d8d7-46be-8180-c44e8a65721a"],
Cell[CellGroupData[{
Cell[89502, 2244, 463, 13, 61, "Subsubsection",ExpressionUUID->"c3d3b48d-d0a5-492b-9b8f-3c7564274c27"],
Cell[89968, 2259, 282, 6, 44, "Text",ExpressionUUID->"7af19012-07ac-4dce-8486-d760eab85d4c"],
Cell[CellGroupData[{
Cell[90275, 2269, 1511, 36, 64, "Input",ExpressionUUID->"467e2c0f-8ac0-458e-9588-b1eb7b148308"],
Cell[91789, 2307, 3295, 87, 128, "Output",ExpressionUUID->"322dc93b-7a3f-41e6-a9de-f0b5f6db5884"]
}, Open  ]],
Cell[95099, 2397, 366, 7, 44, "Text",ExpressionUUID->"a7452d8f-5116-4054-8852-7bb0f958becd"],
Cell[CellGroupData[{
Cell[95490, 2408, 425, 8, 37, "Input",ExpressionUUID->"a3b86557-2875-4bc5-aaf1-e6226cc9326b"],
Cell[95918, 2418, 3158, 81, 70, "Output",ExpressionUUID->"4fc6256e-23a5-4cc6-885a-74ee6c32467a"]
}, Open  ]],
Cell[99091, 2502, 397, 9, 37, "Input",ExpressionUUID->"5f4f54aa-43c9-4f13-923f-19b178401b81"],
Cell[99491, 2513, 359, 8, 37, "Input",ExpressionUUID->"993551e4-2062-4e8d-ac84-1946c87ca68f"],
Cell[CellGroupData[{
Cell[99875, 2525, 884, 24, 64, "Input",ExpressionUUID->"86769a93-b729-465f-9442-a4aff9c25aef"],
Cell[100762, 2551, 803, 20, 68, "Output",ExpressionUUID->"ed0a2980-6ca3-4dea-a73b-2c84c3f2c087"],
Cell[101568, 2573, 733, 18, 68, "Output",ExpressionUUID->"b73d15dc-45b5-4367-abd4-e141a7048e5b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[102338, 2596, 477, 11, 64, "Input",ExpressionUUID->"44ab58ed-afd1-4c2d-8b11-ea23f4993684"],
Cell[102818, 2609, 2734, 80, 70, "Output",ExpressionUUID->"51dab00f-a976-47e5-aba5-8921a6a58472"]
}, Open  ]],
Cell[105567, 2692, 524, 10, 64, "Input",ExpressionUUID->"c3172584-e88a-4c02-9ef9-432a191af0bd"],
Cell[CellGroupData[{
Cell[106116, 2706, 522, 15, 37, "Input",ExpressionUUID->"415a330a-53fd-472b-a557-2d1066762a8a"],
Cell[106641, 2723, 755, 11, 70, "Output",ExpressionUUID->"bf0239ba-9727-4ac0-9f0e-8ca73adbae2c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[107445, 2740, 567, 15, 51, "Subsubsection",ExpressionUUID->"e17d5e2b-6733-4987-8dbb-2975278e62c7"],
Cell[108015, 2757, 686, 12, 44, "Text",ExpressionUUID->"507d700b-2ec1-4a17-97ce-cc80c9bc1901"],
Cell[CellGroupData[{
Cell[108726, 2773, 1039, 21, 37, "Input",ExpressionUUID->"44d87571-0e97-411d-914a-199f20a097ac"],
Cell[109768, 2796, 2023, 58, 70, "Output",ExpressionUUID->"ee36aeb9-dcf3-404f-adc0-adcfcd013f7c"]
}, Open  ]],
Cell[111806, 2857, 620, 9, 44, "Text",ExpressionUUID->"e4d3d00f-8600-4993-8ffa-147a5fa5bd7f"],
Cell[CellGroupData[{
Cell[112451, 2870, 1915, 38, 37, "Input",ExpressionUUID->"f2ad813b-6af7-4a2a-be13-090035ac60d1"],
Cell[114369, 2910, 5399, 130, 70, "Output",ExpressionUUID->"f3c989a3-23ba-4ceb-8a71-33ce84654c7b"]
}, Open  ]],
Cell[119783, 3043, 366, 7, 44, "Text",ExpressionUUID->"d975a2e7-4a4b-40b8-ac88-e7b62d26a578"],
Cell[CellGroupData[{
Cell[120174, 3054, 386, 8, 37, "Input",ExpressionUUID->"00569d06-c30a-41ca-a083-9f6d44b96ffd"],
Cell[120563, 3064, 2714, 73, 70, "Output",ExpressionUUID->"67f19dbd-cb92-4e9f-8ebe-edecab018a92"]
}, Open  ]],
Cell[123292, 3140, 437, 10, 39, "Input",ExpressionUUID->"e383315b-1a6c-442d-b560-d07610871795"],
Cell[CellGroupData[{
Cell[123754, 3154, 446, 11, 37, "Input",ExpressionUUID->"29d0af93-3c26-4114-9482-6e2790a1374b"],
Cell[124203, 3167, 2891, 82, 70, "Output",ExpressionUUID->"952dcb22-ad3f-46d7-b071-3fcf58d802ec"]
}, Open  ]],
Cell[127109, 3252, 312, 7, 37, "Input",ExpressionUUID->"b0b1c32e-7752-4dff-b075-4c5f357496cc"],
Cell[CellGroupData[{
Cell[127446, 3263, 260, 6, 37, "Input",ExpressionUUID->"19e80c42-5574-4672-82ef-bac0db14006d"],
Cell[127709, 3271, 2708, 81, 70, "Output",ExpressionUUID->"f7f4329b-6c0b-49c7-855a-7733421a568b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130454, 3357, 716, 18, 90, "Input",ExpressionUUID->"ed59ad67-cb92-4f6b-8316-bbcebec8ff8c"],
Cell[131173, 3377, 592, 17, 70, "Output",ExpressionUUID->"6e97bad7-9c14-415e-9542-87e2e3ed20d8"],
Cell[131768, 3396, 627, 18, 70, "Output",ExpressionUUID->"69b89578-8262-453a-9df6-04ad20697fa2"]
}, Open  ]],
Cell[132410, 3417, 388, 9, 39, "Input",ExpressionUUID->"6664e471-fb74-4398-b462-bae32c37f0f4"],
Cell[CellGroupData[{
Cell[132823, 3430, 419, 13, 37, "Input",ExpressionUUID->"62581e8d-5d9c-454e-ace6-928daa8d9a8c"],
Cell[133245, 3445, 253, 6, 70, "Output",ExpressionUUID->"d0942d15-a4ac-48bd-8cd0-dcdce2083cf9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133535, 3456, 1643, 39, 90, "Input",ExpressionUUID->"ee9e551c-3ede-4e6f-817a-8bf7117bdae7"],
Cell[135181, 3497, 926, 20, 70, "Output",ExpressionUUID->"65e86f2a-aa02-412c-8628-8a959cc4b907"],
Cell[136110, 3519, 1278, 31, 70, "Output",ExpressionUUID->"fda331de-10a2-444a-8ee9-5dadb36d1cc6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[137425, 3555, 529, 13, 64, "Input",ExpressionUUID->"bf50641c-dac3-496b-8e37-389a71af42d0"],
Cell[137957, 3570, 1982, 58, 70, "Output",ExpressionUUID->"318f5a30-fd3a-48bf-9831-d53ff2e677f1"]
}, Open  ]],
Cell[139954, 3631, 363, 7, 44, "Text",ExpressionUUID->"bfae1fbb-49fc-4fd2-8c5a-c324f3ada106"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[140366, 3644, 366, 6, 67, "Subsection",ExpressionUUID->"31cea144-ed70-4069-a0cc-3776c4eb3a72"],
Cell[CellGroupData[{
Cell[140757, 3654, 484, 13, 61, "Subsubsection",ExpressionUUID->"ae52b195-7694-4dc5-987d-1d79e26465fc"],
Cell[141244, 3669, 655, 15, 47, "Text",ExpressionUUID->"99595dea-911a-47a4-aa65-095587352da3"],
Cell[CellGroupData[{
Cell[141924, 3688, 677, 20, 66, "Input",ExpressionUUID->"45944d02-f2e0-4063-9733-750a972643b4"],
Cell[142604, 3710, 739, 21, 68, "Output",ExpressionUUID->"b0715a95-4c43-4c0d-95f9-db4f540327c6"]
}, Open  ]],
Cell[143358, 3734, 333, 7, 44, "Text",ExpressionUUID->"65dfa4d4-8751-4888-aeba-98a1ad86163d"],
Cell[CellGroupData[{
Cell[143716, 3745, 1722, 44, 90, "Input",ExpressionUUID->"2304c9fb-deb1-4501-8754-c1e0d2b611d4"],
Cell[145441, 3791, 3675, 110, 126, "Output",ExpressionUUID->"424e8f78-eff5-409a-b492-591ac5293f62"]
}, Open  ]],
Cell[149131, 3904, 366, 7, 44, "Text",ExpressionUUID->"c03f6004-e984-4864-836b-816ae214f6e5"],
Cell[CellGroupData[{
Cell[149522, 3915, 340, 8, 37, "Input",ExpressionUUID->"93629099-031e-46bb-9f85-503b21ca302c"],
Cell[149865, 3925, 2908, 87, 123, "Output",ExpressionUUID->"d5f43225-4b37-4d2b-9c90-6f933233b9be"]
}, Open  ]],
Cell[152788, 4015, 397, 9, 37, "Input",ExpressionUUID->"87fce4ab-5e0e-49af-a132-e3c40d3c1bba"],
Cell[153188, 4026, 359, 8, 37, "Input",ExpressionUUID->"beaad10d-e946-4d18-998e-a610b982ab43"],
Cell[CellGroupData[{
Cell[153572, 4038, 1000, 27, 64, "Input",ExpressionUUID->"03aba91f-2481-4466-a330-6a28cbe6be90"],
Cell[154575, 4067, 596, 12, 62, "Output",ExpressionUUID->"15003a57-6138-4b99-9d4d-a0f03748870d"],
Cell[155174, 4081, 526, 9, 42, "Output",ExpressionUUID->"b187fb10-45b5-4ca1-b13e-592c1b93cb98"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[155749, 4096, 462, 13, 50, "Subsubsection",ExpressionUUID->"cc5bef16-082e-4f37-8640-fdabafbe0c92"],
Cell[156214, 4111, 686, 12, 44, "Text",ExpressionUUID->"2e4ec2c1-87bb-4c59-a2f5-3b96c84d2d88"],
Cell[CellGroupData[{
Cell[156925, 4127, 593, 15, 37, "Input",ExpressionUUID->"8debc062-9cec-450c-a0be-bc912457e37a"],
Cell[157521, 4144, 2435, 67, 121, "Output",ExpressionUUID->"49a7d391-466e-484e-9b67-7725646bfcc2"]
}, Open  ]],
Cell[159971, 4214, 620, 9, 44, "Text",ExpressionUUID->"a5c90173-6bac-4039-ab8b-f121607eecc5"],
Cell[CellGroupData[{
Cell[160616, 4227, 782, 22, 37, "Input",ExpressionUUID->"ad431ea3-bee1-41b6-a742-7250fa76537b"],
Cell[161401, 4251, 3836, 79, 69, "Output",ExpressionUUID->"c30b2cb1-8ca7-4771-ac06-4949f8d39687"]
}, Open  ]],
Cell[165252, 4333, 366, 7, 44, "Text",ExpressionUUID->"2d5969de-40a4-44bb-8485-3db4bb1970b1"],
Cell[CellGroupData[{
Cell[165643, 4344, 513, 10, 37, "Input",ExpressionUUID->"2f333a8b-88a7-40d1-b99f-e4a956b3de2d"],
Cell[166159, 4356, 3107, 91, 125, "Output",ExpressionUUID->"402147cf-73bb-424c-b1f9-128b04493a10"]
}, Open  ]],
Cell[CellGroupData[{
Cell[169303, 4452, 772, 19, 90, "Input",ExpressionUUID->"7c08e1c4-21a6-4279-908e-c053ce3285aa"],
Cell[170078, 4473, 1356, 24, 69, "Output",ExpressionUUID->"0d4a07e9-bc1c-4a71-8c15-225a57125617"],
Cell[171437, 4499, 1383, 25, 69, "Output",ExpressionUUID->"c78e3dc7-c892-4e37-b9d3-90c87cdca58e"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[172893, 4532, 161, 3, 84, "Section",ExpressionUUID->"c5748092-b2a1-4a21-b031-94ecdd74394a"],
Cell[CellGroupData[{
Cell[173079, 4539, 2397, 58, 183, "Input",ExpressionUUID->"b647d4cc-ecce-4810-9131-af8ff9a46f31"],
Cell[175479, 4599, 3917, 113, 139, "Output",ExpressionUUID->"b9bf8a59-7f99-48b1-9f59-8b24df324948"]
}, Open  ]],
Cell[CellGroupData[{
Cell[179433, 4717, 4978, 112, 445, "Input",ExpressionUUID->"a8cc0132-66f7-429b-bce2-cdf0aa6ceb29"],
Cell[184414, 4831, 21887, 541, 311, "Output",ExpressionUUID->"4882375d-738f-4243-8f68-100ef9d841e4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[206338, 5377, 1494, 35, 70, "Input",ExpressionUUID->"1ed5a197-c154-462d-bea2-e4278447f1a0"],
Cell[207835, 5414, 2483, 65, 156, "Output",ExpressionUUID->"aaf74d8a-f0b5-47dc-84d0-b75a0d70c31a"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

